# Figure 1 



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
FP <- wes_palette("Zissou1", 5, type = "discrete")
  

## Data loading 
### See "...zenodo/Processing_Analysis/Mouse_integration.R" to prepare the data
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

seu3d <- read.csv("...zenodo/Mouse_integrated_data/seu3d.csv", row.names = 1)
seu3d$Stage <- factor(seu3d$Stage, levels=c("Embryonic", "Neonatal","Pubertal", "Virgin adult", "Pregnant",
                                        "Lactating", "Involuted", "Menopause" ))

### CytoTRACE was run in "CytoTRACE.R"
CytoTRACE <- read.csv("...zenodo/CytoTRACE/Mouse_CytoTRACE_score.csv",
                      row.names = 1)

############################################################################
########################### Fig1A ##########################################
############################################################################
df.std <- as.data.frame(table(seu$Study))
colnames(df.std) <- c("Study", "Count")
df.std$fraction <- df.std$Count / sum(df.std$Count)
df.std$ymax <- cumsum(df.std$fraction)
df.std$ymin <- c(0, head(df.std$ymax, n=-1))
p1 <- ggplot(df.std, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=2.5, fill=Study)) +
  geom_rect(colour="black") +
  scale_colour_manual(values=rep("black", 5)) +
  coord_polar(theta="y") +
  xlim(c(0, 4)) +
  theme_void() + 
  annotate("text", x = 0, y = 0, label = "Study", size=6, fontface = "bold")+ 
  theme(legend.text = element_text(size=10),
        legend.key.size = unit(0.4, "cm"))+
  scale_fill_manual(values=col.std, 
                    name="                         ")

#
df.str <- as.data.frame(table(seu$Strain))
colnames(df.str) <- c("Strain", "Count")
df.str$fraction <- df.str$Count / sum(df.str$Count)
df.str$ymax <- cumsum(df.str$fraction)
df.str$ymin <- c(0, head(df.str$ymax, n=-1))
p2 <- ggplot(df.str, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=2.5, fill=Strain)) +
  geom_rect(colour="black") +
  scale_colour_manual(values=rep("black", 3)) +
  coord_polar(theta="y") +
  xlim(c(0, 4)) +
  theme_void() + 
  annotate("text", x = 0, y = 0, label = "Strain", size=6, fontface = "bold")+ 
  theme(legend.text = element_text(size=10),
        legend.key.size = unit(0.4, "cm"))+
  scale_fill_manual(values=col.str, 
                    name="                         ")

#
df.stg <- as.data.frame(table(seu$Stage))
colnames(df.stg) <- c("Stage", "Count")
df.stg$fraction <- df.stg$Count / sum(df.stg$Count)
df.stg$ymax <- cumsum(df.stg$fraction)
df.stg$ymin <- c(0, head(df.stg$ymax, n=-1))
p3 <- ggplot(df.stg, aes(ymax=ymax, ymin=ymin, xmax=4, xmin=2.5, fill=Stage)) +
  geom_rect(colour="black")+
  scale_colour_manual(values=rep("black", 8)) +
  coord_polar(theta="y") +
  xlim(c(0, 4)) +
  theme_void() + 
  annotate("text", x = 0, y = 0, label = "Stage", size=6, fontface = "bold")+ 
  theme(legend.text = element_text(size=10),
        legend.key.size = unit(0.4, "cm"))+
  scale_fill_manual(values=col.stg, 
                    name="                         ")

Fig1A <- plot_grid(p1, p2, p3, ncol = 1, align = 'hv')


############################################################################
########################### Fig1B ##########################################
############################################################################
Fig1B <- plot_ly(seu3d, x = ~UMAP_1, y = ~UMAP_2, z = -seu3d$UMAP_3, color = ~Stage, colors= col.stg)  %>%
  add_markers() %>%
  layout(scene = list(xaxis = list(title = 'UMAP1'),
                      yaxis = list(title = 'UMAP2'),
                      zaxis = list(title = 'UMAP3')))%>%
  layout(legend = list(font = list(size = 20)))


############################################################################
########################### Fig1C ##########################################
############################################################################
p5 <- UMAPPlot(seu, group.by="Modified.ident", cols=col.clst)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Cluster")
p6 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Study")
p7 <- UMAPPlot(seu, group.by="Strain", cols=col.str)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Strain")
p8 <- UMAPPlot(seu, group.by="Stage", cols=col.stg)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Stage")
Fig1C <- plot_grid(p5, p6, p7, p8, ncol = 2, align='hv')


############################################################################
################################### Fig1D ##################################
############################################################################
Idents(seu) <- "orig.ident"
cell_E16 <- WhichCells(seu, idents="Embryonic_d16(G)")
cell_E18 <- WhichCells(seu, idents="Embryonic_d18(G)")

p9 <- UMAPPlot(seu, cells.highlight=cell_E16)+
  NoLegend()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Embryonic Day16")
p10 <- UMAPPlot(seu, cells.highlight=cell_E18)+
  NoLegend()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Embryonic Day18")
p11 <- FeaturePlot(seu, "Krt14", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Krt14 (Basal cells)")
p12 <- FeaturePlot(seu, "Krt18", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Krt18 (Luminal cells)")
p13 <- FeaturePlot(seu, "Csn3", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Csn3 (Luminal-Alveolar)")
p14 <- FeaturePlot(seu, "Areg", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Areg (Luminal-Hor)")

Fig1D <- plot_grid(p9, p11, p12, p10, p13, p14, align = "v", ncol=3)


############################################################################
########################### Fig1E ##########################################
############################################################################
label <- row.names(CytoTRACE)

sub <- subset(seu, cells = label)

sub <- AddMetaData(sub, metadata = CytoTRACE)

Idents(sub) <- "orig.ident"
sub <- subset(sub, idents = c("Embryonic_d16(G)", "Embryonic_d18(G)", "Postnatal_d4(G)", "Adult_1(G)", "Adult_2(G)",
                              "Puberty_1(P)", "Puberty_2(P)", "Adult(P)", "Nulliparous_1(B)", "Nulliparous_2(B)",
                              "Gestation_1(B)", "Gestation_2(B)", "Lactation_1(B)", "Lactation_2(B)", 
                              "PostInvolution_1(B)", "PostInvolution_2(B)", "OVX(S)"))

df<- sub@meta.data
p15 <- ggboxplot(df, x = "Modified.ident", y = "CytoTRACE",
          col = "Modified.ident", palette =col.clst, 
          add = "jitter",                         
          add.params = list(size = 0.05, jitter = 0.2))+
  NoLegend()+
  xlab("Clusters")+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                              "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                              "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"))+ 
  scale_y_continuous(breaks=seq(0,1,0.25),limits=c(0, 1.1))
my_comparisons <- list( c("1", "2"), c("3", "4"), c("5", "6") )
 
Fig1E <- p15 + stat_compare_means(comparisons = my_comparisons, step.increase = 0, label = "p.signif")
