# Figure 2 



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  


## Data loading 
### See "...zenodo/Processing_Analysis/Mouse_integration.R" to prepare the data
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)



############################################################################
########################### Fig2A-B ########################################
############################################################################
## Refer to "...zenodo/STREAM/500_each_output/S5"


############################################################################
########################### Fig2C_1#########################################
############################################################################
seu <- AddMetaData(seu, meta)
p1 <- FeaturePlot(seu, "S5_pseudotime", pt.size = 0.5)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("S5_Pseudotime (Stem)")+
  NoAxes()+ 
  scale_color_gradient2(midpoint = 0.04, low = "#ad2dfe", mid = "lightgrey",
                        high = "grey24")
p2 <- FeaturePlot(seu, "S4_pseudotime", pt.size = 0.5)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("S4_Pseudotime (Basal)")+
  NoAxes()+ 
  scale_color_gradient2(midpoint = 0.075, low = "#FF7F00", mid = "lightgrey",
                        high = "grey24")
p3 <- FeaturePlot(seu, "S2_pseudotime", pt.size = 0.5)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("S2_Pseudotime (Alv)")+
  NoAxes()+ 
  scale_color_gradient2(midpoint = 0.06, low = "#33A02C", mid = "lightgrey",
                        high = "grey24")
p4 <- FeaturePlot(seu, "S1_pseudotime", pt.size = 0.5)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("S1_Pseudotime (Hor)")+
  NoAxes()+ 
  scale_color_gradient2(midpoint = 0.05, low = "#E31A1C", mid = "lightgrey",
                        high = "grey24")
Fig2A_1 <- plot_grid(p1, p2, p3, p4, ncol = 2, align="hv")



############################################################################
########################### Fig2C_2#########################################
############################################################################
cor_GSVA_Stem <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Stem.csv")
cor_GSVA_Basal <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Basal.csv")
cor_GSVA_Alv <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Alv.csv")
cor_GSVA_Hor <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Hor.csv")

colnames(cor_GSVA_Stem)[1] <- "Study"
colnames(cor_GSVA_Stem)[2:101] <- 1:100
temp_stem <- melt(cor_GSVA_Stem, id="Study", measure = colnames(cor_GSVA_Stem)[2:101])
temp_stem$value <- -1 * temp_stem$value
temp_stem$variable <- as.numeric(temp_stem$variable)
temp_stem$Category <- rep("Stem", length(row.names(temp_stem)))

colnames(cor_GSVA_Basal)[1] <- "Study"
colnames(cor_GSVA_Basal)[2:101] <- 1:100
temp_Basal <- melt(cor_GSVA_Basal, id="Study", measure = colnames(cor_GSVA_Basal)[2:101])
temp_Basal$value <- -1 * temp_Basal$value
temp_Basal$variable <- as.numeric(temp_Basal$variable)
temp_Basal$Category <- rep("Basal", length(row.names(temp_Basal)))

colnames(cor_GSVA_Alv)[1] <- "Study"
colnames(cor_GSVA_Alv)[2:101] <- 1:100
temp_Alv <- melt(cor_GSVA_Alv, id="Study", measure = colnames(cor_GSVA_Alv)[2:101])
temp_Alv$value <- -1 * temp_Alv$value
temp_Alv$variable <- as.numeric(temp_Alv$variable)
temp_Alv$Category <- rep("Alv", length(row.names(temp_Alv)))

colnames(cor_GSVA_Hor)[1] <- "Study"
colnames(cor_GSVA_Hor)[2:101] <- 1:100
temp_Hor <- melt(cor_GSVA_Hor, id="Study", measure = colnames(cor_GSVA_Hor)[2:101])
temp_Hor$value <- -1 * temp_Hor$value
temp_Hor$variable <- as.numeric(temp_Hor$variable)
temp_Hor$Category <- rep("Hor", length(row.names(temp_Hor)))

df <- rbind(temp_stem, temp_Basal, temp_Alv, temp_Hor)
cols <- c(wes_palette("IsleofDogs1", 1),"#FF7F00","#33A02C","#E31A1C")
df$Category <- factor(df$Category, levels = c("Stem", "Basal", "Alv", "Hor"))

###
cor_GSVA_Stem <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Stem_1000.csv")
cor_GSVA_Basal <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Basal_1000.csv")
cor_GSVA_Alv <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Alv_1000.csv")
cor_GSVA_Hor <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Hor_1000.csv")

coln <- seq(120, 1000, 20)

colnames(cor_GSVA_Stem)[1] <- "Study"
colnames(cor_GSVA_Stem)[2:46] <- coln
temp_stem <- melt(cor_GSVA_Stem, id="Study", measure = colnames(cor_GSVA_Stem)[2:46])
temp_stem$value <- -1 * temp_stem$value
temp_stem$variable <- as.numeric(temp_stem$variable)
temp_stem$Category <- rep("Stem", length(row.names(temp_stem)))

colnames(cor_GSVA_Basal)[1] <- "Study"
colnames(cor_GSVA_Basal)[2:46] <- coln
temp_Basal <- melt(cor_GSVA_Basal, id="Study", measure = colnames(cor_GSVA_Basal)[2:46])
temp_Basal$value <- -1 * temp_Basal$value
temp_Basal$variable <- as.numeric(temp_Basal$variable)
temp_Basal$Category <- rep("Basal", length(row.names(temp_Basal)))

colnames(cor_GSVA_Alv)[1] <- "Study"
colnames(cor_GSVA_Alv)[2:46] <- coln
temp_Alv <- melt(cor_GSVA_Alv, id="Study", measure = colnames(cor_GSVA_Alv)[2:46])
temp_Alv$value <- -1 * temp_Alv$value
temp_Alv$variable <- as.numeric(temp_Alv$variable)
temp_Alv$Category <- rep("Alv", length(row.names(temp_Alv)))

colnames(cor_GSVA_Hor)[1] <- "Study"
colnames(cor_GSVA_Hor)[2:46] <- coln
temp_Hor <- melt(cor_GSVA_Hor, id="Study", measure = colnames(cor_GSVA_Hor)[2:46])
temp_Hor$value <- -1 * temp_Hor$value
temp_Hor$variable <- as.numeric(temp_Hor$variable)
temp_Hor$Category <- rep("Hor", length(row.names(temp_Hor)))

df2 <- rbind(temp_stem, temp_Basal, temp_Alv, temp_Hor)
cols <- c(wes_palette("IsleofDogs1", 1),"#FF7F00","#33A02C","#E31A1C")
df2$Category <- factor(df2$Category, levels = c("Stem", "Basal", "Alv", "Hor"))
df2$variable <- rep(coln, each=5)

df3 <- rbind(df,df2)


Fig2A_2 <- ggplot(df3, aes(x=variable, y=value, gruop=Category, color=Category)) +
  geom_smooth()+
  scale_color_manual(values=cols)+
  ggtitle("Genesets performance")+
  xlab("Number of genes in genesets")+
  ylab("Correlation with pseudotime")+ 
  labs(fill = "Genesets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))



#######################################################################################
###### Fig2C_3 ########################################################################
#######################################################################################
#
cor_all <- read.csv("...zenodo/GSVA/Mouse/cor_all_pseudotime_ranked_annotated.csv", row.names = 1)
cor_Stem <- cbind(cor_all[, c(grep("S5", colnames(cor_all)))], cor_all$category)
colnames(cor_Stem)[8] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data <- cor_Stem[cor_Stem$S5_rank %in% c(8, 12, 37, 22545, 22549)|
                         cor_Stem$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data) <- paste(label_data$S5_rank, row.names(label_data), sep=".")

Fig2C_3 <- ggplot(cor_Stem, aes(x=S5_rank, y=S5_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data, aes(x=S5_rank, y=S5_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data, S5_mean > 0.15),
    aes(label=row.names(subset(label_data, S5_mean > 0.15))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data, S5_mean < -0.15),
    aes(label=row.names(subset(label_data, S5_mean < -0.15))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_Stem)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 5 studies)") +
  ggtitle("Feature correlation with S5_pseudotime (Stem)") +
  guides(color=F)




#######################################################################################
###### Fig2D ##########################################################################
#######################################################################################
Mouse_res_meta <- read.csv("...zenodo/GSVA/Mouse/Mouse_res_meta.csv", row.names = 1)
Mouse_res_meta$Annotation <- factor(Mouse_res_meta$Annotation,
                                    levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Mouse_res_meta$Study <- factor(Mouse_res_meta$Study,
                               levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))

## Base trajectory
# Giraddi_res <- Mouse_res_meta[Mouse_res_meta$Study == "Giraddi",]
# data <- Giraddi_res[,1:4]
# data.umap <- umap(data[,1:4], verbose=T)
# saveRDS(data.umap, "...zenodo/UMAP/Mouse_base_umap.rds")
data.umap <- readRDS("...zenodo/UMAP/Mouse_base_umap.rds")

###
df <- as.data.frame(data.umap$layout)
Fig2D_1 <- ggplot(df, aes(x=V1, y=V2))+
  geom_point(size=1, col="black")+
  ggtitle("UMAP (base)")+
  NoLegend()+
  NoAxes()+ 
  theme(plot.title = element_text(size=24, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))


## All data
# data_all <- Mouse_res_meta[,1:4]
# All.umap <- predict(data.umap, data_all)
# write.csv(All.umap, "...zenodo/UMAP/Mouse_all_umap.csv")
All.umap <- read.csv("...zenodo/UMAP/Mouse_all_umap.csv",
                     row.names = 1)

###
All.umap <- as.data.frame(All.umap)
p3 <- ggplot(All.umap, aes(x=V1, y=V2, col=Mouse_res_meta$Annotation))+
  geom_point(size=1)+
  scale_color_manual(values=col.clst)+ 
  labs(col = "Cluster")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  ggtitle("All data (by cluster)")+
  theme_classic()+
  NoLegend()+
  theme(plot.title = element_text(size=24, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title=element_text(size=12,face="bold"),)

p4 <- ggplot(All.umap, aes(x=V1, y=V2, col=Mouse_res_meta$Study))+
  geom_point(size=1)+
  scale_color_manual(values=col.std)+ 
  labs(col = "Cluster")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  ggtitle("All data (by study)")+
  theme_classic()+
  NoLegend()+
  theme(plot.title = element_text(size=24, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title=element_text(size=12,face="bold"),)

Fig2D_2 <- plot_grid(p3, p4, ncol=1)

