# Figure 3 



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}


#######################################################################################
###### Fig3A ##########################################################################
#######################################################################################
Ind6 <- readRDS("...zenodo/Human_normal_breast_data/Ind6/Ind6_cleaned.rds")
Pred_ind6 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind6.csv", row.names = 1)

Ind6 <- AddMetaData(Ind6, Pred_ind6)
Ind6 <- NormalizeData(Ind6)
Ind6 <- FindVariableFeatures(Ind6, selection.method = "vst", nfeatures = 2000)
Ind6 <- ScaleData(Ind6, features = rownames(Ind6))
Ind6 <- RunPCA(Ind6, features = VariableFeatures(object = Ind6))
Ind6 <- RunUMAP(Ind6, dims=1:10)
Ind6 <- FindNeighbors(Ind6, dims = 1:10)
Ind6 <- FindClusters(Ind6, resolution = 0.3)

Ind6$predicted.id <- factor(Ind6$predicted.id, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))

p3 <- UMAPPlot(Ind6, group.by="clust", cols=col.human, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind6_Definitive annotation")
p4 <- UMAPPlot(Ind6, group.by="predicted.id", cols=col.clst, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind6_Transfered annotation")
Fig3A <- plot_grid(p3, p4, align='hv', ncol=2)



######################################################################################
################ Figure 3B ###########################################################
######################################################################################
Ind4 <- readRDS("...zenodo/Human_normal_breast_data/Ind4/Ind4_cleaned.rds")
Ind5 <- readRDS("...zenodo/Human_normal_breast_data/Ind5/Ind5_cleaned.rds")
Ind6 <- readRDS("...zenodo/Human_normal_breast_data/Ind6/Ind6_cleaned.rds")
Ind7 <- readRDS("...zenodo/Human_normal_breast_data/Ind7/Ind7_cleaned.rds")

Nguyen <- merge(Ind4, y = c(Ind5, Ind6, Ind7), 
                add.cell.ids = NULL, project = "Nguyen")
remove(Ind4, Ind5, Ind6, Ind7)
gc();gc()

Pred_ind4 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind4.csv", row.names = 1)
Pred_ind5 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind5.csv", row.names = 1)
Pred_ind6 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind6.csv", row.names = 1)
Pred_ind7 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind7.csv", row.names = 1)
Prediction <- rbind(Pred_ind4, Pred_ind5, Pred_ind6, Pred_ind7)

Nguyen <- AddMetaData(Nguyen, metadata=Prediction)

###
meta <- Nguyen@meta.data[,7:8]
meta$predicted.id[meta$predicted.id=="MaSC/B-pro"] <- "Basal"
meta$predicted.id[meta$predicted.id=="LA-pro"] <- "L-Alv"
meta$predicted.id[meta$predicted.id=="LH-pro"] <- "L-Hor"

stat <- as.data.frame(table(meta$clust, meta$predicted.id))
colnames(stat) <- c("Definitive", "Transferred", "Percentage")
stat <- stat[1:9,]

stat$Definitive <- factor(stat$Definitive, levels = c("L2", "L1.1/L1.2", "B/Myo"))

stat$Percentage[1:3] <- stat$Percentage[1:3]/sum(stat$Percentage[1:3]) *100
stat$Percentage[4:6] <- stat$Percentage[4:6]/sum(stat$Percentage[4:6]) *100
stat$Percentage[7:9] <- stat$Percentage[7:9]/sum(stat$Percentage[7:9]) *100

stat$Label <- round(stat$Percentage, digits = 1)
stat$Label <- paste(stat$Label, "%", sep="")
stat$Label[c(2:4, 6:8)] <-""

Fig3B <- ggplot(stat, aes(x = Transferred, y = Definitive, col = Label)) +
  geom_text(aes(label=Label, col = "black"), size=5)+ 
  geom_point(aes(size = Percentage),alpha = 0.5)+
  scale_size(range = c(0, 30), limits = c(0,100))+
  scale_color_manual(values = c("darkgrey", "#33A02C", "#E31A1C", "#FF7F00", "black"))+
  guides(color = F, size = F)+ 
  scale_x_discrete(breaks=c("Basal","L-Alv","L-Hor"),
                   labels=c("MaSC/B-pro \n Basal", "LA-pro \n L-Alv", "LH-pro \n L-Hor"))+
  xlab("Human breast epithelium \n (Transferred annotation)")+
  ylab("Human breast epithelium \n (Definitive annotation)")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=12),
        legend.text =element_text(size=8),
        axis.title=element_text(size=14,face="bold"))



######################################################################################
################ Figure 3C ###########################################################
######################################################################################
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
Nguyen$predicted.id <- factor(Nguyen$predicted.id,
                              levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))

Nguyen <- ScaleData(Nguyen, features = rownames(Nguyen))
Nguyen <- RunPCA(Nguyen, features = VariableFeatures(object = Nguyen))
Nguyen <- RunUMAP(Nguyen, dims = 1:10)
Nguyen <- FindNeighbors(Nguyen, dims = 1:10)
Nguyen <- FindClusters(Nguyen, resolution = 0.1)


Fig3C_1 <- UMAPPlot(Nguyen, group.by="predicted.id", cols=col.clst)+
  theme(plot.title = element_text(size=24, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  NoLegend()+
  ggtitle("Integrated human breast")



## Fig3C_2
## Refer to "...zenodo/STREAM/Human_all_output/S3"


## Fig3C_3
Normal <- read.csv("...zenodo/GSVA/Human/Normal_breast_GSVA.csv", row.names=1)
# data.umap <- umap(Normal[,1:4], verbose=T)
# saveRDS(data.umap, "...zenodo/UMAP/Human_normal_breast_umap.rds")

data.umap <- readRDS("...zenodo/UMAP/Human_normal_breast_umap.rds")

##
temp <- as.data.frame(data.umap$layout)
Fig3C_3_1 <- ggplot(temp, aes(x=V1, y=V2, col=Normal$clust))+
  geom_point(size=1)+ 
  labs(col = "Cell type")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  scale_color_manual(values = c("#FF7F00", "#33A02C", "#E31A1C"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("Cell type")
Fig3C_3_2 <- ggplot(temp, aes(x=V1, y=V2, col=Normal$orig.ident))+
  geom_point(size=1)+ 
  labs(col = "Dataset")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("Individual")
Fig3C_3 <- plot_grid(Fig3C_3_1, Fig3C_3_2, align='hv', ncol=1)



######################################################################################
################ Figure 3D ###########################################################
######################################################################################
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta <- na.omit(meta)

BRCA_gsvaResult <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)

# data.umap <- umap(BRCA_gsvaResult[,1:4], verbose=T)
# saveRDS(data.umap, "...zenodo/UMAP/TCGA_umap.rds")
data.umap <- readRDS("...zenodo/UMAP/TCGA_umap.rds")

temp <- as.data.frame(data.umap$layout)
temp <- temp[row.names(meta),]

Fig3D_1 <- ggplot(temp, aes(x=V1, y=V2, col=meta$Subtype))+
  geom_point(size=2)+
  scale_color_manual(values = c(pam50.col, "darkgrey"))+ 
  labs(col = "Subtype")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("TCGA_BRCA(n=1215)")

###
BRCA_gsvaResult <- BRCA_gsvaResult[row.names(meta),]
colnames(BRCA_gsvaResult)[1] <- "Curated_Stem"

data_tern <- BRCA_gsvaResult
data_tern$Curated_Stem <- range01(data_tern$Curated_Stem)
data_tern$Curated_Basal <- range01(data_tern$Curated_Basal)
data_tern$Curated_Alv <- range01(data_tern$Curated_Alv)
data_tern$Curated_Hor <- range01(data_tern$Curated_Hor)

colnames(data_tern) <- c("Stem", "Basal", "Alv", "Hor")

Fig3D_2 <- ggtern(data=data_tern, aes(Basal, Alv, Hor))+
  geom_point(aes(color=meta$Subtype), size=2)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(pam50.col, "darkgrey"))+ 
  labs(col = "Subtype")+
  ggtitle("TCGA_BRCA(n=1215)")



######################################################################################
################ Figure 3E ###########################################################
######################################################################################
HBC_res <- read.csv("...zenodo/GSVA/Human/HBC_GSVA.csv", row.names=1)
HBC_res$Subtype <- as.character(HBC_res$Subtype)
HBC_res$Subtype[HBC_res$Subtype == "HER2"] <- "Her2"
HBC_res$Subtype <- factor(HBC_res$Subtype, levels = c("TNBC", "Her2", "LumA", "LumB"))

# data.umap <- umap(HBC_res[,1:4], verbose=T)
# saveRDS(data.umap, "...zenodo/UMAP/scBRCA_umap.rds")
data.umap <- readRDS("...zenodo/UMAP/scBRCA_umap.rds")

PAM50Preds <- readRDS("...zenodo/PAM50/scBRCA_PAM50.rds")
PAM50Preds$subtype
# BC01   BC02   BC03   BC04   BC05   BC06   BC07   BC08   BC10   BC11 
# LumB   LumA   LumB   Her2   Her2   LumB   LumB Normal Normal  Basal 

HBC_res$PAM50 <- "LumB"
HBC_res$patient <- as.character(HBC_res$patient)
HBC_res$PAM50[HBC_res$patient %in% c("BC02")] <- "LumA"
HBC_res$PAM50[HBC_res$patient %in% c("BC04", "BC05")] <- "Her2"
HBC_res$PAM50[HBC_res$patient %in% c("BC08", "BC10")] <- "Normal"
HBC_res$PAM50[HBC_res$patient %in% c("BC11")] <- "Basal"

temp <- as.data.frame(data.umap$layout)
Fig3E_1 <- ggplot(temp, aes(x=V1, y=V2, col=HBC_res$PAM50))+
  geom_point(size=2)+
  scale_color_manual(values = c(pam50.col))+ 
  labs(col = "Subtype")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("BRCA scRNAseq")


###
data_tern <- HBC_res
range01 <- function(x){(x-min(x))/(max(x)-min(x))}
data_tern$Curated_Stem <- range01(data_tern$Curated_Stem)
data_tern$Curated_Basal <- range01(data_tern$Curated_Basal)
data_tern$Curated_Alv <- range01(data_tern$Curated_Alv)
data_tern$Curated_Hor <- range01(data_tern$Curated_Hor)

colnames(data_tern) <- c("Stem", "Basal", "Alv", "Hor")

Fig3E_2 <- ggtern(data=data_tern, aes(Basal, Alv, Hor))+
  geom_point(aes(color=HBC_res$PAM50), size=2)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  scale_color_manual(values = pam50.col)+ 
  labs(col = "Subtype")+
  ggtitle("BRCA scRNAseq")

