# Figure 4



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}


########################################################################
###### Fig. 4A##########################################################
########################################################################
###Human
data.umap <- readRDS("...zenodo/UMAP/Human_normal_breast_umap.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Nguyen_PAM50.rds")
PAM50 <- as.data.frame(PAM50Preds$subtype)
colnames(PAM50) <- "PAM50"
PAM50$PAM50 <- factor(PAM50$PAM50, levels = c("Basal", "Her2", "LumA", "LumB", "Normal"))

temp <- as.data.frame(data.umap$layout)
PAM50 <- PAM50[row.names(temp), ]

Fig4A_1 <- ggplot(temp, aes(x=V1, y=V2, col=PAM50))+
  geom_point(size=1)+ 
  labs(col = "Subtype")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  scale_color_manual(values = pam50.col)+
  ggtitle("Human Breast(PAM50)")


#### Mouse
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
hPAM50 <- as.data.frame(PAM50Preds$subtype)
colnames(hPAM50) <- "PAM50"
hPAM50$PAM50 <- factor(hPAM50$PAM50, levels = c("Basal", "Her2", "LumA", "LumB", "Normal"))

seu_umap <- as.data.frame(seu@reductions$umap@cell.embeddings)

Fig4A_2 <- ggplot(seu_umap, aes(x=UMAP_1, y=UMAP_2, col=hPAM50$PAM50))+
  geom_point(size=1)+ 
  labs(col = "Subtype")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  scale_color_manual(values = pam50.col)+
  ggtitle("Mouse MG(PAM50)")

Fig4A <- plot_grid(Fig4A_1, Fig4A_2, ncol=2)



####################################################################
################ Fig.4B ############################################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
Idents(seu) <- "orig.ident"
sub <- subset(seu, idents = c("Embryonic_d16(G)", "Embryonic_d18(G)", "Postnatal_d4(G)", "Adult_1(G)", "Adult_2(G)",
                              "Puberty_1(P)", "Puberty_2(P)", "Adult(P)", "Nulliparous_1(B)", "Nulliparous_2(B)",
                              "OVX(S)"))
sub_meta <- sub@meta.data
sub_meta$Development <- as.character(sub_meta$Stage)
sub_meta$Development[sub_meta$orig.ident == "Embryonic_d16(G)"] <- "Embryonic(E16)"
sub_meta$Development[sub_meta$orig.ident == "Embryonic_d18(G)"] <- "Embryonic(E18)"
sub@meta.data <- sub_meta
sub$Development <- factor(sub$Development, levels=c("Embryonic(E16)", "Embryonic(E18)", "Neonatal","Pubertal", "Virgin adult", "Menopause" ))
UMAPPlot(sub, group.by="Development")

Idents(sub) <- "Development"
p1 <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Embryonic(E16)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Embryonic(E16)")
p2 <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Embryonic(E18)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Embryonic(E18)")
p3  <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Neonatal"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Neonatal")
p4  <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Pubertal"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Pubertal")
p5  <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Virgin adult"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Virgin adult")
p6  <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Menopause"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Menopause")
Fig4B_1 <- plot_grid(p1, p2, p3, p4, p5, p6, ncol=6)



###
## Refer to "...zenodo/STREAM/Development_output/"



###
stat <- as.data.frame(table(sub$Annotation, sub$Development))
colnames(stat) <- c("Cluster", "Stage", "Freq")
Fig4B_2 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Stage, fill = Cluster), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = col.clst)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "Cluster")+
  ggtitle("Development")



####################################################################
################ Fig.4C ############################################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
Idents(seu) <- "orig.ident"
sub <- subset(seu, idents = c("Nulliparous_1(B)", "Nulliparous_2(B)", "Gestation_1(B)", "Gestation_2(B)", "Lactation_1(B)", "Lactation_2(B)", 
                              "PostInvolution_1(B)", "PostInvolution_2(B)"))
sub$Stage <- factor(sub$Stage, levels=c("Virgin adult", "Pregnant", "Lactating", "Involuted"))
UMAPPlot(sub, group.by="Stage")

Idents(sub) <- "Stage"
p1 <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Virgin adult"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Virgin adult")
p2 <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Pregnant"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Pregnant")
p3  <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Lactating"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Lactating")
p4  <- UMAPPlot(seu, cells.highlight=WhichCells(sub, idents = "Involuted"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Involuted")
Fig4C_1 <- plot_grid(p1, p2, p3, p4, ncol=4)



###
## Refer to "...zenodo/STREAM/Pregnancy_output/"



###
stat <- as.data.frame(table(sub$Annotation, sub$Stage))
colnames(stat) <- c("Cluster", "Stage", "Freq")
Fig4C_2 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Stage, fill = Cluster), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = col.clst)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "Cluster")+
  ggtitle("Pregnancy")



####################################################################
################ Fig.4D ############################################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
Idents(seu) <- "Study"
sub <- subset(seu, idents="Saeki")
UMAPPlot(sub, cols=col.clst, group.by="Annotation", pt.size=1)+NoLegend()
seu$orig.ident <- factor(seu$orig.ident, levels=c("OVX(S)","OVX_E2(S)","OVX_E2_PBDE(S)","OVX_E2_P4(S)","OVX_E2_P4_PBDE(S)"  ))

stat <- as.data.frame(table(sub$Annotation, sub$orig.ident))
stat <- stat[127:156,]
colnames(stat) <- c('Cluster', 'Sample', 'Frequency')

# Total cell number was collected from Supplementary table

stat$Frequency[1:6] <- stat$Frequency[1:6]/3107*100
stat$Frequency[7:12] <- stat$Frequency[7:12]/2229*100
stat$Frequency[13:18] <- stat$Frequency[13:18]/3526*100
stat$Frequency[19:24] <- stat$Frequency[19:24]/3097*100
stat$Frequency[25:30] <- stat$Frequency[25:30]/2358*100

Fig4D <- ggplot(data=stat, aes(x=Sample, y=Frequency, fill=Cluster)) + 
  geom_bar(stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = col.clst)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "Cluster")+
  ggtitle("OVX+HRT")

