# Cytotrace 



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}


########################################################################
###### Mouse CytoTRACE (3,000 each from each cluster) ##################
########################################################################
seu <- readRDS("...zenodo/Integrated_data/IntData.rds")

## Downsample cells
Idents(seu) <- "Modified.ident"
C1 <- sample(WhichCells(seu, idents=1), 3000)
C2 <- sample(WhichCells(seu, idents=2), 3000)
C3 <- sample(WhichCells(seu, idents=3), 3000)
C4 <- sample(WhichCells(seu, idents=4), 3000)
C5 <- sample(WhichCells(seu, idents=5), 3000)
C6 <- WhichCells(seu, idents=6)
down_label <- c(C1, C2, C3, C4, C5, C6)

### Please see "...zonedo/code/Processing_Analysis/Mouse_sample_preprocessing.R" 
### to prepare cleaned data.

## Raw data
Bach <- readRDS("...your_folder/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...your_folder/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...your_folder/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...your_folder/Pal/Pal_cleaned.rds")
TM <- readRDS("...your_folder//TabulaMuris/TabulaMuris_cleaned.rds")

## Data sampling
G.expr <- as.data.frame(Giraddi@assays$RNA@counts)
G.expr <- G.expr[,colnames(G.expr) %in% down_label]

P.expr <- as.data.frame(Pal@assays$RNA@counts)
P.expr <- P.expr[,colnames(P.expr) %in% down_label]

B.expr <- as.data.frame(Bach@assays$RNA@counts)
B.expr <- B.expr[,colnames(B.expr) %in% down_label]

T.expr <- as.data.frame(TM@assays$RNA@counts)
T.expr <- T.expr[,colnames(T.expr) %in% down_label]

S.expr <- as.data.frame(Saeki@assays$RNA@counts) 
S.expr <- S.expr[,colnames(S.expr) %in% down_label]


## iCytoTRACE
datasets <- list(B.expr, G.expr, P.expr, S.expr)
# no cell from Tabula Muris by chance

results <- iCytoTRACE(datasets)
Cytotrace <- cbind(results[['CytoTRACE']], results[['GCS']])
colnames(Cytotrace) <- c("CytoTRACE", "GCS")
write.csv(Cytotrace, "...zenodo/CytoTRACE/Mouse_CytoTRACE_score.csv")


########################################################################
###### Human CytoTRACE (15,000 cells) ##################################
########################################################################
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
label <- sample(colnames(Nguyen), 15000)

Ind4 <- readRDS("...zenodo/Human_normal_breast_data/Ind4/Ind4_cleaned.rds")
Ind5 <- readRDS("...zenodo/Human_normal_breast_data/Ind5/Ind5_cleaned.rds")
Ind6 <- readRDS("...zenodo/Human_normal_breast_data/Ind6/Ind6_cleaned.rds")
Ind7 <- readRDS("...zenodo/Human_normal_breast_data/Ind7/Ind7_cleaned.rds")

##
Ind4.expr <- as.data.frame(Ind4@assays$RNA@counts)
Ind5.expr <- as.data.frame(Ind5@assays$RNA@counts)
Ind6.expr <- as.data.frame(Ind6@assays$RNA@counts)
Ind7.expr <- as.data.frame(Ind7@assays$RNA@counts)

Ind4.expr <- Ind4.expr[ ,colnames(Ind4.expr) %in% label$x]
Ind5.expr <- Ind5.expr[ ,colnames(Ind5.expr) %in% label$x]
Ind6.expr <- Ind6.expr[ ,colnames(Ind6.expr) %in% label$x]
Ind7.expr <- Ind7.expr[ ,colnames(Ind7.expr) %in% label$x]

datasets <- list(Ind4.expr, Ind5.expr, Ind6.expr, Ind7.expr)
names(datasets) <- c("Ind4", "Ind5", "Ind6", "Ind7")

##
results <- iCytoTRACE(datasets)
Cytotrace <- cbind(results[['CytoTRACE']], results[['GCS']])
colnames(Cytotrace) <- c("CytoTRACE", "GCS")
write.csv(Cytotrace, "...zenodo/CytoTRACE/Human_CytoTRACE_score.csv")