# scGSVA analysis of the mouse data



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}



####################################################################
########## Cell sampling for gene list performance #################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

Idents(seu) <- "Study"
Cell_Giraddi <- WhichCells(seu, idents = "Giraddi")
Cell_Giraddi_sampled <- sample(Cell_Giraddi, 1000)

Cell_Bach <- WhichCells(seu, idents = "Bach")
Cell_Bach_sampled <- sample(Cell_Bach, 1000)

Cell_Pal <- WhichCells(seu, idents = "Pal")
Cell_Pal_sampled <- sample(Cell_Pal, 1000)

Cell_Saeki <- WhichCells(seu, idents = "Saeki")
Cell_Saeki_sampled <- sample(Cell_Saeki, 1000)

# Tabula Muris: total 774 cells not sampled
Cell_TabulaMuris <- WhichCells(seu, idents = "TabulaMuris")

# Data saving
temp <- list(Cell_Giraddi_sampled, Cell_Bach_sampled, Cell_Pal_sampled, Cell_Saeki_sampled)
names(temp) <- c("Giraddi", "Bach", "Pal", "Saeki")
saveRDS(temp, "...zenodo/GSVA/Mouse/Sampled_barcodes.rds")



########################################################################
###### Gene pseudotime correlation #####################################
########################################################################

### Please see "...zenodo/code/Processing_Analysis/Mouse_sample_preprocessing.R" 
### to prepare cleaned data.

Bach <- readRDS("...zenodo/Mouse_normal_breast_data/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...zenodo/Mouse_normal_breast_data/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...zenodo/Mouse_normal_breast_data/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...zenodo/Mouse_normal_breast_data/Pal/Pal_cleaned.rds")
TM <- readRDS("...zenodo/Mouse_normal_breast_data//TabulaMuris/TabulaMuris_cleaned.rds")

meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)

## Data preparation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Giraddi <- NormalizeData(Giraddi)
Giraddi <- ScaleData(Giraddi, features=rownames(Giraddi))
matGiraddi <- Giraddi@assays$RNA@scale.data

Bach <- NormalizeData(Bach)
Bach <- ScaleData(Bach, features=rownames(Bach))
matBach <- Bach@assays$RNA@scale.data

Pal <- NormalizeData(Pal)
Pal <- ScaleData(Pal, features=rownames(Pal))
matPal <- Pal@assays$RNA@scale.data

Saeki <- NormalizeData(Saeki)
Saeki <- ScaleData(Saeki, features=rownames(Saeki))
matSaeki <- Saeki@assays$RNA@scale.data

TM <- NormalizeData(TM)
TM <- ScaleData(TM, features=rownames(TM))
matTM <- TM@assays$RNA@scale.data
colnames(matTM) <- gsub("TM_Adu1_", "", colnames(matTM))
colnames(matTM) <- gsub("TM_Adu2_", "", colnames(matTM))

remove(Bach, Pal, Giraddi, Saeki, TM)
gc();gc()

## Gene pseudotime correlation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
meta <- meta[,6:11]
cor_data_Giraddi <- t(matGiraddi)
cor_data_Bach <- t(matBach)
cor_data_Pal <- t(matPal)
cor_data_Saeki <- t(matSaeki)
cor_data_TM <- t(matTM)

remove(matBach, matGiraddi, matPal, matSaeki, matTM)
gc();gc()

### Giraddi
meta_Giraddi <- meta[row.names(meta) %in% row.names(cor_data_Giraddi),]
summary(row.names(meta_Giraddi) == row.names(cor_data_Giraddi))
meta_Giraddi <- meta_Giraddi[row.names(cor_data_Giraddi),]
summary(row.names(meta_Giraddi) == row.names(cor_data_Giraddi))
cor_data_Giraddi <- cbind(meta_Giraddi, cor_data_Giraddi)
cor_data_Giraddi <- as.data.frame(cor_data_Giraddi)

cor_Giraddi_Stem <- cor(cor_data_Giraddi$S5_pseudotime, 
                        cor_data_Giraddi[,7:length(colnames(cor_data_Giraddi))], method="s")
cor_Giraddi_Basal <- cor(cor_data_Giraddi$S4_pseudotime, 
                         cor_data_Giraddi[,7:length(colnames(cor_data_Giraddi))], method="s")
cor_Giraddi_Alv <- cor(cor_data_Giraddi$S2_pseudotime, 
                       cor_data_Giraddi[,7:length(colnames(cor_data_Giraddi))], method="s")
cor_Giraddi_Hor <- cor(cor_data_Giraddi$S1_pseudotime, 
                       cor_data_Giraddi[,7:length(colnames(cor_data_Giraddi))], method="s")
remove(cor_data_Giraddi)
gc();gc()

### Bach
length(colnames(cor_data_Bach))
cor_data_Bach_1 <- cor_data_Bach[,1:9000]
cor_data_Bach_2 <- cor_data_Bach[,9001:18219]
#### Data was split to reduce computational burden
remove(cor_data_Bach)
gc();gc()

#### Bach_1
meta_Bach <- meta[row.names(meta) %in% row.names(cor_data_Bach_1),]
summary(row.names(meta_Bach) == row.names(cor_data_Bach_1))
meta_Bach <- meta_Bach[row.names(cor_data_Bach_1),]
summary(row.names(meta_Bach) == row.names(cor_data_Bach_1))
cor_data_Bach_1 <- cbind(meta_Bach, cor_data_Bach_1)
cor_data_Bach_1 <- as.data.frame(cor_data_Bach_1)

cor_Bach_Stem_1 <- cor(cor_data_Bach_1$S5_pseudotime, 
                       cor_data_Bach_1[,7:length(colnames(cor_data_Bach_1))], method="s")
cor_Bach_Basal_1 <- cor(cor_data_Bach_1$S4_pseudotime, 
                        cor_data_Bach_1[,7:length(colnames(cor_data_Bach_1))], method="s")
cor_Bach_Alv_1 <- cor(cor_data_Bach_1$S2_pseudotime, 
                      cor_data_Bach_1[,7:length(colnames(cor_data_Bach_1))], method="s")
cor_Bach_Hor_1 <- cor(cor_data_Bach_1$S1_pseudotime, 
                      cor_data_Bach_1[,7:length(colnames(cor_data_Bach_1))], method="s")

#### Bach_2
meta_Bach <- meta[row.names(meta) %in% row.names(cor_data_Bach_2),]
summary(row.names(meta_Bach) == row.names(cor_data_Bach_2))
meta_Bach <- meta_Bach[row.names(cor_data_Bach_2),]
summary(row.names(meta_Bach) == row.names(cor_data_Bach_2))
cor_data_Bach_2 <- cbind(meta_Bach, cor_data_Bach_2)
cor_data_Bach_2 <- as.data.frame(cor_data_Bach_2)

cor_Bach_Stem_2 <- cor(cor_data_Bach_2$S5_pseudotime, 
                       cor_data_Bach_2[,7:length(colnames(cor_data_Bach_2))], method="s")
cor_Bach_Basal_2 <- cor(cor_data_Bach_2$S4_pseudotime, 
                        cor_data_Bach_2[,7:length(colnames(cor_data_Bach_2))], method="s")
cor_Bach_Alv_2 <- cor(cor_data_Bach_2$S2_pseudotime, 
                      cor_data_Bach_2[,7:length(colnames(cor_data_Bach_2))], method="s")
cor_Bach_Hor_2 <- cor(cor_data_Bach_2$S1_pseudotime, 
                      cor_data_Bach_2[,7:length(colnames(cor_data_Bach_2))], method="s")

#### Bach_merge
remove(cor_data_Bach_1, cor_data_Bach_2)
gc();gc()

cor_Bach_Stem <- cbind(cor_Bach_Stem_1, cor_Bach_Stem_2) 
cor_Bach_Basal <- cbind(cor_Bach_Basal_1, cor_Bach_Basal_2) 
cor_Bach_Alv <- cbind(cor_Bach_Alv_1, cor_Bach_Alv_2) 
cor_Bach_Hor <- cbind(cor_Bach_Hor_1, cor_Bach_Hor_2) 

remove(cor_Bach_Stem_1, cor_Bach_Stem_2, cor_Bach_Basal_1, cor_Bach_Basal_2, 
       cor_Bach_Alv_1, cor_Bach_Alv_2, cor_Bach_Hor_1, cor_Bach_Hor_2)
gc();gc()

### Pal
meta_Pal <- meta[row.names(meta) %in% row.names(cor_data_Pal),]
summary(row.names(meta_Pal) == row.names(cor_data_Pal))
meta_Pal <- meta_Pal[row.names(cor_data_Pal),]
summary(row.names(meta_Pal) == row.names(cor_data_Pal))
cor_data_Pal <- cbind(meta_Pal, cor_data_Pal)
cor_data_Pal <- as.data.frame(cor_data_Pal)

cor_Pal_Stem <- cor(cor_data_Pal$S5_pseudotime, 
                    cor_data_Pal[,7:length(colnames(cor_data_Pal))], method="s")
cor_Pal_Basal <- cor(cor_data_Pal$S4_pseudotime, 
                     cor_data_Pal[,7:length(colnames(cor_data_Pal))], method="s")
cor_Pal_Alv <- cor(cor_data_Pal$S2_pseudotime, 
                   cor_data_Pal[,7:length(colnames(cor_data_Pal))], method="s")
cor_Pal_Hor <- cor(cor_data_Pal$S1_pseudotime, 
                   cor_data_Pal[,7:length(colnames(cor_data_Pal))], method="s")
remove(cor_data_Pal)
gc();gc()

### Saeki
meta_Saeki <- meta[row.names(meta) %in% row.names(cor_data_Saeki),]
summary(row.names(meta_Saeki) == row.names(cor_data_Saeki))
meta_Saeki <- meta_Saeki[row.names(cor_data_Saeki),]
summary(row.names(meta_Saeki) == row.names(cor_data_Saeki))
cor_data_Saeki <- cbind(meta_Saeki, cor_data_Saeki)
cor_data_Saeki <- as.data.frame(cor_data_Saeki)

cor_Saeki_Stem <- cor(cor_data_Saeki$S5_pseudotime, 
                      cor_data_Saeki[,7:length(colnames(cor_data_Saeki))], method="s")
cor_Saeki_Basal <- cor(cor_data_Saeki$S4_pseudotime, 
                       cor_data_Saeki[,7:length(colnames(cor_data_Saeki))], method="s")
cor_Saeki_Alv <- cor(cor_data_Saeki$S2_pseudotime, 
                     cor_data_Saeki[,7:length(colnames(cor_data_Saeki))], method="s")
cor_Saeki_Hor <- cor(cor_data_Saeki$S1_pseudotime, 
                     cor_data_Saeki[,7:length(colnames(cor_data_Saeki))], method="s")
remove(cor_data_Saeki)
gc();gc()

### TM
meta_TM <- meta[row.names(meta) %in% row.names(cor_data_TM),]
summary(row.names(meta_TM) == row.names(cor_data_TM))
meta_TM <- meta_TM[row.names(cor_data_TM),]
summary(row.names(meta_TM) == row.names(cor_data_TM))
cor_data_TM <- cbind(meta_TM, cor_data_TM)
cor_data_TM <- as.data.frame(cor_data_TM)

cor_TM_Stem <- cor(cor_data_TM$S5_pseudotime, 
                   cor_data_TM[,7:length(colnames(cor_data_TM))], method="s")
cor_TM_Basal <- cor(cor_data_TM$S4_pseudotime, 
                    cor_data_TM[,7:length(colnames(cor_data_TM))], method="s")
cor_TM_Alv <- cor(cor_data_TM$S2_pseudotime, 
                  cor_data_TM[,7:length(colnames(cor_data_TM))], method="s")
cor_TM_Hor <- cor(cor_data_TM$S1_pseudotime, 
                  cor_data_TM[,7:length(colnames(cor_data_TM))], method="s")
remove(cor_data_TM)
gc();gc()


## Generate summary object %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
temp <- list(cor_Giraddi_Stem, cor_Giraddi_Basal, cor_Giraddi_Alv, cor_Giraddi_Hor,
             cor_Pal_Stem, cor_Pal_Basal, cor_Pal_Alv, cor_Pal_Hor,
             cor_Saeki_Stem, cor_Saeki_Basal, cor_Saeki_Alv, cor_Saeki_Hor,
             cor_TM_Stem, cor_TM_Basal, cor_TM_Alv, cor_TM_Hor,
             cor_Bach_Stem, cor_Bach_Basal, cor_Bach_Alv, cor_Bach_Hor)
names(temp)<- c("cor_Giraddi_Stem", "cor_Giraddi_Basal", "cor_Giraddi_Alv", "cor_Giraddi_Hor",
                "cor_Pal_Stem", "cor_Pal_Basal", "cor_Pal_Alv", "cor_Pal_Hor",
                "cor_Saeki_Stem", "cor_Saeki_Basal", "cor_Saeki_Alv", "cor_Saeki_Hor",
                "cor_TM_Stem", "cor_TM_Basal", "cor_TM_Alv", "cor_TM_Hor",
                "cor_Bach_Stem", 'cor_Bach_Basal', "cor_Bach_Alv", "cor_Bach_Hor")

### Stem
cor_Giraddi_Stem <- temp$cor_Giraddi_Stem
cor_Giraddi_Stem <- t(cor_Giraddi_Stem)
colnames(cor_Giraddi_Stem) <- "cor_Giraddi"
cor_Giraddi_Stem <- as.data.frame(cor_Giraddi_Stem)
cor_Giraddi_Stem$gene <- row.names(cor_Giraddi_Stem)

cor_Bach_Stem <- temp$cor_Bach_Stem
cor_Bach_Stem <- t(cor_Bach_Stem)
colnames(cor_Bach_Stem) <- "cor_Bach"
cor_Bach_Stem <- as.data.frame(cor_Bach_Stem)
cor_Bach_Stem$gene <- row.names(cor_Bach_Stem)

cor_Pal_Stem <- temp$cor_Pal_Stem
cor_Pal_Stem <- t(cor_Pal_Stem)
colnames(cor_Pal_Stem) <- "cor_Pal"
cor_Pal_Stem <- as.data.frame(cor_Pal_Stem)
cor_Pal_Stem$gene <- row.names(cor_Pal_Stem)

cor_Saeki_Stem <- temp$cor_Saeki_Stem
cor_Saeki_Stem <- t(cor_Saeki_Stem)
colnames(cor_Saeki_Stem) <- "cor_Saeki"
cor_Saeki_Stem <- as.data.frame(cor_Saeki_Stem)
cor_Saeki_Stem$gene <- row.names(cor_Saeki_Stem)

cor_TM_Stem <- temp$cor_TM_Stem
cor_TM_Stem <- t(cor_TM_Stem)
colnames(cor_TM_Stem) <- "cor_TM"
cor_TM_Stem <- as.data.frame(cor_TM_Stem)
cor_TM_Stem$gene <- row.names(cor_TM_Stem)

cor_Stem <- merge(cor_Giraddi_Stem, cor_Bach_Stem, by.x="gene", by.y = "gene")
cor_Stem <- merge(cor_Stem, cor_Pal_Stem, by.x="gene", by.y = "gene")
cor_Stem <- merge(cor_Stem, cor_Saeki_Stem, by.x="gene", by.y = "gene")
cor_Stem <- merge(cor_Stem, cor_TM_Stem, by.x="gene", by.y = "gene")
row.names(cor_Stem) <- cor_Stem$gene
cor_Stem <- cor_Stem[,2:6]
mean <- apply(cor_Stem, 1, mean)
rank <- rank(mean)
mean.inv <- -1*mean
rank.inv <- rank(mean.inv)
cor_Stem <- cbind(cor_Stem, mean, rank, mean.inv, rank.inv)

### Basal
cor_Giraddi_Basal <- temp$cor_Giraddi_Basal
cor_Giraddi_Basal <- t(cor_Giraddi_Basal)
colnames(cor_Giraddi_Basal) <- "cor_Giraddi"
cor_Giraddi_Basal <- as.data.frame(cor_Giraddi_Basal)
cor_Giraddi_Basal$gene <- row.names(cor_Giraddi_Basal)

cor_Bach_Basal <- temp$cor_Bach_Basal
cor_Bach_Basal <- t(cor_Bach_Basal)
colnames(cor_Bach_Basal) <- "cor_Bach"
cor_Bach_Basal <- as.data.frame(cor_Bach_Basal)
cor_Bach_Basal$gene <- row.names(cor_Bach_Basal)

cor_Pal_Basal <- temp$cor_Pal_Basal
cor_Pal_Basal <- t(cor_Pal_Basal)
colnames(cor_Pal_Basal) <- "cor_Pal"
cor_Pal_Basal <- as.data.frame(cor_Pal_Basal)
cor_Pal_Basal$gene <- row.names(cor_Pal_Basal)

cor_Saeki_Basal <- temp$cor_Saeki_Basal
cor_Saeki_Basal <- t(cor_Saeki_Basal)
colnames(cor_Saeki_Basal) <- "cor_Saeki"
cor_Saeki_Basal <- as.data.frame(cor_Saeki_Basal)
cor_Saeki_Basal$gene <- row.names(cor_Saeki_Basal)

cor_TM_Basal <- temp$cor_TM_Basal
cor_TM_Basal <- t(cor_TM_Basal)
colnames(cor_TM_Basal) <- "cor_TM"
cor_TM_Basal <- as.data.frame(cor_TM_Basal)
cor_TM_Basal$gene <- row.names(cor_TM_Basal)

cor_Basal <- merge(cor_Giraddi_Basal, cor_Bach_Basal, by.x="gene", by.y = "gene")
cor_Basal <- merge(cor_Basal, cor_Pal_Basal, by.x="gene", by.y = "gene")
cor_Basal <- merge(cor_Basal, cor_Saeki_Basal, by.x="gene", by.y = "gene")
cor_Basal <- merge(cor_Basal, cor_TM_Basal, by.x="gene", by.y = "gene")
row.names(cor_Basal) <- cor_Basal$gene
cor_Basal <- cor_Basal[,2:6]
mean <- apply(cor_Basal, 1, mean)
rank <- rank(mean)
mean.inv <- -1*mean
rank.inv <- rank(mean.inv)
cor_Basal <- cbind(cor_Basal, mean, rank, mean.inv, rank.inv)

### Alv
cor_Giraddi_Alv <- temp$cor_Giraddi_Alv
cor_Giraddi_Alv <- t(cor_Giraddi_Alv)
colnames(cor_Giraddi_Alv) <- "cor_Giraddi"
cor_Giraddi_Alv <- as.data.frame(cor_Giraddi_Alv)
cor_Giraddi_Alv$gene <- row.names(cor_Giraddi_Alv)

cor_Bach_Alv <- temp$cor_Bach_Alv
cor_Bach_Alv <- t(cor_Bach_Alv)
colnames(cor_Bach_Alv) <- "cor_Bach"
cor_Bach_Alv <- as.data.frame(cor_Bach_Alv)
cor_Bach_Alv$gene <- row.names(cor_Bach_Alv)

cor_Pal_Alv <- temp$cor_Pal_Alv
cor_Pal_Alv <- t(cor_Pal_Alv)
colnames(cor_Pal_Alv) <- "cor_Pal"
cor_Pal_Alv <- as.data.frame(cor_Pal_Alv)
cor_Pal_Alv$gene <- row.names(cor_Pal_Alv)

cor_Saeki_Alv <- temp$cor_Saeki_Alv
cor_Saeki_Alv <- t(cor_Saeki_Alv)
colnames(cor_Saeki_Alv) <- "cor_Saeki"
cor_Saeki_Alv <- as.data.frame(cor_Saeki_Alv)
cor_Saeki_Alv$gene <- row.names(cor_Saeki_Alv)

cor_TM_Alv <- temp$cor_TM_Alv
cor_TM_Alv <- t(cor_TM_Alv)
colnames(cor_TM_Alv) <- "cor_TM"
cor_TM_Alv <- as.data.frame(cor_TM_Alv)
cor_TM_Alv$gene <- row.names(cor_TM_Alv)

cor_Alv <- merge(cor_Giraddi_Alv, cor_Bach_Alv, by.x="gene", by.y = "gene")
cor_Alv <- merge(cor_Alv, cor_Pal_Alv, by.x="gene", by.y = "gene")
cor_Alv <- merge(cor_Alv, cor_Saeki_Alv, by.x="gene", by.y = "gene")
cor_Alv <- merge(cor_Alv, cor_TM_Alv, by.x="gene", by.y = "gene")
row.names(cor_Alv) <- cor_Alv$gene
cor_Alv <- cor_Alv[,2:6]
mean <- apply(cor_Alv, 1, mean)
rank <- rank(mean)
mean.inv <- -1*mean
rank.inv <- rank(mean.inv)
cor_Alv <- cbind(cor_Alv, mean, rank, mean.inv, rank.inv)

### Hor
cor_Giraddi_Hor <- temp$cor_Giraddi_Hor
cor_Giraddi_Hor <- t(cor_Giraddi_Hor)
colnames(cor_Giraddi_Hor) <- "cor_Giraddi"
cor_Giraddi_Hor <- as.data.frame(cor_Giraddi_Hor)
cor_Giraddi_Hor$gene <- row.names(cor_Giraddi_Hor)

cor_Bach_Hor <- temp$cor_Bach_Hor
cor_Bach_Hor <- t(cor_Bach_Hor)
colnames(cor_Bach_Hor) <- "cor_Bach"
cor_Bach_Hor <- as.data.frame(cor_Bach_Hor)
cor_Bach_Hor$gene <- row.names(cor_Bach_Hor)

cor_Pal_Hor <- temp$cor_Pal_Hor
cor_Pal_Hor <- t(cor_Pal_Hor)
colnames(cor_Pal_Hor) <- "cor_Pal"
cor_Pal_Hor <- as.data.frame(cor_Pal_Hor)
cor_Pal_Hor$gene <- row.names(cor_Pal_Hor)

cor_Saeki_Hor <- temp$cor_Saeki_Hor
cor_Saeki_Hor <- t(cor_Saeki_Hor)
colnames(cor_Saeki_Hor) <- "cor_Saeki"
cor_Saeki_Hor <- as.data.frame(cor_Saeki_Hor)
cor_Saeki_Hor$gene <- row.names(cor_Saeki_Hor)

cor_TM_Hor <- temp$cor_TM_Hor
cor_TM_Hor <- t(cor_TM_Hor)
colnames(cor_TM_Hor) <- "cor_TM"
cor_TM_Hor <- as.data.frame(cor_TM_Hor)
cor_TM_Hor$gene <- row.names(cor_TM_Hor)

cor_Hor <- merge(cor_Giraddi_Hor, cor_Bach_Hor, by.x="gene", by.y = "gene")
cor_Hor <- merge(cor_Hor, cor_Pal_Hor, by.x="gene", by.y = "gene")
cor_Hor <- merge(cor_Hor, cor_Saeki_Hor, by.x="gene", by.y = "gene")
cor_Hor <- merge(cor_Hor, cor_TM_Hor, by.x="gene", by.y = "gene")
row.names(cor_Hor) <- cor_Hor$gene
cor_Hor <- cor_Hor[,2:6]
mean <- apply(cor_Hor, 1, mean)
rank <- rank(mean)
mean.inv <- -1*mean
rank.inv <- rank(mean.inv)
cor_Hor <- cbind(cor_Hor, mean, rank, mean.inv, rank.inv)

## Data saving
write.csv(cor_Stem, "...zenodo/GSVA/Mouse/cor_Stem.csv")
write.csv(cor_Alv, "...zenodo/GSVA/Mouse/cor_Alv.csv")
write.csv(cor_Basal, "...zenodo/GSVA/Mouse/cor_Basal.csv")
write.csv(cor_Hor, "...zenodo/GSVA/Mouse/cor_Hor.csv")


##########################################################################
############# Top gene lists #############################################
##########################################################################
cor_Stem <- read.csv("...zenodo/GSVA/Mouse/cor_Stem.csv")
cor_Alv <- read.csv("...zenodo/GSVA/Mouse/cor_Stem.csv")
cor_Basal <- read.csv("...zenodo/GSVA/Mouse/cor_Stem.csv")
cor_Hor <-  read.csv("...zenodo/GSVA/Mouse/cor_Stem.csv")

## Top 100
### Stem
colnames(cor_Stem)[1] <- "gene"
cor_Stem <- cor_Stem %>% arrange(rank)
hoge <- list()
for(i in 1:100){
  y <- list(as.character(cor_Stem$gene[1:i]))
  names(y) <- paste("Top_Stem", i, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Stem_cor_genes_top100.rds")

### Basal
colnames(cor_Basal)[1] <- "gene"
cor_Basal <- cor_Basal %>% arrange(rank)
hoge <- list()
for(i in 1:100){
  y <- list(as.character(cor_Basal$gene[1:i]))
  names(y) <- paste("Top_Basal", i, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Basal_cor_genes_top100.rds")

### Alv
colnames(cor_Alv)[1] <- "gene"
cor_Alv <- cor_Alv %>% arrange(rank)
hoge <- list()
for(i in 1:100){
  y <- list(as.character(cor_Alv$gene[1:i]))
  names(y) <- paste("Top_Alv", i, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Alv_cor_genes_top100.rds")

### Hor
colnames(cor_Hor)[1] <- "gene"
cor_Hor <- cor_Hor %>% arrange(rank)
hoge <- list()
for(i in 1:100){
  y <- list(as.character(cor_Hor$gene[1:i]))
  names(y) <- paste("Top_Hor", i, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Hor_cor_genes_top100.rds")

## Top1000
### Stem
colnames(cor_Stem)[1] <- "gene"
cor_Stem <- cor_Stem %>% arrange(rank)
hoge <- list()
for(i in 1:45){
  x <- 100+20*i
  y <- list(as.character(cor_Stem$gene[1:x]))
  names(y) <- paste("Top_Stem", x, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Stem_cor_genes_top1000.rds")

### Basal
colnames(cor_Basal)[1] <- "gene"
cor_Basal <- cor_Basal %>% arrange(rank)
hoge <- list()
for(i in 1:45){
  x <- 100+20*i
  y <- list(as.character(cor_Basal$gene[1:x]))
  names(y) <- paste("Top_Basal", x, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Basal_cor_genes_top1000.rds")

### Alv
colnames(cor_Alv)[1] <- "gene"
cor_Alv <- cor_Alv %>% arrange(rank)
hoge <- list()
for(i in 1:45){
  x <- 100+20*i
  y <- list(as.character(cor_Alv$gene[1:x]))
  names(y) <- paste("Top_Alv", x, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Alv_cor_genes_top1000.rds")

### Hor
colnames(cor_Hor)[1] <- "gene"
cor_Hor <- cor_Hor %>% arrange(rank)
hoge <- list()
for(i in 1:45){
  x <- 100+20*i
  y <- list(as.character(cor_Hor$gene[1:x]))
  names(y) <- paste("Top_Hor", x, sep = "_")
  hoge <- c(hoge, y)
}
saveRDS(hoge, "...zenodo/GSVA/Mouse/Hor_cor_genes_top1000.rds")



##########################################################################
############ GSVA analysis for gene list performance evaluation (top100)##
##########################################################################
## Data_prep
Bach <- readRDS("...zenodo/Mouse_normal_breast_data/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...zenodo/Mouse_normal_breast_data/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...zenodo/Mouse_normal_breast_data/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...zenodo/Mouse_normal_breast_data/Pal/Pal_cleaned.rds")
TM <- readRDS("...zenodo/Mouse_normal_breast_data/TabulaMuris/TabulaMuris_cleaned.rds")

meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)
Cell_barcodes <- readRDS("...zenodo/GSVA/Mouse/Sampled_barcodes.rds")

###
Giraddi <- NormalizeData(Giraddi)
Giraddi <- ScaleData(Giraddi, features=rownames(Giraddi))
matGiraddi <- Giraddi@assays$RNA@scale.data
matGiraddi <- matGiraddi[,colnames(matGiraddi) %in% Cell_barcodes$Giraddi]

Bach <- NormalizeData(Bach)
Bach <- ScaleData(Bach, features=rownames(Bach))
matBach <- Bach@assays$RNA@scale.data
matBach <- matBach[,colnames(matBach) %in% Cell_barcodes$Bach]

Pal <- NormalizeData(Pal)
Pal <- ScaleData(Pal, features=rownames(Pal))
matPal <- Pal@assays$RNA@scale.data
matPal <- matPal[,colnames(matPal) %in% Cell_barcodes$Pal]

Saeki <- NormalizeData(Saeki)
Saeki <- ScaleData(Saeki, features=rownames(Saeki))
matSaeki <- Saeki@assays$RNA@scale.data
matSaeki <- matSaeki[,colnames(matSaeki) %in% Cell_barcodes$Saeki]

TM <- NormalizeData(TM)
TM <- ScaleData(TM, features=rownames(TM))
matTM <- TM@assays$RNA@scale.data
colnames(matTM) <- gsub("TM_Adu1_", "", colnames(matTM))
colnames(matTM) <- gsub("TM_Adu2_", "", colnames(matTM))

###
meta_Giraddi <- meta[colnames(matGiraddi),]
meta_Bach <- meta[colnames(matBach),]
meta_Pal <- meta[colnames(matPal),]
meta_Saeki <- meta[colnames(matSaeki),]
meta_TM <- meta[colnames(matTM),]

remove(Bach, Pal, Giraddi, Saeki, TM, Cell_barcodes)
gc();gc()


## GSVA
# Stem
Stem_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Stem_cor_genes_top100.rds")
#
Giraddi_gsvaResult_Stem <- gsva(matGiraddi, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Stem_100.csv")
Giraddi_gsvaResult_Stem <- t(Giraddi_gsvaResult_Stem)
Giraddi_gsvaResult_Stem <- cbind(meta_Giraddi$S5_pseudotime, Giraddi_gsvaResult_Stem)
cor_Giraddi_GSVA_Stem <- cor(Giraddi_gsvaResult_Stem[,1], Giraddi_gsvaResult_Stem[,2:101], method="s")
cor_GSVA_Stem <- NULL
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Giraddi_GSVA_Stem)
#
Bach_gsvaResult_Stem <- gsva(matBach, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Bach_GSVA_Stem_100.csv")
Bach_gsvaResult_Stem <- t(Bach_gsvaResult_Stem)
Bach_gsvaResult_Stem <- cbind(meta_Bach$S5_pseudotime, Bach_gsvaResult_Stem)
cor_Bach_GSVA_Stem <- cor(Bach_gsvaResult_Stem[,1], Bach_gsvaResult_Stem[,2:101], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Bach_GSVA_Stem)
#
Pal_gsvaResult_Stem <- gsva(matPal, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Pal_GSVA_Stem_100.csv")
Pal_gsvaResult_Stem <- t(Pal_gsvaResult_Stem)
Pal_gsvaResult_Stem <- cbind(meta_Pal$S5_pseudotime, Pal_gsvaResult_Stem)
cor_Pal_GSVA_Stem <- cor(Pal_gsvaResult_Stem[,1], Pal_gsvaResult_Stem[,2:101], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Pal_GSVA_Stem)
#
Saeki_gsvaResult_Stem <- gsva(matSaeki, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Saeki_GSVA_Stem_100.csv")
Saeki_gsvaResult_Stem <- t(Saeki_gsvaResult_Stem)
Saeki_gsvaResult_Stem <- cbind(meta_Saeki$S5_pseudotime, Saeki_gsvaResult_Stem)
cor_Saeki_GSVA_Stem <- cor(Saeki_gsvaResult_Stem[,1], Saeki_gsvaResult_Stem[,2:101], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Saeki_GSVA_Stem)
#
TM_gsvaResult_Stem <- gsva(matTM, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Stem, "...zenodo/GSVA/Mouse/TM_GSVA_Stem_100.csv")
TM_gsvaResult_Stem <- t(TM_gsvaResult_Stem)
TM_gsvaResult_Stem <- cbind(meta_TM$S5_pseudotime, TM_gsvaResult_Stem)
cor_TM_GSVA_Stem <- cor(TM_gsvaResult_Stem[,1], TM_gsvaResult_Stem[,2:101], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_TM_GSVA_Stem)


# Basal
Basal_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Basal_cor_genes_top100.rds")
#
Giraddi_gsvaResult_Basal <- gsva(matGiraddi, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Basal_100.csv")
Giraddi_gsvaResult_Basal <- t(Giraddi_gsvaResult_Basal)
Giraddi_gsvaResult_Basal <- cbind(meta_Giraddi$S4_pseudotime, Giraddi_gsvaResult_Basal)
cor_Giraddi_GSVA_Basal <- cor(Giraddi_gsvaResult_Basal[,1], Giraddi_gsvaResult_Basal[,2:101], method="s")
cor_GSVA_Basal <- NULL
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Giraddi_GSVA_Basal)
#
Bach_gsvaResult_Basal <- gsva(matBach, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Bach_GSVA_Basal_100.csv")
Bach_gsvaResult_Basal <- t(Bach_gsvaResult_Basal)
Bach_gsvaResult_Basal <- cbind(meta_Bach$S4_pseudotime, Bach_gsvaResult_Basal)
cor_Bach_GSVA_Basal <- cor(Bach_gsvaResult_Basal[,1], Bach_gsvaResult_Basal[,2:101], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Bach_GSVA_Basal)
#
Pal_gsvaResult_Basal <- gsva(matPal, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Pal_GSVA_Basal_100.csv")
Pal_gsvaResult_Basal <- t(Pal_gsvaResult_Basal)
Pal_gsvaResult_Basal <- cbind(meta_Pal$S4_pseudotime, Pal_gsvaResult_Basal)
cor_Pal_GSVA_Basal <- cor(Pal_gsvaResult_Basal[,1], Pal_gsvaResult_Basal[,2:101], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Pal_GSVA_Basal)
#
Saeki_gsvaResult_Basal <- gsva(matSaeki, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Saeki_GSVA_Basal_100.csv")
Saeki_gsvaResult_Basal <- t(Saeki_gsvaResult_Basal)
Saeki_gsvaResult_Basal <- cbind(meta_Saeki$S4_pseudotime, Saeki_gsvaResult_Basal)
cor_Saeki_GSVA_Basal <- cor(Saeki_gsvaResult_Basal[,1], Saeki_gsvaResult_Basal[,2:101], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Saeki_GSVA_Basal)
#
TM_gsvaResult_Basal <- gsva(matTM, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Basal, "...zenodo/GSVA/Mouse/TM_GSVA_Basal_100.csv")
TM_gsvaResult_Basal <- t(TM_gsvaResult_Basal)
TM_gsvaResult_Basal <- cbind(meta_TM$S4_pseudotime, TM_gsvaResult_Basal)
cor_TM_GSVA_Basal <- cor(TM_gsvaResult_Basal[,1], TM_gsvaResult_Basal[,2:101], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_TM_GSVA_Basal)

# Alv
Alv_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Alv_cor_genes_top100.rds")
#
Giraddi_gsvaResult_Alv <- gsva(matGiraddi, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Alv_100.csv")
Giraddi_gsvaResult_Alv <- t(Giraddi_gsvaResult_Alv)
Giraddi_gsvaResult_Alv <- cbind(meta_Giraddi$S2_pseudotime, Giraddi_gsvaResult_Alv)
cor_Giraddi_GSVA_Alv <- cor(Giraddi_gsvaResult_Alv[,1], Giraddi_gsvaResult_Alv[,2:101], method="s")
cor_GSVA_Alv <- NULL
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Giraddi_GSVA_Alv)
#
Bach_gsvaResult_Alv <- gsva(matBach, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Bach_GSVA_Alv_100.csv")
Bach_gsvaResult_Alv <- t(Bach_gsvaResult_Alv)
Bach_gsvaResult_Alv <- cbind(meta_Bach$S2_pseudotime, Bach_gsvaResult_Alv)
cor_Bach_GSVA_Alv <- cor(Bach_gsvaResult_Alv[,1], Bach_gsvaResult_Alv[,2:101], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Bach_GSVA_Alv)
#
Pal_gsvaResult_Alv <- gsva(matPal, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Pal_GSVA_Alv_100.csv")
Pal_gsvaResult_Alv <- t(Pal_gsvaResult_Alv)
Pal_gsvaResult_Alv <- cbind(meta_Pal$S2_pseudotime, Pal_gsvaResult_Alv)
cor_Pal_GSVA_Alv <- cor(Pal_gsvaResult_Alv[,1], Pal_gsvaResult_Alv[,2:101], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Pal_GSVA_Alv)
#
Saeki_gsvaResult_Alv <- gsva(matSaeki, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Saeki_GSVA_Alv_100.csv")
Saeki_gsvaResult_Alv <- t(Saeki_gsvaResult_Alv)
Saeki_gsvaResult_Alv <- cbind(meta_Saeki$S2_pseudotime, Saeki_gsvaResult_Alv)
cor_Saeki_GSVA_Alv <- cor(Saeki_gsvaResult_Alv[,1], Saeki_gsvaResult_Alv[,2:101], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Saeki_GSVA_Alv)
#
TM_gsvaResult_Alv <- gsva(matTM, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Alv, "...zenodo/GSVA/Mouse/TM_GSVA_Alv_100.csv")
TM_gsvaResult_Alv <- t(TM_gsvaResult_Alv)
TM_gsvaResult_Alv <- cbind(meta_TM$S2_pseudotime, TM_gsvaResult_Alv)
cor_TM_GSVA_Alv <- cor(TM_gsvaResult_Alv[,1], TM_gsvaResult_Alv[,2:101], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_TM_GSVA_Alv)


# Hor
Hor_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Hor_cor_genes_top100.rds")
#
Giraddi_gsvaResult_Hor <- gsva(matGiraddi, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Hor_100.csv")
Giraddi_gsvaResult_Hor <- t(Giraddi_gsvaResult_Hor)
Giraddi_gsvaResult_Hor <- cbind(meta_Giraddi$S1_pseudotime, Giraddi_gsvaResult_Hor)
cor_Giraddi_GSVA_Hor <- cor(Giraddi_gsvaResult_Hor[,1], Giraddi_gsvaResult_Hor[,2:101], method="s")
cor_GSVA_Hor <- NULL
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Giraddi_GSVA_Hor)
#
Bach_gsvaResult_Hor <- gsva(matBach, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Bach_GSVA_Hor_100.csv")
Bach_gsvaResult_Hor <- t(Bach_gsvaResult_Hor)
Bach_gsvaResult_Hor <- cbind(meta_Bach$S1_pseudotime, Bach_gsvaResult_Hor)
cor_Bach_GSVA_Hor <- cor(Bach_gsvaResult_Hor[,1], Bach_gsvaResult_Hor[,2:101], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Bach_GSVA_Hor)
#
Pal_gsvaResult_Hor <- gsva(matPal, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Pal_GSVA_Hor_100.csv")
Pal_gsvaResult_Hor <- t(Pal_gsvaResult_Hor)
Pal_gsvaResult_Hor <- cbind(meta_Pal$S1_pseudotime, Pal_gsvaResult_Hor)
cor_Pal_GSVA_Hor <- cor(Pal_gsvaResult_Hor[,1], Pal_gsvaResult_Hor[,2:101], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Pal_GSVA_Hor)
#
Saeki_gsvaResult_Hor <- gsva(matSaeki, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Saeki_GSVA_Hor_100.csv")
Saeki_gsvaResult_Hor <- t(Saeki_gsvaResult_Hor)
Saeki_gsvaResult_Hor <- cbind(meta_Saeki$S1_pseudotime, Saeki_gsvaResult_Hor)
cor_Saeki_GSVA_Hor <- cor(Saeki_gsvaResult_Hor[,1], Saeki_gsvaResult_Hor[,2:101], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Saeki_GSVA_Hor)
#
TM_gsvaResult_Hor <- gsva(matTM, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Hor, "...zenodo/GSVA/Mouse/TM_GSVA_Hor_100.csv")
TM_gsvaResult_Hor <- t(TM_gsvaResult_Hor)
TM_gsvaResult_Hor <- cbind(meta_TM$S1_pseudotime, TM_gsvaResult_Hor)
cor_TM_GSVA_Hor <- cor(TM_gsvaResult_Hor[,1], TM_gsvaResult_Hor[,2:101], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_TM_GSVA_Hor)

rownames(cor_GSVA_Stem) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Stem, "...zenodo/GSVA/Mouse/cor_GSVA_Stem.csv")
rownames(cor_GSVA_Basal) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Basal, "...zenodo/GSVA/Mouse/cor_GSVA_Basal.csv")
rownames(cor_GSVA_Alv) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Alv, "...zenodo/GSVA/Mouse/cor_GSVA_Alv.csv")
rownames(cor_GSVA_Hor) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Hor, "...zenodo/GSVA/Mouse/cor_GSVA_Hor.csv")



##########################################################################
######## GSVA analysis for gene list performance evaluation (top1000) ####
##########################################################################
# Stem
Stem_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Stem_cor_genes_top1000.rds")
#
Giraddi_gsvaResult_Stem <- gsva(matGiraddi, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Stem_1000.csv")
Giraddi_gsvaResult_Stem <- t(Giraddi_gsvaResult_Stem)
Giraddi_gsvaResult_Stem <- cbind(meta_Giraddi$S5_pseudotime, Giraddi_gsvaResult_Stem)
cor_Giraddi_GSVA_Stem <- cor(Giraddi_gsvaResult_Stem[,1], Giraddi_gsvaResult_Stem[,2:46], method="s")
cor_GSVA_Stem <- NULL
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Giraddi_GSVA_Stem)
#
Bach_gsvaResult_Stem <- gsva(matBach, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Bach_GSVA_Stem_1000.csv")
Bach_gsvaResult_Stem <- t(Bach_gsvaResult_Stem)
Bach_gsvaResult_Stem <- cbind(meta_Bach$S5_pseudotime, Bach_gsvaResult_Stem)
cor_Bach_GSVA_Stem <- cor(Bach_gsvaResult_Stem[,1], Bach_gsvaResult_Stem[,2:46], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Bach_GSVA_Stem)
#
Pal_gsvaResult_Stem <- gsva(matPal, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Pal_GSVA_Stem_1000.csv")
Pal_gsvaResult_Stem <- t(Pal_gsvaResult_Stem)
Pal_gsvaResult_Stem <- cbind(meta_Pal$S5_pseudotime, Pal_gsvaResult_Stem)
cor_Pal_GSVA_Stem <- cor(Pal_gsvaResult_Stem[,1], Pal_gsvaResult_Stem[,2:46], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Pal_GSVA_Stem)
#
Saeki_gsvaResult_Stem <- gsva(matSaeki, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Stem, "...zenodo/GSVA/Mouse/Saeki_GSVA_Stem_1000.csv")
Saeki_gsvaResult_Stem <- t(Saeki_gsvaResult_Stem)
Saeki_gsvaResult_Stem <- cbind(meta_Saeki$S5_pseudotime, Saeki_gsvaResult_Stem)
cor_Saeki_GSVA_Stem <- cor(Saeki_gsvaResult_Stem[,1], Saeki_gsvaResult_Stem[,2:46], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_Saeki_GSVA_Stem)
#
TM_gsvaResult_Stem <- gsva(matTM, Stem_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Stem, "...zenodo/GSVA/Mouse/TM_GSVA_Stem_1000.csv")
TM_gsvaResult_Stem <- t(TM_gsvaResult_Stem)
TM_gsvaResult_Stem <- cbind(meta_TM$S5_pseudotime, TM_gsvaResult_Stem)
cor_TM_GSVA_Stem <- cor(TM_gsvaResult_Stem[,1], TM_gsvaResult_Stem[,2:46], method="s")
cor_GSVA_Stem <- rbind(cor_GSVA_Stem, cor_TM_GSVA_Stem)


# Basal
Basal_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Basal_cor_genes_top1000.rds")
#
Giraddi_gsvaResult_Basal <- gsva(matGiraddi, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Basal_1000.csv")
Giraddi_gsvaResult_Basal <- t(Giraddi_gsvaResult_Basal)
Giraddi_gsvaResult_Basal <- cbind(meta_Giraddi$S4_pseudotime, Giraddi_gsvaResult_Basal)
cor_Giraddi_GSVA_Basal <- cor(Giraddi_gsvaResult_Basal[,1], Giraddi_gsvaResult_Basal[,2:46], method="s")
cor_GSVA_Basal <- NULL
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Giraddi_GSVA_Basal)
#
Bach_gsvaResult_Basal <- gsva(matBach, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Bach_GSVA_Basal_1000.csv")
Bach_gsvaResult_Basal <- t(Bach_gsvaResult_Basal)
Bach_gsvaResult_Basal <- cbind(meta_Bach$S4_pseudotime, Bach_gsvaResult_Basal)
cor_Bach_GSVA_Basal <- cor(Bach_gsvaResult_Basal[,1], Bach_gsvaResult_Basal[,2:46], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Bach_GSVA_Basal)
#
Pal_gsvaResult_Basal <- gsva(matPal, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Pal_GSVA_Basal_1000.csv")
Pal_gsvaResult_Basal <- t(Pal_gsvaResult_Basal)
Pal_gsvaResult_Basal <- cbind(meta_Pal$S4_pseudotime, Pal_gsvaResult_Basal)
cor_Pal_GSVA_Basal <- cor(Pal_gsvaResult_Basal[,1], Pal_gsvaResult_Basal[,2:46], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Pal_GSVA_Basal)
#
Saeki_gsvaResult_Basal <- gsva(matSaeki, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Basal, "...zenodo/GSVA/Mouse/Saeki_GSVA_Basal_1000.csv")
Saeki_gsvaResult_Basal <- t(Saeki_gsvaResult_Basal)
Saeki_gsvaResult_Basal <- cbind(meta_Saeki$S4_pseudotime, Saeki_gsvaResult_Basal)
cor_Saeki_GSVA_Basal <- cor(Saeki_gsvaResult_Basal[,1], Saeki_gsvaResult_Basal[,2:46], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_Saeki_GSVA_Basal)
#
TM_gsvaResult_Basal <- gsva(matTM, Basal_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Basal, "...zenodo/GSVA/Mouse/TM_GSVA_Basal_1000.csv")
TM_gsvaResult_Basal <- t(TM_gsvaResult_Basal)
TM_gsvaResult_Basal <- cbind(meta_TM$S4_pseudotime, TM_gsvaResult_Basal)
cor_TM_GSVA_Basal <- cor(TM_gsvaResult_Basal[,1], TM_gsvaResult_Basal[,2:46], method="s")
cor_GSVA_Basal <- rbind(cor_GSVA_Basal, cor_TM_GSVA_Basal)

# Alv
Alv_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Alv_cor_genes_top1000.rds")
#
Giraddi_gsvaResult_Alv <- gsva(matGiraddi, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Alv_1000.csv")
Giraddi_gsvaResult_Alv <- t(Giraddi_gsvaResult_Alv)
Giraddi_gsvaResult_Alv <- cbind(meta_Giraddi$S2_pseudotime, Giraddi_gsvaResult_Alv)
cor_Giraddi_GSVA_Alv <- cor(Giraddi_gsvaResult_Alv[,1], Giraddi_gsvaResult_Alv[,2:46], method="s")
cor_GSVA_Alv <- NULL
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Giraddi_GSVA_Alv)
#
Bach_gsvaResult_Alv <- gsva(matBach, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Bach_GSVA_Alv_1000.csv")
Bach_gsvaResult_Alv <- t(Bach_gsvaResult_Alv)
Bach_gsvaResult_Alv <- cbind(meta_Bach$S2_pseudotime, Bach_gsvaResult_Alv)
cor_Bach_GSVA_Alv <- cor(Bach_gsvaResult_Alv[,1], Bach_gsvaResult_Alv[,2:46], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Bach_GSVA_Alv)
#
Pal_gsvaResult_Alv <- gsva(matPal, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Pal_GSVA_Alv_1000.csv")
Pal_gsvaResult_Alv <- t(Pal_gsvaResult_Alv)
Pal_gsvaResult_Alv <- cbind(meta_Pal$S2_pseudotime, Pal_gsvaResult_Alv)
cor_Pal_GSVA_Alv <- cor(Pal_gsvaResult_Alv[,1], Pal_gsvaResult_Alv[,2:46], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Pal_GSVA_Alv)
#
Saeki_gsvaResult_Alv <- gsva(matSaeki, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Alv, "...zenodo/GSVA/Mouse/Saeki_GSVA_Alv_1000.csv")
Saeki_gsvaResult_Alv <- t(Saeki_gsvaResult_Alv)
Saeki_gsvaResult_Alv <- cbind(meta_Saeki$S2_pseudotime, Saeki_gsvaResult_Alv)
cor_Saeki_GSVA_Alv <- cor(Saeki_gsvaResult_Alv[,1], Saeki_gsvaResult_Alv[,2:46], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_Saeki_GSVA_Alv)
#
TM_gsvaResult_Alv <- gsva(matTM, Alv_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Alv, "...zenodo/GSVA/Mouse/TM_GSVA_Alv_1000.csv")
TM_gsvaResult_Alv <- t(TM_gsvaResult_Alv)
TM_gsvaResult_Alv <- cbind(meta_TM$S2_pseudotime, TM_gsvaResult_Alv)
cor_TM_GSVA_Alv <- cor(TM_gsvaResult_Alv[,1], TM_gsvaResult_Alv[,2:46], method="s")
cor_GSVA_Alv <- rbind(cor_GSVA_Alv, cor_TM_GSVA_Alv)


# Hor
Hor_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Hor_cor_genes_top1000.rds")
#
Giraddi_gsvaResult_Hor <- gsva(matGiraddi, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Giraddi_GSVA_Hor_1000.csv")
Giraddi_gsvaResult_Hor <- t(Giraddi_gsvaResult_Hor)
Giraddi_gsvaResult_Hor <- cbind(meta_Giraddi$S1_pseudotime, Giraddi_gsvaResult_Hor)
cor_Giraddi_GSVA_Hor <- cor(Giraddi_gsvaResult_Hor[,1], Giraddi_gsvaResult_Hor[,2:46], method="s")
cor_GSVA_Hor <- NULL
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Giraddi_GSVA_Hor)
#
Bach_gsvaResult_Hor <- gsva(matBach, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Bach_GSVA_Hor_1000.csv")
Bach_gsvaResult_Hor <- t(Bach_gsvaResult_Hor)
Bach_gsvaResult_Hor <- cbind(meta_Bach$S1_pseudotime, Bach_gsvaResult_Hor)
cor_Bach_GSVA_Hor <- cor(Bach_gsvaResult_Hor[,1], Bach_gsvaResult_Hor[,2:46], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Bach_GSVA_Hor)
#
Pal_gsvaResult_Hor <- gsva(matPal, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Pal_GSVA_Hor_1000.csv")
Pal_gsvaResult_Hor <- t(Pal_gsvaResult_Hor)
Pal_gsvaResult_Hor <- cbind(meta_Pal$S1_pseudotime, Pal_gsvaResult_Hor)
cor_Pal_GSVA_Hor <- cor(Pal_gsvaResult_Hor[,1], Pal_gsvaResult_Hor[,2:46], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Pal_GSVA_Hor)
#
Saeki_gsvaResult_Hor <- gsva(matSaeki, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult_Hor, "...zenodo/GSVA/Mouse/Saeki_GSVA_Hor_1000.csv")
Saeki_gsvaResult_Hor <- t(Saeki_gsvaResult_Hor)
Saeki_gsvaResult_Hor <- cbind(meta_Saeki$S1_pseudotime, Saeki_gsvaResult_Hor)
cor_Saeki_GSVA_Hor <- cor(Saeki_gsvaResult_Hor[,1], Saeki_gsvaResult_Hor[,2:46], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_Saeki_GSVA_Hor)
#
TM_gsvaResult_Hor <- gsva(matTM, Hor_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult_Hor, "...zenodo/GSVA/Mouse/TM_GSVA_Hor_1000.csv")
TM_gsvaResult_Hor <- t(TM_gsvaResult_Hor)
TM_gsvaResult_Hor <- cbind(meta_TM$S1_pseudotime, TM_gsvaResult_Hor)
cor_TM_GSVA_Hor <- cor(TM_gsvaResult_Hor[,1], TM_gsvaResult_Hor[,2:46], method="s")
cor_GSVA_Hor <- rbind(cor_GSVA_Hor, cor_TM_GSVA_Hor)

###
rownames(cor_GSVA_Stem) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Stem, "...zenodo/GSVA/Mouse/cor_GSVA_Stem_1000.csv")
rownames(cor_GSVA_Basal) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Basal, "...zenodo/GSVA/Mouse/cor_GSVA_Basal_1000.csv")
rownames(cor_GSVA_Alv) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Alv, "...zenodo/GSVA/Mouse/cor_GSVA_Alv_1000.csv")
rownames(cor_GSVA_Hor) <- c("Giraddi", "Bach", "Pal", "Saeki", "TM")
write.csv(cor_GSVA_Hor, "...zenodo/GSVA/Mouse/cor_GSVA_Hor_1000.csv")



##########################################################################
############ GSVA analysis for gene list performance evaluation ##########
##########################################################################
## Data_prep
Bach <- readRDS("...zenodo/Mouse_normal_breast_data/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...zenodo/Mouse_normal_breast_data/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...zenodo/Mouse_normal_breast_data/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...zenodo/Mouse_normal_breast_data/Pal/Pal_cleaned.rds")
TM <- readRDS("...zenodo/Mouse_normal_breast_data//TabulaMuris/TabulaMuris_cleaned.rds")

meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)
Cell_barcodes <- readRDS("...zenodo/GSVA/Mouse/Sampled_barcodes.rds")

m_df = msigdbr(species = "Mus musculus")
GeneSets <- split(x = m_df$gene_symbol, f = m_df$gs_name)

###
Giraddi <- NormalizeData(Giraddi)
Giraddi <- ScaleData(Giraddi, features=rownames(Giraddi))
matGiraddi <- Giraddi@assays$RNA@scale.data
matGiraddi <- matGiraddi[,colnames(matGiraddi) %in% Cell_barcodes$Giraddi]

Bach <- NormalizeData(Bach)
Bach <- ScaleData(Bach, features=rownames(Bach))
matBach <- Bach@assays$RNA@scale.data
matBach <- matBach[,colnames(matBach) %in% Cell_barcodes$Bach]

Pal <- NormalizeData(Pal)
Pal <- ScaleData(Pal, features=rownames(Pal))
matPal <- Pal@assays$RNA@scale.data
matPal <- matPal[,colnames(matPal) %in% Cell_barcodes$Pal]

Saeki <- NormalizeData(Saeki)
Saeki <- ScaleData(Saeki, features=rownames(Saeki))
matSaeki <- Saeki@assays$RNA@scale.data
matSaeki <- matSaeki[,colnames(matSaeki) %in% Cell_barcodes$Saeki]

TM <- NormalizeData(TM)
TM <- ScaleData(TM, features=rownames(TM))
matTM <- TM@assays$RNA@scale.data
colnames(matTM) <- gsub("TM_Adu1_", "", colnames(matTM))
colnames(matTM) <- gsub("TM_Adu2_", "", colnames(matTM))


## Run 
# Caution! 8 hours each. 
Giraddi_gsvaResult <- gsva(matGiraddi, GeneSets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult, "...zenodo/GSVA/Mouse/Giraddi_GSVA.csv")
# 26165.75 sec elapsed

Bach_gsvaResult <- gsva(matBach, GeneSets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult, "...zenodo/GSVA/Mouse/Bach_GSVA.csv")
# 27488.38 sec elapsed

Pal_gsvaResult <- gsva(matPal, GeneSets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult, "...zenodo/GSVA/Mouse/Pal_GSVA.csv")
# 21485.23 sec elapsed

Saeki_gsvaResult <- gsva(matSaeki, GeneSets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult, "...zenodo/GSVA/Mouse/Saeki_GSVA.csv")
# 24945.38 sec elapsed

TM_gsvaResult <- gsva(matTM, GeneSets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult, "...zenodo/GSVA/Mouse/TM_GSVA.csv")
# 6480.58 sec


##########################################################################
############ GSVA analysis for curated gene sets  ########################
##########################################################################
Stem_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Stem_cor_genes_top1000.rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Stem_gene_sets$Top_Stem_160, Basal_gene_sets$Top_Basal_240, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_200)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Stem_gene_sets, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

# Data_prep
Bach <- readRDS("...zenodo/Mouse_normal_breast_data/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...zenodo/Mouse_normal_breast_data/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...zenodo/Mouse_normal_breast_data/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...zenodo/Mouse_normal_breast_data/Pal/Pal_cleaned.rds")
TM <- readRDS("...zenodo/Mouse_normal_breast_data//TabulaMuris/TabulaMuris_cleaned.rds")

#
Giraddi <- NormalizeData(Giraddi)
Giraddi <- ScaleData(Giraddi, features=rownames(Giraddi))
matGiraddi <- Giraddi@assays$RNA@scale.data

Bach <- NormalizeData(Bach)
Bach <- ScaleData(Bach, features=rownames(Bach))
matBach <- Bach@assays$RNA@scale.data

Pal <- NormalizeData(Pal)
Pal <- ScaleData(Pal, features=rownames(Pal))
matPal <- Pal@assays$RNA@scale.data

Saeki <- NormalizeData(Saeki)
Saeki <- ScaleData(Saeki, features=rownames(Saeki))
matSaeki <- Saeki@assays$RNA@scale.data

TM <- NormalizeData(TM)
TM <- ScaleData(TM, features=rownames(TM))
matTM <- TM@assays$RNA@scale.data
colnames(matTM) <- gsub("TM_Adu1_", "", colnames(matTM))
colnames(matTM) <- gsub("TM_Adu2_", "", colnames(matTM))

remove(Giraddi, Bach, Pal, Saeki, TM)
gc();gc()

###
Giraddi_gsvaResult <- gsva(matGiraddi, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Giraddi_gsvaResult, "...zenodo/GSVA/Mouse/Giraddi_GSVA_curated.csv")

Bach_gsvaResult <- gsva(matBach, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Bach_gsvaResult, "...zenodo/GSVA/Mouse/Bach_GSVA_curated.csv")

Pal_gsvaResult <- gsva(matPal, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Pal_gsvaResult, "...zenodo/GSVA/Mouse/Pal_GSVA_curated.csv")

Saeki_gsvaResult <- gsva(matSaeki, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(Saeki_gsvaResult, "...zenodo/GSVA/Mouse/Saeki_GSVA_curated.csv")

TM_gsvaResult <- gsva(matTM, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(TM_gsvaResult, "...zenodo/GSVA/Mouse/TM_GSVA_curated.csv")



##########################################################################
############ Curated gene sets; Performance evaluation ###################
##########################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
meta_seu <- seu@meta.data[,c("nFeature_RNA", "nCount_RNA", "percent.mt")]
remove(seu)
gc();gc()

#
Cell_barcodes <- readRDS("...zenodo/GSVA/Mouse/Sampled_barcodes.rds")
meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)
#
meta_Giraddi <- meta[row.names(meta) %in% Cell_barcodes$Giraddi,]
meta_Bach <- meta[row.names(meta) %in% Cell_barcodes$Bach,]
meta_Pal <- meta[row.names(meta) %in% Cell_barcodes$Pal,]
meta_Saeki <- meta[row.names(meta) %in% Cell_barcodes$Saeki,]

#
Cytotrace <- read.csv("...zenodo/CytoTRACE/Mouse_CytoTRACE_score.csv",
                      row.names = 1)

## Giraddi
Giraddi_gsvaResult <- read.csv("...zenodo/GSVA/Mouse/Giraddi_GSVA.csv",
                               row.names = 1)
Giraddi_gsvaResult_Stem <- read.csv("...zenodo/GSVA/Mouse/Giraddi_GSVA_Stem_1000.csv",
                                    row.names = 1)
Giraddi_gsvaResult_Basal <- read.csv("...zenodo/GSVA/Mouse/Giraddi_GSVA_Basal_1000.csv",
                                     row.names = 1)
Giraddi_gsvaResult_Alv <- read.csv("...zenodo/GSVA/Mouse/Giraddi_GSVA_Alv_1000.csv",
                                   row.names = 1)
Giraddi_gsvaResult_Hor <- read.csv("...zenodo/GSVA/Mouse/Giraddi_GSVA_Hor_1000.csv",
                                   row.names = 1)
Giraddi_gsvaResult_Curated <- rbind(Giraddi_gsvaResult_Stem[3,],Giraddi_gsvaResult_Basal[7,],
                                    Giraddi_gsvaResult_Alv[20,],Giraddi_gsvaResult_Hor[5,]) 
row.names(Giraddi_gsvaResult_Curated) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")

remove(Giraddi_gsvaResult_Stem, Giraddi_gsvaResult_Basal, Giraddi_gsvaResult_Alv, Giraddi_gsvaResult_Hor)
gc();gc()

# 
Giraddi_gsvaResult <- t(Giraddi_gsvaResult)
Giraddi_gsvaResult_Curated <- t(Giraddi_gsvaResult_Curated)
Giraddi_matrix <- cbind(Giraddi_gsvaResult_Curated, Giraddi_gsvaResult)

meta_Giraddi <- meta_Giraddi[row.names(Giraddi_matrix),]
bio_Giraddi <- meta_seu[row.names(Giraddi_matrix),]
Giraddi_matrix <- cbind(meta_Giraddi[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")], Giraddi_matrix, bio_Giraddi)

cor_Giraddi_S5 <- cor(Giraddi_matrix$S5_pseudotime, Giraddi_matrix[,5:length(colnames(Giraddi_matrix))], method = "s")
cor_Giraddi_S4 <- cor(Giraddi_matrix$S4_pseudotime, Giraddi_matrix[,5:length(colnames(Giraddi_matrix))], method = "s")
cor_Giraddi_S2 <- cor(Giraddi_matrix$S2_pseudotime, Giraddi_matrix[,5:length(colnames(Giraddi_matrix))], method = "s")
cor_Giraddi_S1 <- cor(Giraddi_matrix$S1_pseudotime, Giraddi_matrix[,5:length(colnames(Giraddi_matrix))], method = "s")

cor_Giraddi_pseudotime <- rbind(cor_Giraddi_S5, cor_Giraddi_S4, cor_Giraddi_S2, cor_Giraddi_S1)
row.names(cor_Giraddi_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

Giraddi_cytotrace <- Cytotrace[row.names(Cytotrace) %in% Cell_barcodes$Giraddi, ]
meta_Giraddi_cytotrace <- meta_Giraddi[row.names(Giraddi_cytotrace),]
Giraddi_cytotrace_matrix <- cbind(meta_Giraddi_cytotrace[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")],
                                  Giraddi_cytotrace)
cor_Giraddi_cytotrace_S5 <- cor(Giraddi_cytotrace_matrix$S5_pseudotime, Giraddi_cytotrace_matrix[,5:length(colnames(Giraddi_cytotrace_matrix))], method = "s")
cor_Giraddi_cytotrace_S4 <- cor(Giraddi_cytotrace_matrix$S4_pseudotime, Giraddi_cytotrace_matrix[,5:length(colnames(Giraddi_cytotrace_matrix))], method = "s")
cor_Giraddi_cytotrace_S2 <- cor(Giraddi_cytotrace_matrix$S2_pseudotime, Giraddi_cytotrace_matrix[,5:length(colnames(Giraddi_cytotrace_matrix))], method = "s")
cor_Giraddi_cytotrace_S1 <- cor(Giraddi_cytotrace_matrix$S1_pseudotime, Giraddi_cytotrace_matrix[,5:length(colnames(Giraddi_cytotrace_matrix))], method = "s")

cor_Giraddi_cytotrace_pseudotime <- rbind(cor_Giraddi_cytotrace_S5, cor_Giraddi_cytotrace_S4, cor_Giraddi_cytotrace_S2, cor_Giraddi_cytotrace_S1)
row.names(cor_Giraddi_cytotrace_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

cor_Giraddi_pseudotime <- cbind(cor_Giraddi_cytotrace_pseudotime, cor_Giraddi_pseudotime)

remove(cor_Giraddi_cytotrace_pseudotime, cor_Giraddi_cytotrace_S5, cor_Giraddi_cytotrace_S4, cor_Giraddi_cytotrace_S2, cor_Giraddi_cytotrace_S1,
       Giraddi_cytotrace_matrix, meta_Giraddi_cytotrace, Giraddi_cytotrace, cor_Giraddi_S1, cor_Giraddi_S2, cor_Giraddi_S4, cor_Giraddi_S5,
       Giraddi_matrix, Giraddi_gsvaResult, Giraddi_gsvaResult_Curated)
gc();gc()


# Bach
Bach_gsvaResult <- read.csv("...zenodo/GSVA/Mouse/Bach_GSVA.csv",
                            row.names = 1)
Bach_gsvaResult_Stem <- read.csv("...zenodo/GSVA/Mouse/Bach_GSVA_Stem_1000.csv",
                                 row.names = 1)
Bach_gsvaResult_Basal <- read.csv("...zenodo/GSVA/Mouse/Bach_GSVA_Basal_1000.csv",
                                  row.names = 1)
Bach_gsvaResult_Alv <- read.csv("...zenodo/GSVA/Mouse/Bach_GSVA_Alv_1000.csv",
                                row.names = 1)
Bach_gsvaResult_Hor <- read.csv("...zenodo/GSVA/Mouse/Bach_GSVA_Hor_1000.csv",
                                row.names = 1)
Bach_gsvaResult_Curated <- rbind(Bach_gsvaResult_Stem[3,],Bach_gsvaResult_Basal[7,],
                                 Bach_gsvaResult_Alv[20,],Bach_gsvaResult_Hor[5,]) 
row.names(Bach_gsvaResult_Curated) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")

remove(Bach_gsvaResult_Stem, Bach_gsvaResult_Basal, Bach_gsvaResult_Alv, Bach_gsvaResult_Hor)
gc();gc()

# 
Bach_gsvaResult <- t(Bach_gsvaResult)
Bach_gsvaResult_Curated <- t(Bach_gsvaResult_Curated)
Bach_matrix <- cbind(Bach_gsvaResult_Curated, Bach_gsvaResult)

meta_Bach <- meta_Bach[row.names(Bach_matrix),]
bio_Bach <- meta_seu[row.names(Bach_matrix),]
Bach_matrix <- cbind(meta_Bach[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")], Bach_matrix, bio_Bach)

cor_Bach_S5 <- cor(Bach_matrix$S5_pseudotime, Bach_matrix[,5:length(colnames(Bach_matrix))], method = "s")
cor_Bach_S4 <- cor(Bach_matrix$S4_pseudotime, Bach_matrix[,5:length(colnames(Bach_matrix))], method = "s")
cor_Bach_S2 <- cor(Bach_matrix$S2_pseudotime, Bach_matrix[,5:length(colnames(Bach_matrix))], method = "s")
cor_Bach_S1 <- cor(Bach_matrix$S1_pseudotime, Bach_matrix[,5:length(colnames(Bach_matrix))], method = "s")

cor_Bach_pseudotime <- rbind(cor_Bach_S5, cor_Bach_S4, cor_Bach_S2, cor_Bach_S1)
row.names(cor_Bach_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

Bach_cytotrace <- Cytotrace[row.names(Cytotrace) %in% Cell_barcodes$Bach, ]
meta_Bach_cytotrace <- meta_Bach[row.names(Bach_cytotrace),]
Bach_cytotrace_matrix <- cbind(meta_Bach_cytotrace[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")],
                               Bach_cytotrace)
cor_Bach_cytotrace_S5 <- cor(Bach_cytotrace_matrix$S5_pseudotime, Bach_cytotrace_matrix[,5:length(colnames(Bach_cytotrace_matrix))], method = "s")
cor_Bach_cytotrace_S4 <- cor(Bach_cytotrace_matrix$S4_pseudotime, Bach_cytotrace_matrix[,5:length(colnames(Bach_cytotrace_matrix))], method = "s")
cor_Bach_cytotrace_S2 <- cor(Bach_cytotrace_matrix$S2_pseudotime, Bach_cytotrace_matrix[,5:length(colnames(Bach_cytotrace_matrix))], method = "s")
cor_Bach_cytotrace_S1 <- cor(Bach_cytotrace_matrix$S1_pseudotime, Bach_cytotrace_matrix[,5:length(colnames(Bach_cytotrace_matrix))], method = "s")

cor_Bach_cytotrace_pseudotime <- rbind(cor_Bach_cytotrace_S5, cor_Bach_cytotrace_S4, cor_Bach_cytotrace_S2, cor_Bach_cytotrace_S1)
row.names(cor_Bach_cytotrace_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

cor_Bach_pseudotime <- cbind(cor_Bach_cytotrace_pseudotime, cor_Bach_pseudotime)

remove(cor_Bach_cytotrace_pseudotime, cor_Bach_cytotrace_S5, cor_Bach_cytotrace_S4, cor_Bach_cytotrace_S2, cor_Bach_cytotrace_S1,
       Bach_cytotrace_matrix, meta_Bach_cytotrace, Bach_cytotrace, cor_Bach_S1, cor_Bach_S2, cor_Bach_S4, cor_Bach_S5,
       Bach_matrix, Bach_gsvaResult, Bach_gsvaResult_Curated)
gc();gc()


# Pal
Pal_gsvaResult <- read.csv("...zenodo/GSVA/Mouse/Pal_GSVA.csv",
                           row.names = 1)
Pal_gsvaResult_Stem <- read.csv("...zenodo/GSVA/Mouse/Pal_GSVA_Stem_1000.csv",
                                row.names = 1)
Pal_gsvaResult_Basal <- read.csv("...zenodo/GSVA/Mouse/Pal_GSVA_Basal_1000.csv",
                                 row.names = 1)
Pal_gsvaResult_Alv <- read.csv("...zenodo/GSVA/Mouse/Pal_GSVA_Alv_1000.csv",
                               row.names = 1)
Pal_gsvaResult_Hor <- read.csv("...zenodo/GSVA/Mouse/Pal_GSVA_Hor_1000.csv",
                               row.names = 1)
Pal_gsvaResult_Curated <- rbind(Pal_gsvaResult_Stem[3,],Pal_gsvaResult_Basal[7,],
                                Pal_gsvaResult_Alv[20,],Pal_gsvaResult_Hor[5,]) 
row.names(Pal_gsvaResult_Curated) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")

remove(Pal_gsvaResult_Stem, Pal_gsvaResult_Basal, Pal_gsvaResult_Alv, Pal_gsvaResult_Hor)
gc();gc()

# 
Pal_gsvaResult <- t(Pal_gsvaResult)
Pal_gsvaResult_Curated <- t(Pal_gsvaResult_Curated)
Pal_matrix <- cbind(Pal_gsvaResult_Curated, Pal_gsvaResult)

meta_Pal <- meta_Pal[row.names(Pal_matrix),]
bio_Pal <- meta_seu[row.names(Pal_matrix),]
Pal_matrix <- cbind(meta_Pal[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")], Pal_matrix, bio_Pal)

cor_Pal_S5 <- cor(Pal_matrix$S5_pseudotime, Pal_matrix[,5:length(colnames(Pal_matrix))], method = "s")
cor_Pal_S4 <- cor(Pal_matrix$S4_pseudotime, Pal_matrix[,5:length(colnames(Pal_matrix))], method = "s")
cor_Pal_S2 <- cor(Pal_matrix$S2_pseudotime, Pal_matrix[,5:length(colnames(Pal_matrix))], method = "s")
cor_Pal_S1 <- cor(Pal_matrix$S1_pseudotime, Pal_matrix[,5:length(colnames(Pal_matrix))], method = "s")

cor_Pal_pseudotime <- rbind(cor_Pal_S5, cor_Pal_S4, cor_Pal_S2, cor_Pal_S1)
row.names(cor_Pal_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

Pal_cytotrace <- Cytotrace[row.names(Cytotrace) %in% Cell_barcodes$Pal, ]
meta_Pal_cytotrace <- meta_Pal[row.names(Pal_cytotrace),]
Pal_cytotrace_matrix <- cbind(meta_Pal_cytotrace[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")],
                              Pal_cytotrace)
cor_Pal_cytotrace_S5 <- cor(Pal_cytotrace_matrix$S5_pseudotime, Pal_cytotrace_matrix[,5:length(colnames(Pal_cytotrace_matrix))], method = "s")
cor_Pal_cytotrace_S4 <- cor(Pal_cytotrace_matrix$S4_pseudotime, Pal_cytotrace_matrix[,5:length(colnames(Pal_cytotrace_matrix))], method = "s")
cor_Pal_cytotrace_S2 <- cor(Pal_cytotrace_matrix$S2_pseudotime, Pal_cytotrace_matrix[,5:length(colnames(Pal_cytotrace_matrix))], method = "s")
cor_Pal_cytotrace_S1 <- cor(Pal_cytotrace_matrix$S1_pseudotime, Pal_cytotrace_matrix[,5:length(colnames(Pal_cytotrace_matrix))], method = "s")

cor_Pal_cytotrace_pseudotime <- rbind(cor_Pal_cytotrace_S5, cor_Pal_cytotrace_S4, cor_Pal_cytotrace_S2, cor_Pal_cytotrace_S1)
row.names(cor_Pal_cytotrace_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

cor_Pal_pseudotime <- cbind(cor_Pal_cytotrace_pseudotime, cor_Pal_pseudotime)

remove(cor_Pal_cytotrace_pseudotime, cor_Pal_cytotrace_S5, cor_Pal_cytotrace_S4, cor_Pal_cytotrace_S2, cor_Pal_cytotrace_S1,
       Pal_cytotrace_matrix, meta_Pal_cytotrace, Pal_cytotrace, cor_Pal_S1, cor_Pal_S2, cor_Pal_S4, cor_Pal_S5,
       Pal_matrix, Pal_gsvaResult, Pal_gsvaResult_Curated)
gc();gc()


# Saeki
Saeki_gsvaResult <- read.csv("...zenodo/GSVA/Mouse/Saeki_GSVA.csv",
                             row.names = 1)
Saeki_gsvaResult_Stem <- read.csv("...zenodo/GSVA/Mouse/Saeki_GSVA_Stem_1000.csv",
                                  row.names = 1)
Saeki_gsvaResult_Basal <- read.csv("...zenodo/GSVA/Mouse/Saeki_GSVA_Basal_1000.csv",
                                   row.names = 1)
Saeki_gsvaResult_Alv <- read.csv("...zenodo/GSVA/Mouse/Saeki_GSVA_Alv_1000.csv",
                                 row.names = 1)
Saeki_gsvaResult_Hor <- read.csv("...zenodo/GSVA/Mouse/Saeki_GSVA_Hor_1000.csv",
                                 row.names = 1)
Saeki_gsvaResult_Curated <- rbind(Saeki_gsvaResult_Stem[3,],Saeki_gsvaResult_Basal[7,],
                                  Saeki_gsvaResult_Alv[20,],Saeki_gsvaResult_Hor[5,]) 
row.names(Saeki_gsvaResult_Curated) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")

remove(Saeki_gsvaResult_Stem, Saeki_gsvaResult_Basal, Saeki_gsvaResult_Alv, Saeki_gsvaResult_Hor)
gc();gc()

# 
Saeki_gsvaResult <- t(Saeki_gsvaResult)
Saeki_gsvaResult_Curated <- t(Saeki_gsvaResult_Curated)
Saeki_matrix <- cbind(Saeki_gsvaResult_Curated, Saeki_gsvaResult)

meta_Saeki <- meta_Saeki[row.names(Saeki_matrix),]
bio_Saeki <- meta_seu[row.names(Saeki_matrix),]
Saeki_matrix <- cbind(meta_Saeki[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")], Saeki_matrix, bio_Saeki)

cor_Saeki_S5 <- cor(Saeki_matrix$S5_pseudotime, Saeki_matrix[,5:length(colnames(Saeki_matrix))], method = "s")
cor_Saeki_S4 <- cor(Saeki_matrix$S4_pseudotime, Saeki_matrix[,5:length(colnames(Saeki_matrix))], method = "s")
cor_Saeki_S2 <- cor(Saeki_matrix$S2_pseudotime, Saeki_matrix[,5:length(colnames(Saeki_matrix))], method = "s")
cor_Saeki_S1 <- cor(Saeki_matrix$S1_pseudotime, Saeki_matrix[,5:length(colnames(Saeki_matrix))], method = "s")

cor_Saeki_pseudotime <- rbind(cor_Saeki_S5, cor_Saeki_S4, cor_Saeki_S2, cor_Saeki_S1)
row.names(cor_Saeki_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

Saeki_cytotrace <- Cytotrace[row.names(Cytotrace) %in% Cell_barcodes$Saeki, ]
meta_Saeki_cytotrace <- meta_Saeki[row.names(Saeki_cytotrace),]
Saeki_cytotrace_matrix <- cbind(meta_Saeki_cytotrace[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")],
                                Saeki_cytotrace)
cor_Saeki_cytotrace_S5 <- cor(Saeki_cytotrace_matrix$S5_pseudotime, Saeki_cytotrace_matrix[,5:length(colnames(Saeki_cytotrace_matrix))], method = "s")
cor_Saeki_cytotrace_S4 <- cor(Saeki_cytotrace_matrix$S4_pseudotime, Saeki_cytotrace_matrix[,5:length(colnames(Saeki_cytotrace_matrix))], method = "s")
cor_Saeki_cytotrace_S2 <- cor(Saeki_cytotrace_matrix$S2_pseudotime, Saeki_cytotrace_matrix[,5:length(colnames(Saeki_cytotrace_matrix))], method = "s")
cor_Saeki_cytotrace_S1 <- cor(Saeki_cytotrace_matrix$S1_pseudotime, Saeki_cytotrace_matrix[,5:length(colnames(Saeki_cytotrace_matrix))], method = "s")

cor_Saeki_cytotrace_pseudotime <- rbind(cor_Saeki_cytotrace_S5, cor_Saeki_cytotrace_S4, cor_Saeki_cytotrace_S2, cor_Saeki_cytotrace_S1)
row.names(cor_Saeki_cytotrace_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

cor_Saeki_pseudotime <- cbind(cor_Saeki_cytotrace_pseudotime, cor_Saeki_pseudotime)

remove(cor_Saeki_cytotrace_pseudotime, cor_Saeki_cytotrace_S5, cor_Saeki_cytotrace_S4, cor_Saeki_cytotrace_S2, cor_Saeki_cytotrace_S1,
       Saeki_cytotrace_matrix, meta_Saeki_cytotrace, Saeki_cytotrace, cor_Saeki_S1, cor_Saeki_S2, cor_Saeki_S4, cor_Saeki_S5,
       Saeki_matrix, Saeki_gsvaResult, Saeki_gsvaResult_Curated)
gc();gc()


# TabulaMuris
TM_gsvaResult <- read.csv("...zenodo/GSVA/Mouse/TM_GSVA.csv",
                          row.names = 1)
TM_gsvaResult_Stem <- read.csv("...zenodo/GSVA/Mouse/TM_GSVA_Stem_1000.csv",
                               row.names = 1)
TM_gsvaResult_Basal <- read.csv("...zenodo/GSVA/Mouse/TM_GSVA_Basal_1000.csv",
                                row.names = 1)
TM_gsvaResult_Alv <- read.csv("...zenodo/GSVA/Mouse/TM_GSVA_Alv_1000.csv",
                              row.names = 1)
TM_gsvaResult_Hor <- read.csv("...zenodo/GSVA/Mouse/TM_GSVA_Hor_1000.csv",
                              row.names = 1)
TM_gsvaResult_Curated <- rbind(TM_gsvaResult_Stem[3,],TM_gsvaResult_Basal[7,],
                               TM_gsvaResult_Alv[20,],TM_gsvaResult_Hor[5,]) 
row.names(TM_gsvaResult_Curated) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")

remove(TM_gsvaResult_Stem, TM_gsvaResult_Basal, TM_gsvaResult_Alv, TM_gsvaResult_Hor)
gc();gc()

# 
TM_gsvaResult <- t(TM_gsvaResult)
TM_gsvaResult_Curated <- t(TM_gsvaResult_Curated)
TM_matrix <- cbind(TM_gsvaResult_Curated, TM_gsvaResult)
row.names(TM_matrix) <- gsub("X10X", "10X", row.names(TM_matrix))

meta_TM <- meta[row.names(TM_matrix),]
bio_TM <- meta_seu[row.names(TM_matrix),]
TM_matrix <- cbind(meta_TM[,c("S5_pseudotime", "S4_pseudotime", "S2_pseudotime", "S1_pseudotime")], TM_matrix, bio_TM)

cor_TM_S5 <- cor(TM_matrix$S5_pseudotime, TM_matrix[,5:length(colnames(TM_matrix))], method = "s")
cor_TM_S4 <- cor(TM_matrix$S4_pseudotime, TM_matrix[,5:length(colnames(TM_matrix))], method = "s")
cor_TM_S2 <- cor(TM_matrix$S2_pseudotime, TM_matrix[,5:length(colnames(TM_matrix))], method = "s")
cor_TM_S1 <- cor(TM_matrix$S1_pseudotime, TM_matrix[,5:length(colnames(TM_matrix))], method = "s")

cor_TM_pseudotime <- rbind(cor_TM_S5, cor_TM_S4, cor_TM_S2, cor_TM_S1)
row.names(cor_TM_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")

cor_TM_cytotrace_pseudotime <- cbind(rep(NA, 4), rep(NA, 4))
row.names(cor_TM_cytotrace_pseudotime) <- c("cor_S5", "cor_S4", "cor_S2", "cor_S1")
colnames(cor_TM_cytotrace_pseudotime) <- c("CytoTRACE", "GCS")

cor_TM_pseudotime <- cbind(cor_TM_cytotrace_pseudotime, cor_TM_pseudotime)

remove(cor_TM_cytotrace_pseudotime,
       TM_cytotrace_matrix, meta_TM_cytotrace, TM_cytotrace, cor_TM_S1, cor_TM_S2, cor_TM_S4, cor_TM_S5,
       TM_matrix, TM_gsvaResult, TM_gsvaResult_Curated)
gc();gc()


###
cor_Giraddi_pseudotime <- t(cor_Giraddi_pseudotime)
cor_Giraddi_pseudotime <- as.data.frame(cor_Giraddi_pseudotime)
cor_Giraddi_pseudotime$Feature <- row.names(cor_Giraddi_pseudotime)

cor_Bach_pseudotime <- t(cor_Bach_pseudotime)
cor_Bach_pseudotime <- as.data.frame(cor_Bach_pseudotime)
cor_Bach_pseudotime$Feature <- row.names(cor_Bach_pseudotime)

cor_Pal_pseudotime <- t(cor_Pal_pseudotime)
cor_Pal_pseudotime <- as.data.frame(cor_Pal_pseudotime)
cor_Pal_pseudotime$Feature <- row.names(cor_Pal_pseudotime)

cor_Saeki_pseudotime <- t(cor_Saeki_pseudotime)
cor_Saeki_pseudotime <- as.data.frame(cor_Saeki_pseudotime)
cor_Saeki_pseudotime$Feature <- row.names(cor_Saeki_pseudotime)

cor_TM_pseudotime <- t(cor_TM_pseudotime)
cor_TM_pseudotime <- as.data.frame(cor_TM_pseudotime)
cor_TM_pseudotime$Feature <- row.names(cor_TM_pseudotime)

colnames(cor_Giraddi_pseudotime)[1:4] <- paste(colnames(cor_Giraddi_pseudotime)[1:4], "Giraddi", sep="_")
colnames(cor_Bach_pseudotime)[1:4] <- paste(colnames(cor_Bach_pseudotime)[1:4], "Bach", sep="_")
colnames(cor_Pal_pseudotime)[1:4] <- paste(colnames(cor_Pal_pseudotime)[1:4], "Pal", sep="_")
colnames(cor_Saeki_pseudotime)[1:4] <- paste(colnames(cor_Saeki_pseudotime)[1:4], "Saeki", sep="_")
colnames(cor_TM_pseudotime)[1:4] <- paste(colnames(cor_TM_pseudotime)[1:4], "TM", sep="_")


#
write.csv(cor_Giraddi_pseudotime, "...zenodo/GSVA/Mouse/cor_Giraddi_pseudotime.csv")
write.csv(cor_Bach_pseudotime, "...zenodo/GSVA/Mouse/cor_Bach_pseudotime.csv")
write.csv(cor_Pal_pseudotime, "...zenodo/GSVA/Mouse/cor_Pal_pseudotime.csv")
write.csv(cor_Saeki_pseudotime, "...zenodo/GSVA/Mouse/cor_Saeki_pseudotime.csv")
write.csv(cor_TM_pseudotime, "...zenodo/GSVA/Mouse/cor_TM_pseudotime.csv")

###
cor_all <- merge(cor_Giraddi_pseudotime, cor_Bach_pseudotime, by.x="Feature", by.y = "Feature")
cor_all <- merge(cor_all, cor_Pal_pseudotime, by.x="Feature", by.y = "Feature")
cor_all <- merge(cor_all, cor_Saeki_pseudotime, by.x="Feature", by.y = "Feature")
cor_all <- merge(cor_all, cor_TM_pseudotime, by.x="Feature", by.y = "Feature")

rownames(cor_all) <- cor_all$Feature
cor_all <- cor_all[,2:21]

S5_mean <- -1*apply(cor_all[, grep("S5", colnames(cor_all))], 1, mean, na.rm=TRUE)
S5_rank <- rank(-1*S5_mean)

S4_mean <- -1*apply(cor_all[, grep("S4", colnames(cor_all))], 1, mean, na.rm=TRUE)
S4_rank <- rank(-1*S4_mean)

S2_mean <- -1*apply(cor_all[, grep("S2", colnames(cor_all))], 1, mean, na.rm=TRUE)
S2_rank <- rank(-1*S2_mean)

S1_mean <- -1*apply(cor_all[, grep("S1", colnames(cor_all))], 1, mean, na.rm=TRUE)
S1_rank <- rank(-1*S1_mean)

cor_all <- cbind(cor_all, S5_mean, S5_rank, S4_mean, S4_rank, S2_mean, S2_rank, S1_mean, S1_rank)

cor_all$category <- "MSigDB"
cor_all$category[rownames(cor_all) == "CytoTRACE" | rownames(cor_all) == "GCS"] <- "CytoTRACE"
cor_all$category[grep("Curated_", rownames(cor_all))] <- "Curated"
cor_all$category[rownames(cor_all) == "nFeature_RNA" |
                   rownames(cor_all) == "nCount_RNA"|
                   rownames(cor_all) == "percent.mt"] <- "Biological"  
write.csv(cor_all, "...zenodo/GSVA/Mouse/cor_all_pseudotime_ranked_annotated.csv")



##########################################################################
############ Lineage-specific gene sets based scoring ####################
##########################################################################
Giraddi_res <- read.csv("...zenodo/GSVA/Mouse/Giraddi_GSVA_curated.csv", row.names = 1)
Bach_res <- read.csv("...zenodo/GSVA/Mouse/Bach_GSVA_curated.csv", row.names = 1)
Pal_res <- read.csv("...zenodo/GSVA/Mouse/Pal_GSVA_curated.csv", row.names = 1)
Saeki_res <- read.csv("...zenodo/GSVA/Mouse/Saeki_GSVA_curated.csv", row.names = 1)
TM_res <- read.csv("...zenodo/GSVA/Mouse/TM_GSVA_curated.csv", row.names = 1)

seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

#
Giraddi_res <- as.data.frame(t(Giraddi_res))
Bach_res <- as.data.frame(t(Bach_res))
Pal_res <- as.data.frame(t(Pal_res))
Saeki_res <- as.data.frame(t(Saeki_res))
TM_res <- as.data.frame(t(TM_res))
row.names(TM_res) <- gsub("X10X", "10X", row.names(TM_res))

#
Mouse_res <- rbind(Giraddi_res, Bach_res, Pal_res, Saeki_res, TM_res)
meta <- seu@meta.data[,c(1:7,10:11)]
meta <- meta[row.names(Mouse_res), ]

Mouse_res_meta <- cbind(Mouse_res, meta)
Mouse_res_meta$Annotation <- factor(Mouse_res_meta$Annotation,
                                    levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Mouse_res_meta$Study <- factor(Mouse_res_meta$Study,
                               levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
write.csv(Mouse_res_meta, "...zenodo/GSVA/Mouse/Mouse_res_meta.csv")




