# Human normal breast scRNAseq label transfer & integration



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Cell cycle genes
data(cc.genes)
s.genes <- cc.genes$s.genes
g2m.genes <- cc.genes$g2m.genes

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")



########################################################################
###### Label transfer ##################################################
########################################################################
Ind4 <- readRDS("...zenodo/Human_normal_breast_data/Ind4/Ind4_cleaned.rds")
Ind5 <- readRDS("...zenodo/Human_normal_breast_data/Ind5/Ind5_cleaned.rds")
Ind6 <- readRDS("...zenodo/Human_normal_breast_data/Ind6/Ind6_cleaned.rds")
Ind7 <- readRDS("...zenodo/Human_normal_breast_data/Ind7/Ind7_cleaned.rds")
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

##
Nguyen <- merge(Ind4, y = c(Ind5, Ind6, Ind7), 
                add.cell.ids = NULL, project = "Nguyen")
remove(Ind4, Ind5, Ind6, Ind7)
gc();gc()

gene_list <- row.names(Nguyen)
mouse_gene_list <- row.names(seu@assays$RNA)

human = biomaRt::useMart("ensembl", dataset = "hsapiens_gene_ensembl")
mouse = biomaRt::useMart("ensembl", dataset = "mmusculus_gene_ensembl")
genes.list = biomaRt::getLDS(attributes = c("hgnc_symbol"), filters = "hgnc_symbol", values = gene_list , mart = human, attributesL = c("mgi_symbol"), martL = mouse, uniqueRows = T)
genes.list_unique <- genes.list[genes.list$MGI.symbol %in% mouse_gene_list,]
genes.list_unique <- genes.list_unique %>% arrange(HGNC.symbol)

hoge <- genes.list_unique[1,]
for(i in 1:14453){
  if(!genes.list_unique$HGNC.symbol[i] == genes.list_unique$HGNC.symbol[i+1]){
    hoge <- rbind(hoge, genes.list_unique[i+1,])
  }
}

hoge <- hoge %>% arrange(MGI.symbol) 

hoge2 <- hoge[1,]
for(i in 1:13798){
  if(!hoge$MGI.symbol[i] == hoge$MGI.symbol[i+1]){
    hoge2 <- rbind(hoge2, hoge[i+1,])
  }
}

temp <- Nguyen[hoge2$HGNC.symbol,]
rownames(hoge2) <- hoge2$HGNC.symbol
hoge2 <- hoge2[row.names(temp),]

temp2 <- temp
row.names(temp2@assays$RNA@counts) <- hoge2$MGI.symbol
row.names(temp2@assays$RNA@data) <- hoge2$MGI.symbol
row.names(temp2@assays$RNA@meta.features) <- hoge2$MGI.symbol

Nguyen <- temp2

##
Nguyen$Dataset <- rep("Nguyen", length(colnames(Nguyen)))
seu$Dataset <- rep("Integrated", length(colnames(seu)))

BGPCT_N <- merge(seu, Nguyen, add.cell.ids = NULL, project = "BGPCT_N")
BGPCT_N.list <- SplitObject(BGPCT_N, split.by = "Dataset")
Nguyen <- BGPCT_N.list[[2]]

##
Nguyen.list <- SplitObject(Nguyen, split.by = "orig.ident")

for (i in 1:length(Nguyen.list)) {
  Nguyen.list[[i]] <- NormalizeData(Nguyen.list[[i]], verbose = FALSE)
  Nguyen.list[[i]] <- FindVariableFeatures(Nguyen.list[[i]], selection.method = "vst", 
                                           nfeatures = 2000, verbose = FALSE)
}

##
hoge <- NULL
ind <- c("Ind4", "Ind5", "Ind6", "Ind7")

for(i in 1:4){
  data.query <- Nguyen.list[[ind[i]]]
  transfer.anchors <- FindTransferAnchors(reference = seu, query = data.query, 
                                          dims = 1:50, reduction = "cca")
  predictions <- TransferData(anchorset = transfer.anchors, refdata = seu$Annotation, 
                              dims = 1:50, weight.reduction = "cca")
  file1 <- paste(paste("...zenodo/Human_normal_breast_data/Transfer_anchors", ind[i], sep = "_"), "rds", sep=".")
  file2 <- paste(paste("...zenodo/Human_normal_breast_data/Predicted_annotation", ind[i], sep = "_"), "csv", sep=".")
  
  saveRDS(transfer.anchors, file1)
  write.csv(predictions, file2)
  
  hoge <- c(hoge, list(predictions))
  
  remove(transfer.anchors, predictions, data.query)
  gc();gc()
}



########################################################################
###### Data integration ################################################
########################################################################
Ind4 <- readRDS("...zenodo/Human_normal_breast_data/Ind4/Ind4_cleaned.rds")
Ind5 <- readRDS("...zenodo/Human_normal_breast_data/Ind5/Ind5_cleaned.rds")
Ind6 <- readRDS("...zenodo/Human_normal_breast_data/Ind6/Ind6_cleaned.rds")
Ind7 <- readRDS("...zenodo/Human_normal_breast_data/Ind7/Ind7_cleaned.rds")

Nguyen <- merge(Ind4, y = c(Ind5, Ind6, Ind7), 
                add.cell.ids = NULL, project = "Nguyen")
remove(Ind4, Ind5, Ind6, Ind7)
gc();gc()

##
Nguyen.list <- SplitObject(Nguyen, split.by = "orig.ident")
for (i in 1:length(Nguyen.list)) {
  Nguyen.list[[i]] <- NormalizeData(Nguyen.list[[i]], verbose = FALSE)
  Nguyen.list[[i]] <- FindVariableFeatures(Nguyen.list[[i]], selection.method = "vst", 
                                           nfeatures = 2000, verbose = FALSE)
}
Nguyen.anchors <- FindIntegrationAnchors(object.list = Nguyen.list, dims = 1:50, anchor.features = 2000)
Nguyen <- IntegrateData(anchorset = Nguyen.anchors, dims = 1:50)

##
Pred_ind4 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind4.csv", row.names = 1)
Pred_ind5 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind5.csv", row.names = 1)
Pred_ind6 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind6.csv", row.names = 1)
Pred_ind7 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind7.csv", row.names = 1)
Prediction <- rbind(Pred_ind4, Pred_ind5, Pred_ind6, Pred_ind7)

Nguyen <- subset(Nguyen, cells=row.names(Prediction))
Nguyen <- AddMetaData(Nguyen, metadata=Prediction)
Nguyen$predicted.id <- factor(Nguyen$predicted.id,
                              levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
saveRDS(Nguyen, "...zenodo/Human_normal_breast_data/Nguyen_integrated.rds")

##
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated.rds")

Nguyen <- ScaleData(Nguyen, features = rownames(Nguyen))
Nguyen <- RunPCA(Nguyen, features = VariableFeatures(object = Nguyen))
Nguyen <- RunUMAP(Nguyen, dims = 1:10)
Nguyen <- FindNeighbors(Nguyen, dims = 1:10)
Nguyen <- FindClusters(Nguyen, resolution = 0.1)

##
p1 <- UMAPPlot(Nguyen)
p2 <- UMAPPlot(Nguyen, group.by="orig.ident")
p3 <- UMAPPlot(Nguyen, group.by="predicted.id", cols=col.clst)
p4 <- UMAPPlot(Nguyen, group.by="clust")
plot_grid(p1,p2,p3,p4)

VlnPlot(Nguyen, c("nFeature_RNA", "nCount_RNA", "percent.mt"), pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=8),
        axis.title=element_text(size=12,face="bold"))

##
Nguyen_markers <- FindAllMarkers(Nguyen, only.pos = T)
write.csv(Nguyen_markers, "...zenodo/Human_normal_breast_data/Nguyen_markers.csv")

##
Cell_barcodes <- WhichCells(Nguyen, idents=c(0,1,2))
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated.rds")

##
Sub <- subset(Nguyen,  cells=Cell_barcodes)
saveRDS(Sub, "...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
