# Human normal breast scRNAseq processing & integration



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Cell cycle genes
data(cc.genes)
s.genes <- cc.genes$s.genes
g2m.genes <- cc.genes$g2m.genes



########################################################################
###### Data retrieval ##################################################
########################################################################
# Data was obtained from the Gene Expression Omnibus database (accession number: GSE113196)
# Manually remove NULL value to load data properly
Ind4 <- read.table("...your_folder/Nguyen/GSM3099846_Ind4_Expression_Matrix.txt",
                   row.names = 1)
Ind5 <- read.table("...your_folder/Nguyen/GSM3099847_Ind5_Expression_Matrix.txt",
                   row.names = 1)
Ind6 <- read.table("...your_folder/Nguyen/GSM3099848_Ind6_Expression_Matrix.txt",
                   row.names = 1)
Ind7 <- read.table("...your_folder/Nguyen/GSM3099849_Ind7_Expression_Matrix.txt",
                   row.names = 1)


##
Ind4 <- CreateSeuratObject(Ind4, min.cells = 3, min.features = 200)
Ind4[["percent.mt"]] <- PercentageFeatureSet(Ind4, pattern = "^MT-")

Ind5 <- CreateSeuratObject(Ind5, min.cells = 3, min.features = 200)
Ind5[["percent.mt"]] <- PercentageFeatureSet(Ind5, pattern = "^MT-")

Ind6 <- CreateSeuratObject(Ind6, min.cells = 3, min.features = 200)
Ind6[["percent.mt"]] <- PercentageFeatureSet(Ind6, pattern = "^MT-")

Ind7 <- CreateSeuratObject(Ind7, min.cells = 3, min.features = 200)
Ind7[["percent.mt"]] <- PercentageFeatureSet(Ind7, pattern = "^MT-")



########################################################################
###### Data retrieval ##################################################
########################################################################
setwd("...your_folder/Human_normal_breast_data")

## Ind4 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ind4 <- subset(Ind4, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 10)
hoge <- Ind4
dataset <- "Ind4"
dir.create("Ind4")
hoge <- NormalizeData(hoge)
hoge <- FindVariableFeatures(hoge, selection.method = "vst", nfeatures = 2000)
hoge <- ScaleData(hoge, features = rownames(hoge))
hoge <- RunPCA(hoge, features = VariableFeatures(object = hoge))
ElbowPlot(hoge)
hoge <- RunUMAP(hoge, dims=1:10)
hoge <- FindNeighbors(hoge, dims = 1:10)
hoge <- FindClusters(hoge, resolution = 0.3)

PC <- 10

## Basic characteristics
p1 <- UMAPPlot(hoge, label=T, label.size=8)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind4")

p2 <- VlnPlot(hoge, "nFeature_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p3 <- VlnPlot(hoge, "nCount_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p4 <- VlnPlot(hoge, "percent.mt",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mitochondrial gene percentage")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(p1, p2, p3, p4, ncol=4, align="hv")
ggsave(paste(dataset, "fig1.pdf", sep="/"), width = 20, height = 4)
ggsave(paste(dataset, "fig1.tiff", sep="/"), width = 20, height = 4, dpi=300)

## Cell cycle analysis
hoge <- CellCycleScoring(hoge, s.features = s.genes, g2m.features = g2m.genes, set.ident = TRUE)
p5 <- UMAPPlot(hoge, group.by="Phase")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "Cell_cycle"))
stat <- as.data.frame(table(hoge$seurat_clusters, hoge@active.ident))
p6 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "Cell_cycle"))

#
plot_grid(p5, p6, ncol=2, align="hv")
ggsave(paste(dataset, "fig2.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig2.tiff", sep="/"), width = 10, height = 4, dpi=300)

Idents(hoge) <- "seurat_clusters"


## DEG analysis
if(length(levels(hoge@active.ident))>1){
  markers <- FindAllMarkers(hoge, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
  top5 <- markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_logFC)
  palette <- wes_palette("Zissou1", 100, type = "continuous")
  p7 <- DoHeatmap(hoge, features = as.character(top5$gene), label = T) +
    scale_fill_gradientn(colors = palette)
  
  write.csv(markers, paste(dataset, "DEG.csv", sep = "/"))
  
  p7
  ggsave(paste(dataset, "fig3.pdf", sep="/"), width = 10, height = 8)
  ggsave(paste(dataset, "fig3.tiff", sep="/"), width = 10, height = 8, dpi=300)
  
}


## Doublet finder
sweep.res.list_data <- paramSweep_v3(hoge, PCs = 1:PC, sct = FALSE)
sweep.stats_data <- summarizeSweep(sweep.res.list_data, GT = FALSE)
bcmvn_data <- find.pK(sweep.stats_data)
saveRDS(bcmvn_data, paste(dataset, "bcmvn_data.rds", sep = "/"))

annotations <- hoge@active.ident
homotypic.prop <- modelHomotypic(annotations) 
nExp_poi <- round(0.2*length(colnames(x = hoge)))  ## Assuming 20% doublet formation rate - tailor for your dataset
nExp_poi.adj <- round(nExp_poi*(1-homotypic.prop))

pK=0.26

hoge <- doubletFinder_v3(hoge, PCs = 1:PC, pN = 0.25, pK = pK, nExp = nExp_poi.adj, reuse.pANN = FALSE, sct = FALSE)

p8 <-UMAPPlot(hoge, group.by=paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "DoubletFinder"))
stat <- as.data.frame(table(hoge$seurat_clusters,
                            hoge@meta.data[,colnames(hoge@meta.data) == paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_")]))
p9 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "DoubletFinder"))

##
plot_grid(p8, p9, ncol=2, align="hv")
ggsave(paste(dataset, "fig4.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig4.tiff", sep="/"), width = 10, height = 4, dpi=300)

## Gene expression
FP <- wes_palette("Zissou1", 5, type = "discrete")
g1 <- FeaturePlot(hoge, "KRT14", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g2 <- FeaturePlot(hoge, "ACTA2", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g3 <- FeaturePlot(hoge, "KRT18", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g4 <- FeaturePlot(hoge, "SLPI", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g5 <- FeaturePlot(hoge, "ELF5", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g6 <- FeaturePlot(hoge, "AREG", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g7 <- FeaturePlot(hoge, "ANKRD30A", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g8 <- FeaturePlot(hoge, "MKI67", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g1,g2,g3,g4,g5,g6,g7,g8, ncol=4)
ggsave(paste(dataset, "fig5.pdf", sep="/"), width = 20, height = 10)
ggsave(paste(dataset, "fig5.tiff", sep="/"), width = 20, height = 10, dpi=300)

#
g9 <- FeaturePlot(hoge, "PTPRC", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g10 <- FeaturePlot(hoge, "CD52", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g11 <- FeaturePlot(hoge, "VIM", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g12 <- FeaturePlot(hoge, "COL4A1", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g13 <- FeaturePlot(hoge, "CDH5", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g14 <- FeaturePlot(hoge, "DES", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g9, g11, g12, g13, ncol=2)
ggsave(paste(dataset, "fig6.pdf", sep="/"), width = 10, height = 10)
ggsave(paste(dataset, "fig6.tiff", sep="/"), width = 10, height = 10, dpi=300)

## Retained cells
temp <- subset(hoge, idents = c(0:3))
temp@meta.data$clust <- rep(NULL, length(colnames(hoge)))
temp@meta.data$clust[temp$seurat_clusters==0] <- "B/Myo"
temp@meta.data$clust[temp$seurat_clusters==1|temp$seurat_clusters==2] <- "L1.1/L1.2"
temp@meta.data$clust[temp$seurat_clusters==3] <- "L2"
UMAPPlot(temp, group.by="clust")
FeaturePlot(temp, c("SLPI", "KRT14", "AREG"), 
            pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")
meta <- temp@meta.data


## Cleaned data saving
hoge <- Ind4
hoge <- subset(hoge, cells = row.names(meta))
hoge <- AddMetaData(hoge, meta)
saveRDS(hoge, paste(paste(dataset, dataset, sep = "/"), "cleaned.rds", sep = "_"))

## Clean environment
remove(top5, sweep.stats_data, sweep.res.list_data, stat, bcmvn_data, hoge, markers,
       p1, p2, p3, p4, p5, p6, p7, p8, p9, g1, g2, g3, g4, g5, g6, g7, g8, 
       annotations, cells, dataset, FP, homotypic.prop, nExp_poi, nExp_poi.adj, path, PC, pK, res, palette,
       g9, g10, g11, g12, g13, g14)


## Ind5 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ind5 <- subset(Ind5, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 10)
hoge <- Ind5
dataset <- "Ind5"
dir.create("Ind5")
hoge <- NormalizeData(hoge)
hoge <- FindVariableFeatures(hoge, selection.method = "vst", nfeatures = 2000)
hoge <- ScaleData(hoge, features = rownames(hoge))
hoge <- RunPCA(hoge, features = VariableFeatures(object = hoge))
ElbowPlot(hoge)
hoge <- RunUMAP(hoge, dims=1:10)
hoge <- FindNeighbors(hoge, dims = 1:10)
hoge <- FindClusters(hoge, resolution = 0.3)

PC <- 10

## Basic characteristics
p1 <- UMAPPlot(hoge, label=T, label.size=8)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind5")

p2 <- VlnPlot(hoge, "nFeature_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p3 <- VlnPlot(hoge, "nCount_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p4 <- VlnPlot(hoge, "percent.mt",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mitochondrial gene percentage")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(p1, p2, p3, p4, ncol=4, align="hv")
ggsave(paste(dataset, "fig1.pdf", sep="/"), width = 20, height = 4)
ggsave(paste(dataset, "fig1.tiff", sep="/"), width = 20, height = 4, dpi=300)

## Cell cycle analysis
hoge <- CellCycleScoring(hoge, s.features = s.genes, g2m.features = g2m.genes, set.ident = TRUE)
p5 <- UMAPPlot(hoge, group.by="Phase")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "Cell_cycle"))
stat <- as.data.frame(table(hoge$seurat_clusters, hoge@active.ident))
p6 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "Cell_cycle"))

#
plot_grid(p5, p6, ncol=2, align="hv")
ggsave(paste(dataset, "fig2.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig2.tiff", sep="/"), width = 10, height = 4, dpi=300)

Idents(hoge) <- "seurat_clusters"


## DEG analysis
if(length(levels(hoge@active.ident))>1){
  markers <- FindAllMarkers(hoge, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
  top5 <- markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_logFC)
  palette <- wes_palette("Zissou1", 100, type = "continuous")
  p7 <- DoHeatmap(hoge, features = as.character(top5$gene), label = T) +
    scale_fill_gradientn(colors = palette)
  
  write.csv(markers, paste(dataset, "DEG.csv", sep = "/"))
  
  p7
  ggsave(paste(dataset, "fig3.pdf", sep="/"), width = 10, height = 8)
  ggsave(paste(dataset, "fig3.tiff", sep="/"), width = 10, height = 8, dpi=300)
  
}


## Doublet finder
sweep.res.list_data <- paramSweep_v3(hoge, PCs = 1:PC, sct = FALSE)
sweep.stats_data <- summarizeSweep(sweep.res.list_data, GT = FALSE)
bcmvn_data <- find.pK(sweep.stats_data)
saveRDS(bcmvn_data, paste(dataset, "bcmvn_data.rds", sep = "/"))

annotations <- hoge@active.ident
homotypic.prop <- modelHomotypic(annotations) 
nExp_poi <- round(0.2*length(colnames(x = hoge)))  ## Assuming 20% doublet formation rate - tailor for your dataset
nExp_poi.adj <- round(nExp_poi*(1-homotypic.prop))

pK=0.005

hoge <- doubletFinder_v3(hoge, PCs = 1:PC, pN = 0.25, pK = pK, nExp = nExp_poi.adj, reuse.pANN = FALSE, sct = FALSE)

p8 <-UMAPPlot(hoge, group.by=paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "DoubletFinder"))
stat <- as.data.frame(table(hoge$seurat_clusters,
                            hoge@meta.data[,colnames(hoge@meta.data) == paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_")]))
p9 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "DoubletFinder"))

##
plot_grid(p8, p9, ncol=2, align="hv")
ggsave(paste(dataset, "fig4.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig4.tiff", sep="/"), width = 10, height = 4, dpi=300)

## Gene expression
FP <- wes_palette("Zissou1", 5, type = "discrete")
g1 <- FeaturePlot(hoge, "KRT14", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g2 <- FeaturePlot(hoge, "ACTA2", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g3 <- FeaturePlot(hoge, "KRT18", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g4 <- FeaturePlot(hoge, "SLPI", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g5 <- FeaturePlot(hoge, "ELF5", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g6 <- FeaturePlot(hoge, "AREG", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g7 <- FeaturePlot(hoge, "ANKRD30A", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g8 <- FeaturePlot(hoge, "MKI67", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g1,g2,g3,g4,g5,g6,g7,g8, ncol=4)
ggsave(paste(dataset, "fig5.pdf", sep="/"), width = 20, height = 10)
ggsave(paste(dataset, "fig5.tiff", sep="/"), width = 20, height = 10, dpi=300)

#
g9 <- FeaturePlot(hoge, "PTPRC", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g10 <- FeaturePlot(hoge, "CD52", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g11 <- FeaturePlot(hoge, "VIM", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g12 <- FeaturePlot(hoge, "COL4A1", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g13 <- FeaturePlot(hoge, "CDH5", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g14 <- FeaturePlot(hoge, "DES", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g10, g11, g12, g13, g14, ncol=3)
ggsave(paste(dataset, "fig6.pdf", sep="/"), width = 10, height = 10)
ggsave(paste(dataset, "fig6.tiff", sep="/"), width = 10, height = 10, dpi=300)

## Retained cells
temp <- subset(hoge, idents = c(0:5))
temp@meta.data$clust[temp$seurat_clusters==0|temp$seurat_clusters==1|temp$seurat_clusters==3] <- "B/Myo"
temp@meta.data$clust[temp$seurat_clusters==2|temp$seurat_clusters==5] <- "L1.1/L1.2"
temp@meta.data$clust[temp$seurat_clusters==4] <- "L2"
UMAPPlot(temp, group.by="clust")
FeaturePlot(temp, c("SLPI", "KRT14", "AREG"), 
            pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")
meta <- temp@meta.data


## Cleaned data saving
hoge <- Ind5
hoge <- subset(hoge, cells = row.names(meta))
hoge <- AddMetaData(hoge, meta)
saveRDS(hoge, paste(paste(dataset, dataset, sep = "/"), "cleaned.rds", sep = "_"))


## Clean environment
remove(top5, sweep.stats_data, sweep.res.list_data, stat, bcmvn_data, hoge, markers,
       p1, p2, p3, p4, p5, p6, p7, p8, p9, g1, g2, g3, g4, g5, g6, g7, g8, 
       annotations, cells, dataset, FP, homotypic.prop, nExp_poi, nExp_poi.adj, path, PC, pK, res, palette,
       g9, g10, g11, g12, g13, g14)



## Ind6 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ind6 <- subset(Ind6, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 10)
hoge <- Ind6
dataset <- "Ind6"
dir.create("Ind6")
hoge <- NormalizeData(hoge)
hoge <- FindVariableFeatures(hoge, selection.method = "vst", nfeatures = 2000)
hoge <- ScaleData(hoge, features = rownames(hoge))
hoge <- RunPCA(hoge, features = VariableFeatures(object = hoge))
ElbowPlot(hoge)
hoge <- RunUMAP(hoge, dims=1:15)
hoge <- FindNeighbors(hoge, dims = 1:15)
hoge <- FindClusters(hoge, resolution = 0.3)

PC <- 15

## Basic characteristics
p1 <- UMAPPlot(hoge, label=T, label.size=8)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind6")

p2 <- VlnPlot(hoge, "nFeature_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p3 <- VlnPlot(hoge, "nCount_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p4 <- VlnPlot(hoge, "percent.mt",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mitochondrial gene percentage")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(p1, p2, p3, p4, ncol=4, align="hv")
ggsave(paste(dataset, "fig1.pdf", sep="/"), width = 20, height = 4)
ggsave(paste(dataset, "fig1.tiff", sep="/"), width = 20, height = 4, dpi=300)

## Cell cycle analysis
hoge <- CellCycleScoring(hoge, s.features = s.genes, g2m.features = g2m.genes, set.ident = TRUE)
p5 <- UMAPPlot(hoge, group.by="Phase")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "Cell_cycle"))
stat <- as.data.frame(table(hoge$seurat_clusters, hoge@active.ident))
p6 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "Cell_cycle"))

#
plot_grid(p5, p6, ncol=2, align="hv")
ggsave(paste(dataset, "fig2.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig2.tiff", sep="/"), width = 10, height = 4, dpi=300)

Idents(hoge) <- "seurat_clusters"


## DEG analysis
if(length(levels(hoge@active.ident))>1){
  markers <- FindAllMarkers(hoge, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
  top5 <- markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_logFC)
  palette <- wes_palette("Zissou1", 100, type = "continuous")
  p7 <- DoHeatmap(hoge, features = as.character(top5$gene), label = T) +
    scale_fill_gradientn(colors = palette)
  
  write.csv(markers, paste(dataset, "DEG.csv", sep = "/"))
  
  p7
  ggsave(paste(dataset, "fig3.pdf", sep="/"), width = 10, height = 8)
  ggsave(paste(dataset, "fig3.tiff", sep="/"), width = 10, height = 8, dpi=300)
  
}


## Doublet finder
sweep.res.list_data <- paramSweep_v3(hoge, PCs = 1:PC, sct = FALSE)
sweep.stats_data <- summarizeSweep(sweep.res.list_data, GT = FALSE)
bcmvn_data <- find.pK(sweep.stats_data)
saveRDS(bcmvn_data, paste(dataset, "bcmvn_data.rds", sep = "/"))

annotations <- hoge@active.ident
homotypic.prop <- modelHomotypic(annotations) 
nExp_poi <- round(0.2*length(colnames(x = hoge)))  ## Assuming 20% doublet formation rate - tailor for your dataset
nExp_poi.adj <- round(nExp_poi*(1-homotypic.prop))

pK=0.3

hoge <- doubletFinder_v3(hoge, PCs = 1:PC, pN = 0.25, pK = pK, nExp = nExp_poi.adj, reuse.pANN = FALSE, sct = FALSE)

p8 <-UMAPPlot(hoge, group.by=paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "DoubletFinder"))
stat <- as.data.frame(table(hoge$seurat_clusters,
                            hoge@meta.data[,colnames(hoge@meta.data) == paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_")]))
p9 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "DoubletFinder"))

##
plot_grid(p8, p9, ncol=2, align="hv")
ggsave(paste(dataset, "fig4.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig4.tiff", sep="/"), width = 10, height = 4, dpi=300)

## Gene expression
FP <- wes_palette("Zissou1", 5, type = "discrete")
g1 <- FeaturePlot(hoge, "KRT14", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g2 <- FeaturePlot(hoge, "ACTA2", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g3 <- FeaturePlot(hoge, "KRT18", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g4 <- FeaturePlot(hoge, "SLPI", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g5 <- FeaturePlot(hoge, "ELF5", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g6 <- FeaturePlot(hoge, "AREG", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g7 <- FeaturePlot(hoge, "ANKRD30A", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g8 <- FeaturePlot(hoge, "MKI67", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g1,g2,g3,g4,g5,g6,g7,g8, ncol=4)
ggsave(paste(dataset, "fig5.pdf", sep="/"), width = 20, height = 10)
ggsave(paste(dataset, "fig5.tiff", sep="/"), width = 20, height = 10, dpi=300)

#
g9 <- FeaturePlot(hoge, "ESR1", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g10 <- FeaturePlot(hoge, "CD52", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g11 <- FeaturePlot(hoge, "VIM", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g12 <- FeaturePlot(hoge, "COL4A1", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g13 <- FeaturePlot(hoge, "CDH5", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g14 <- FeaturePlot(hoge, "DES", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g9, g10, g11, g12, ncol=2)
ggsave(paste(dataset, "fig6.pdf", sep="/"), width = 10, height = 10)
ggsave(paste(dataset, "fig6.tiff", sep="/"), width = 10, height = 10, dpi=300)

## Retained cells
temp <- subset(hoge, idents = c(0:6))
temp@meta.data$clust[temp$seurat_clusters==0|temp$seurat_clusters==1|
                       temp$seurat_clusters==2|temp$seurat_clusters==5] <- "B/Myo"
temp@meta.data$clust[temp$seurat_clusters==3] <- "L1.1/L1.2"
temp@meta.data$clust[temp$seurat_clusters==4|temp$seurat_clusters==6] <- "L2"
UMAPPlot(temp, group.by="clust")
FeaturePlot(temp, c("SLPI", "KRT14", "AREG"), 
            pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")
meta <- temp@meta.data


## Cleaned data saving
hoge <- Ind6
hoge <- subset(hoge, cells = row.names(meta))
hoge <- AddMetaData(hoge, meta)
saveRDS(hoge, paste(paste(dataset, dataset, sep = "/"), "cleaned.rds", sep = "_"))

## Clean environment
remove(top5, sweep.stats_data, sweep.res.list_data, stat, bcmvn_data, hoge, markers,
       p1, p2, p3, p4, p5, p6, p7, p8, p9, g1, g2, g3, g4, g5, g6, g7, g8, 
       annotations, cells, dataset, FP, homotypic.prop, nExp_poi, nExp_poi.adj, path, PC, pK, res, palette,
       g9, g10, g11, g12, g13, g14)


## Ind7 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Ind7 <- subset(Ind7, subset = nCount_RNA > 1000 & nFeature_RNA > 500 & percent.mt < 10)
hoge <- Ind7
dataset <- "Ind7"
dir.create("Ind7")
hoge <- NormalizeData(hoge)
hoge <- FindVariableFeatures(hoge, selection.method = "vst", nfeatures = 2000)
hoge <- ScaleData(hoge, features = rownames(hoge))
hoge <- RunPCA(hoge, features = VariableFeatures(object = hoge))
ElbowPlot(hoge)
hoge <- RunUMAP(hoge, dims=1:10)
hoge <- FindNeighbors(hoge, dims = 1:10)
hoge <- FindClusters(hoge, resolution = 0.3)

PC <- 10

## Basic characteristics
p1 <- UMAPPlot(hoge, label=T, label.size=8)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind7")

p2 <- VlnPlot(hoge, "nFeature_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p3 <- VlnPlot(hoge, "nCount_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p4 <- VlnPlot(hoge, "percent.mt",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mitochondrial gene percentage")+ 
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(p1, p2, p3, p4, ncol=4, align="hv")
ggsave(paste(dataset, "fig1.pdf", sep="/"), width = 20, height = 4)
ggsave(paste(dataset, "fig1.tiff", sep="/"), width = 20, height = 4, dpi=300)

## Cell cycle analysis
hoge <- CellCycleScoring(hoge, s.features = s.genes, g2m.features = g2m.genes, set.ident = TRUE)
p5 <- UMAPPlot(hoge, group.by="Phase")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "Cell_cycle"))
stat <- as.data.frame(table(hoge$seurat_clusters, hoge@active.ident))
p6 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "Cell_cycle"))

#
plot_grid(p5, p6, ncol=2, align="hv")
ggsave(paste(dataset, "fig2.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig2.tiff", sep="/"), width = 10, height = 4, dpi=300)

Idents(hoge) <- "seurat_clusters"


## DEG analysis
if(length(levels(hoge@active.ident))>1){
  markers <- FindAllMarkers(hoge, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
  top5 <- markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_logFC)
  palette <- wes_palette("Zissou1", 100, type = "continuous")
  p7 <- DoHeatmap(hoge, features = as.character(top5$gene), label = T) +
    scale_fill_gradientn(colors = palette)
  
  write.csv(markers, paste(dataset, "DEG.csv", sep = "/"))
  
  p7
  ggsave(paste(dataset, "fig3.pdf", sep="/"), width = 10, height = 8)
  ggsave(paste(dataset, "fig3.tiff", sep="/"), width = 10, height = 8, dpi=300)
  
}


## Doublet finder
sweep.res.list_data <- paramSweep_v3(hoge, PCs = 1:PC, sct = FALSE)
sweep.stats_data <- summarizeSweep(sweep.res.list_data, GT = FALSE)
bcmvn_data <- find.pK(sweep.stats_data)
saveRDS(bcmvn_data, paste(dataset, "bcmvn_data.rds", sep = "/"))

annotations <- hoge@active.ident
homotypic.prop <- modelHomotypic(annotations) 
nExp_poi <- round(0.2*length(colnames(x = hoge)))  ## Assuming 20% doublet formation rate - tailor for your dataset
nExp_poi.adj <- round(nExp_poi*(1-homotypic.prop))

pK=0.19

hoge <- doubletFinder_v3(hoge, PCs = 1:PC, pN = 0.25, pK = pK, nExp = nExp_poi.adj, reuse.pANN = FALSE, sct = FALSE)

p8 <-UMAPPlot(hoge, group.by=paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  ggtitle(paste(dataset, "DoubletFinder"))
stat <- as.data.frame(table(hoge$seurat_clusters,
                            hoge@meta.data[,colnames(hoge@meta.data) == paste(paste("DF.classifications_0.25", pK, sep = "_"), nExp_poi.adj, sep = "_")]))
p9 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle(paste(dataset, "DoubletFinder"))

##
plot_grid(p8, p9, ncol=2, align="hv")
ggsave(paste(dataset, "fig4.pdf", sep="/"), width = 10, height = 4)
ggsave(paste(dataset, "fig4.tiff", sep="/"), width = 10, height = 4, dpi=300)

## Gene expression
FP <- wes_palette("Zissou1", 5, type = "discrete")
g1 <- FeaturePlot(hoge, "KRT14", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g2 <- FeaturePlot(hoge, "ACTA2", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g3 <- FeaturePlot(hoge, "KRT18", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g4 <- FeaturePlot(hoge, "SLPI", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g5 <- FeaturePlot(hoge, "ELF5", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g6 <- FeaturePlot(hoge, "AREG", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g7 <- FeaturePlot(hoge, "ANKRD30A", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g8 <- FeaturePlot(hoge, "MKI67", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g1,g2,g3,g4,g5,g6,g7,g8, ncol=4)
ggsave(paste(dataset, "fig5.pdf", sep="/"), width = 20, height = 10)
ggsave(paste(dataset, "fig5.tiff", sep="/"), width = 20, height = 10, dpi=300)

#
g9 <- FeaturePlot(hoge, "PTPRC", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g10 <- FeaturePlot(hoge, "CD52", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

g11 <- FeaturePlot(hoge, "VIM", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g12 <- FeaturePlot(hoge, "COL4A1", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g13 <- FeaturePlot(hoge, "CDH5", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
g14 <- FeaturePlot(hoge, "DES", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

#
plot_grid(g10, g11, g12, g14, ncol=2)
ggsave(paste(dataset, "fig6.pdf", sep="/"), width = 10, height = 10)
ggsave(paste(dataset, "fig6.tiff", sep="/"), width = 10, height = 10, dpi=300)

## Retained cells
temp <- subset(hoge, idents = c(0:3))
temp@meta.data$clust[temp$seurat_clusters==3] <- "B/Myo"
temp@meta.data$clust[temp$seurat_clusters==1] <- "L1.1/L1.2"
temp@meta.data$clust[temp$seurat_clusters==0|temp$seurat_clusters==2] <- "L2"
UMAPPlot(temp, group.by="clust")
FeaturePlot(temp, c("SLPI", "KRT14", "AREG"), 
            pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")
meta <- temp@meta.data


## Cleaned data saving
hoge <- Ind7
hoge <- subset(hoge, cells = row.names(meta))
hoge <- AddMetaData(hoge, meta)
saveRDS(hoge, paste(paste(dataset, dataset, sep = "/"), "cleaned.rds", sep = "_"))


## Clean environment
remove(top5, sweep.stats_data, sweep.res.list_data, stat, bcmvn_data, hoge, markers,
       p1, p2, p3, p4, p5, p6, p7, p8, p9, g1, g2, g3, g4, g5, g6, g7, g8, 
       annotations, cells, dataset, FP, homotypic.prop, nExp_poi, nExp_poi.adj, path, PC, pK, res, palette,
       g9, g10, g11, g12, g13, g14)
