# Lim et al. microarray


########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}



##############################################################################
################# Data preparation ###########################################
##############################################################################
### Mouse gene list
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
gene_mouse <- row.names(seu@assays$RNA)
saveRDS(gene_mouse, "...zenodo/Others/mouse_genes.rds")

###
#### Data were retrieved from GEO, and only expression column was retained.
exp <- read.table("...zenodo/Lim_microarray/GSE19446/mouse_modified.txt", header=T)
anno <- read.table("...zenodo/Lim_microarray/GSE19446/GPL6887_Annotation.txt", header=T)

table(exp$ID_REF %in% anno$Probe_Id)
row.names(exp) <- exp$ID_REF
row.names(anno) <- anno$Probe_Id

exp <- log2(exp[,2:19])
exp <- as.matrix(exp)
exp <- normalizeBetweenArrays(exp, method = "quantile")
boxplot(exp)

df <- merge(anno, exp, by.x = "row.names", by.y="row.names")
df <- df[,c(2,4:21)]
df <- df[!is.na(df$Symbol),]

unique_ID <- as.character(unique(df$Symbol))
hoge <- NULL

for(i in 1:length(unique_ID)){       
  hoge <- rbind(hoge, apply(df[which(df$Symbol == unique_ID[i]), 2:19], 2, mean, na.rm=TRUE))
}                                      
rownames(hoge) <- unique_ID   
hoge <- as.data.frame(hoge)

write.csv(hoge, "...zenodo/Lim_microarray/GSE19446/mouse_averaged.csv")

#
Stem_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Stem_cor_genes_top1000.rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Stem_gene_sets$Top_Stem_160, Basal_gene_sets$Top_Basal_240, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_200)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Stem_gene_sets, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

#
hoge <- read.csv("...zenodo/Lim_microarray/GSE19446/mouse_averaged.csv", row.names = 1)
mouse_gene <- readRDS("...zenodo/Others/mouse_genes.rds")
hoge <- hoge[row.names(hoge) %in% mouse_gene,]
df <- as.matrix(hoge)
df_gsvaResult <- gsva(df, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")

write.csv(df_gsvaResult, "...zenodo/Lim_microarray/Lim_mouse_gsva.csv")


### Human
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
Genes <- row.names(Nguyen@assays$RNA)
saveRDS(Genes, "...zenodo/Others/human_genes.rds")

###
exp <- read.table("...zenodo/Lim_microarray/GSE16997/human_modified.txt", header=T)
anno <- read.table("...zenodo/Lim_microarray/GSE16997/GPL6884_annotation.txt", header=T)

table(exp$ID_REF %in% anno$ID)
row.names(exp) <- exp$ID_REF
row.names(anno) <- anno$ID

exp <- log2(exp[,2:13])
exp <- as.matrix(exp)
exp <- normalizeBetweenArrays(exp, method = "quantile")
boxplot(exp)

df <- merge(anno, exp, by.x = "row.names", by.y="row.names")
df <- df[,c(3:15)]
df <- df[!is.na(df$Symbol),]

unique_ID <- as.character(unique(df$Symbol))
hoge <- NULL

for(i in 1:length(unique_ID)){       
  hoge <- rbind(hoge, apply(df[which(df$Symbol == unique_ID[i]), 2:13], 2, mean, na.rm=TRUE))
}                                      
rownames(hoge) <- unique_ID   
hoge <- as.data.frame(hoge)
write.csv(hoge, "...zenodo/Lim_microarray/GSE16997/human_averaged.csv")

#
Curated_stem <-  readRDS("...zenodo/GSVA/Human/Curated_Stem(m2h).rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Human/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Human/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Human/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Curated_stem$`Curated_Stem(m2h)`, Basal_gene_sets$Top_Basal_1000, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_240)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Curated_stem, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

#
hoge <- read.csv("...zenodo/Lim_microarray/GSE16997/human_averaged.csv", row.names = 1)
Genes <- readRDS("...zenodo/Others/human_genes.rds")
hoge <- hoge[row.names(hoge) %in% Genes,]
df <- as.matrix(hoge)

tic()
df_gsvaResult <- gsva(df, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
toc()

write.csv(df_gsvaResult, "...zenodo/Lim_microarray/Lim_human_gsva.csv")