# Data integration

########################################################################
###### Environment #####################################################
########################################################################
## library
lib <- readRDS("...zenodo/Others/Library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Data 

### Please see "...zonedo/code/Processing_Analysis/Mouse_sample_preprocessing.R" 
### to prepare cleaned data.

Bach <- readRDS("...zenodo/Cleaned_data_for_integration/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...zenodo/Cleaned_data_for_integration/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...zenodo/Cleaned_data_for_integration/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...zenodo/Cleaned_data_for_integration/Pal/Pal_cleaned.rds")
TM <- readRDS("...zenodo/Cleaned_data_for_integration//TabulaMuris/TabulaMuris_cleaned.rds")

IntData <- merge(Bach, c(Giraddi, Pal, Saeki, TM), add.cell.ids = NULL, project = "IntData")
remove(Bach, Giraddi, Pal, Saeki, TM)
gc()



########################################################################
###### Integration #####################################################
########################################################################
IntData.list <- SplitObject(IntData, split.by = "Dataset")
for (i in 1:length(IntData.list)) {
  IntData.list[[i]] <- NormalizeData(IntData.list[[i]], verbose = FALSE)
  IntData.list[[i]] <- FindVariableFeatures(IntData.list[[i]], selection.method = "vst", 
                                          nfeatures = 2000, verbose = FALSE)
}
reference_dataset <- which(names(IntData.list) == "Giraddi")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, reference = reference_dataset)
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_G.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
reference_dataset <- which(names(IntData.list) == "Pal")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, reference = reference_dataset)
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_P.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
reference_dataset <- which(names(IntData.list) == "Bach")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, reference = reference_dataset)
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_B.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
reference_dataset <- which(names(IntData.list) == "Saeki")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, reference = reference_dataset)
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_S.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
reference_dataset <- which(names(IntData.list) == "TabulaMuris")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, reference = reference_dataset)
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_T.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
reference_dataset1 <- which(names(IntData.list) == "Pal")
reference_dataset2 <- which(names(IntData.list) == "Giraddi")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, reference = c(reference_dataset1,reference_dataset2))
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_GP.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
reference_dataset1 <- which(names(IntData.list) == "Pal")
reference_dataset2 <- which(names(IntData.list) == "Bach")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, reference = c(reference_dataset1,reference_dataset2))
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_PB.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
reference_dataset1 <- which(names(IntData.list) == "Pal")
reference_dataset2 <- which(names(IntData.list) == "Bach")
reference_dataset3 <- which(names(IntData.list) == "Giraddi")
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000, 
                                        reference = c(reference_dataset1,reference_dataset2,reference_dataset3))
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_GPB.rds")

#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
IntData.anchors <- FindIntegrationAnchors(object.list = IntData.list, dims = 1:50, anchor.features = 2000)
IntData <- IntegrateData(anchorset = IntData.anchors, dims = 1:50)

#%
saveRDS(IntData, "...zenodo/Integrated_data/IntData_ref_none.rds")



########################################################################
###### Preprocessing ###################################################
########################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData_ref_P.rds")
meta <- read.csv("...zenodo/Mouse_integrated_data/Metadata.csv")

Idents(seu) <- "Dataset"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu$Dataset <- NULL

## Change levels of "orig.ident"
Idents(seu) <- "orig.ident"
seu@active.ident <- factor(seu@active.ident , 
                           levels = c(as.character(meta$Dataset)))
seu$orig.ident <- seu@active.ident

## Metadata for "Strain" and "Stage"
Idents(seu) <- "orig.ident"
new.cluster.ids <- c(as.character(meta$Strain))
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu$Strain <- seu@active.ident

Idents(seu) <- "orig.ident"
new.cluster.ids <- c(as.character(meta$Stage))
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu$Stage <- seu@active.ident
seu$Stage <- factor(seu$Stage, levels=c("Embryonic", "Neonatal","Pubertal", "Virgin adult", "Pregnant",
                                        "Lactating", "Involuted", "Menopause" ))

## Clustering
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims = 1:10)
seu <- FindNeighbors(seu, dims = 1:10)
seu <- FindClusters(seu, resolution = 0.4)
UMAPPlot(seu, label=T)
UMAPPlot(seu, group.by="Stage")


## Modified.ident
levels(seu)
table(seu@active.ident)
new.cluster.ids <- c(1, 3, 2, 2, 1, 4, 3, 5, 6)
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident, levels=c(1:6))
seu$Modified.ident <- seu@active.ident

Idents(seu) <- "Modified.ident"
new.cluster.ids <- c(6, 2, 4, 1, 3, 5)
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c(1,2,3,4,5,6))
seu$Modified.ident <- seu@active.ident

UMAPPlot(seu, label=T, group.by="Modified.ident")

## Annotation
Idents(seu) <- "Modified.ident"
levels(seu)
new.cluster.ids <- c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu$Annotation <- seu@active.ident
UMAPPlot(seu, label=T)

## Save data
saveRDS(seu, "...zenodo/Mouse_integrated_data/IntData.rds")

# seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
## 3d plot
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims = 1:10, n.components = 3)
seu <- FindNeighbors(seu, dims = 1:10)
seu <- FindClusters(seu, resolution = 0.2)

umap <- seu@reductions$umap@cell.embeddings
seu3d <- as.data.frame(cbind(umap, seu@meta.data))
write.csv(seu3d, "...zenodo/Mouse_integrated_data/seu3d.csv")




