# PAM50



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}



#############################################################################
####################### PAM 50 (Mouse) ######################################
#############################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

#
pam50 <- pam50
pam50.ID <- pam50$centroids.map$EntrezGene.ID

seu.gene <- row.names(seu@assays$RNA)
converted.seu.gene <- GeneID2entrez(seu.gene, return.Matrix = T, mode="m2h")
summary(pam50.ID %in% converted.seu.gene$human.gene.ID)
# Mode    TRUE 
# logical      50 


###
ddata <- seu@assays$RNA@data
ddata <- as.matrix(ddata)
ddata <- t(ddata)
dannot <- converted.seu.gene
rownames(dannot) <- dannot$mouse.gene.ID
colnames(dannot) <- c("probe", "EntrezGene.ID")

PAM50Preds<-molecular.subtyping(sbt.model = "pam50", data=ddata,
                                annot=dannot, do.mapping=T)
saveRDS(PAM50Preds, "...zenodo/PAM50/Mouse_PAM50.rds")



#############################################################################
####################### PAM 50 (Human) ######################################
#############################################################################
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")

Nguyen.gene <- row.names(Nguyen@assays$RNA)
GeneEntrez <- GeneID2entrez(Nguyen.gene, return.Matrix = T, mode="h2h")

pam50.ID <- pam50$centroids.map$EntrezGene.ID
summary(pam50.ID %in% GeneEntrez$ENTREZ.ID)
# Mode    TRUE 
# logical      50 

###
ddata <- Nguyen@assays$RNA@data
ddata <- as.matrix(ddata)
ddata <- t(ddata)
dannot <- GeneEntrez
rownames(dannot) <- dannot$GENE.ID
colnames(dannot) <- c("probe", "EntrezGene.ID")

PAM50Preds<-molecular.subtyping(sbt.model = "pam50", data=ddata,
                                annot=dannot, do.mapping=T)
saveRDS(PAM50Preds, "...zenodo/PAM50/Nguyen_PAM50.rds")



#############################################################################
####################### PAM 50 (BRCA)  ######################################
#############################################################################
HBC <- readRDS("...zenodo/scBRCA/HBC_tumor.rds")

HBC.gene <- row.names(HBC@assays$RNA)
GeneEntrez <- GeneID2entrez(HBC.gene, return.Matrix = T, mode="h2h")
pam50.ID <- pam50$centroids.map$EntrezGene.ID
summary(pam50.ID %in% GeneEntrez$ENTREZ.ID)

HBC <- NormalizeData(HBC)
HBC <- FindVariableFeatures(HBC, selection.method = "vst", nfeatures = 2000)
all.genes <- rownames(HBC)
HBC <- ScaleData(HBC, features = all.genes)
HBC <- RunPCA(HBC, features = VariableFeatures(object = HBC))
ElbowPlot(HBC)
HBC$Subtype <- factor(HBC$Subtype, levels = c("TNBC", "HER2", "LumA", "LumB"))

HBC <- RunUMAP(HBC, dims = 1:5)
HBC <- FindNeighbors(HBC, dims = 1:5)
HBC <- FindClusters(HBC, resolution = 0.5)

###
ddata <- HBC@assays$RNA@data
ddata <- as.matrix(ddata)
ddata <- t(ddata)
dannot <- GeneEntrez
dannot <- na.omit(GeneEntrez)
rownames(dannot) <- dannot$GENE.ID
colnames(dannot) <- c("probe", "EntrezGene.ID")

###
Idents(HBC) <- "patient"
ave <- AverageExpression(HBC) 
ave <- ave$RNA
ave <- t(ave)

PAM50Preds<-molecular.subtyping(sbt.model = "pam50", data=ave,
                                annot=dannot, do.mapping=T)
saveRDS(PAM50Preds, "...zenodo/PAM50/scBRCA_PAM50.rds")


#############################################################################
####################### TCGA Claudin-low ####################################
#############################################################################
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[is.na(meta$Subtype)] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 

Exp <- assay(data)
row <- rowData(data)
geneData <- row@listData
row.names(Exp) <- geneData$external_gene_name
GeneEntrez <- GeneID2entrez(row.names(Exp), return.Matrix = T, mode="h2h")

GeneEntrez <- na.omit(GeneEntrez)
length(unique(GeneEntrez$GENE.ID))
length(unique(GeneEntrez$ENTREZ.ID))

Exp <- Exp[GeneEntrez$GENE.ID,]
row.names(Exp) <- GeneEntrez$ENTREZ.ID

predout <- claudinLow(x=train$xd, classes=as.matrix(train$classes$Group,ncol=1), y=Exp)
results <- cbind(predout$predictions, predout$distances)
saveRDS(results, "...zenodo/PAM50/TCGA_claudin.rds")

