# Pseudo_bulkRNAseq


########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}



##############################################################################
################# Data prepatation ###########################################
##############################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

Idents(seu) <- "Annotation"
Cluster <- levels(seu)
Sampling <- c(10, 100, 200, 500, 1000)

df <- data.frame(row.names = row.names(seu@assays$RNA))

for(i in 1:6){
  temp <- WhichCells(seu, idents=Cluster[i])
  for(j in 1:5){
    list <- list()
    for(k in 1:5){
      list[k] <- list(sample(temp, Sampling[j]))
    }
    
    for(k in 1:5){
      seu_temp <- subset(seu, cells=list[[k]])
      Exp <- AverageExpression(seu_temp, assays = "RNA")
      df <- cbind(df, Exp[[1]])
    }
  }
}

### Mixture label
seu$mix <- rep("Mix",length(colnames(seu)))
Idents(seu) <- "mix"

Mix <- c(sample(WhichCells(seu, idents=Cluster[1]), 1000),
         sample(WhichCells(seu, idents=Cluster[2]), 1000),
         sample(WhichCells(seu, idents=Cluster[3]), 1000),
         sample(WhichCells(seu, idents=Cluster[4]), 1000),
         sample(WhichCells(seu, idents=Cluster[5]), 1000),
         sample(WhichCells(seu, idents=Cluster[6]), 1000))

for(j in 1:5){
  list <- list()
  for(k in 1:5){
    list[k] <- list(sample(Mix, Sampling[j]))
  }
  
  for(k in 1:5){
    seu_temp <- subset(seu, cells=list[[k]])
    Exp <- AverageExpression(seu_temp, assays = "RNA")
    df <- cbind(df, Exp[[1]])
  }
}


label <- paste(rep(c(Cluster,"Mixture"),each=5), Sampling, sep = "_")
label <- rep(label, each=5)
label <- paste(label, rep(1:5,35), sep="_")

colnames(df) <- label

meta <- data.frame(row.names = label)
meta$Cluster <- rep(c(Cluster, "Mixture"), each=25)
meta$Sampling <- rep(rep(Sampling, each=5), 7) 

write.csv(df, "...zenodo/PseudoRNAseq/PseudoRNA_mouse_df.csv")
write.csv(meta, "...zenodo/PseudoRNAseq/PseudoRNA_mouse_meta.csv")



##############################################################################
################# GSVA1 ######################################################
##############################################################################
df <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_mouse_df.csv", row.names = 1)
meta <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_mouse_meta.csv", row.names = 1)

Stem_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Stem_cor_genes_top1000.rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Stem_gene_sets$Top_Stem_160, Basal_gene_sets$Top_Basal_240, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_200)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Stem_gene_sets, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

###
df <- as.matrix(df)
df_gsvaResult <- gsva(df, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(df_gsvaResult, "...zenodo/PseudoRNAseq/PseudoRNA_mouse_gsva.csv")



##############################################################################
################# Data prepatation 2 #########################################
##############################################################################
load("...zenodo/PseudoRNAseq/droplet_Mammary_seurat_tiss.Robj")
tiss <- UpdateSeuratObject(tiss)
colnames(tiss@meta.data)[1:2] <- c("nFeature_RNA", "nCount_RNA")
tiss[["percent.mt"]] <- PercentageFeatureSet(tiss, pattern = "^mt-")
Idents(tiss) <- "channel"
new.cluster.ids <- c("Adult_1(TM)", "Adult_2(TM)")
names(new.cluster.ids) <- levels(tiss)
tiss <- RenameIdents(tiss, new.cluster.ids)
tiss$orig.ident <- tiss@active.ident

###
Idents(seu) <- "Study"
TM <- subset(seu, idents = "TabulaMuris")

table(colnames(TM) %in% colnames(tiss))

Annotation <- as.data.frame(TM$Annotation)
meta <- tiss@meta.data
colnames(Annotation) <- "Int_Annotation"

meta <- merge(meta, Annotation, by.x = "row.names", by.y = "row.names", all=T)
meta$Int_Annotation <- as.character(meta$Int_Annotation)
meta$Int_Annotation[is.na(meta$Int_Annotation)] <- "Stroma"
row.names(meta) <- meta$Row.names

tiss@meta.data <- meta
saveRDS(tiss, "...zenodo/PseudoRNAseq/Annotated_TM.rds")


###
Adu1 <- readRDS("...zenodo/Mouse_normal_breast_data/Adult_1(TM)/Adult_1(TM)_cleaned.rds")
Adu2 <- readRDS("...zenodo/Mouse_normal_breast_data/Adult_2(TM)/Adult_2(TM)_cleaned.rds")
TabulaMuris <- merge(Adu1, Adu2, 
                     add.cell.ids = NULL, project = "TabulaMuris")
TabulaMuris@meta.data <- TabulaMuris@meta.data[,c(1:3, 14)]
remove(Adu1, Adu2)

TabulaMuris <- NormalizeData(TabulaMuris)
TabulaMuris <- FindVariableFeatures(TabulaMuris, selection.method = "vst", nfeatures = 2000)
TabulaMuris <- ScaleData(TabulaMuris, features = rownames(TabulaMuris))
TabulaMuris <- RunPCA(TabulaMuris, features = VariableFeatures(object = TabulaMuris))
TabulaMuris <- RunUMAP(TabulaMuris, dims=1:10)
TabulaMuris <- FindNeighbors(TabulaMuris, dims = 1:10)
TabulaMuris <- FindClusters(TabulaMuris, resolution = 0.6)

Remove_Barcode <- WhichCells(TabulaMuris, idents = c(4,5))
saveRDS(Remove_Barcode, "...zenodo/PseudoRNAseq/Remove_Barcode.rds")



##############################################################################
################# Data prepatation 3 #########################################
##############################################################################
tiss <- readRDS("...zenodo/PseudoRNAseq/Annotated_TM.rds")
Remove_Barcode <- readRDS("...zenodo/PseudoRNAseq/Remove_Barcode.rds")

Retained <- colnames(tiss)[!colnames(tiss) %in% Remove_Barcode]
tiss <- subset(tiss, cells = Retained)

tiss <- NormalizeData(tiss)
tiss <- FindVariableFeatures(tiss, selection.method = "vst", nfeatures = 2000)
tiss <- ScaleData(tiss, features = rownames(tiss))
tiss <- RunPCA(tiss, features = VariableFeatures(object = tiss))
tiss <- RunUMAP(tiss, dims=1:10)
tiss <- FindNeighbors(tiss, dims = 1:10)
tiss <- FindClusters(tiss, resolution = 0.1)

tiss$Int_Annotation <- factor(tiss$Int_Annotation, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor", "Stroma"))

Basal <- WhichCells(tiss, idents = 3)
Alv <- WhichCells(tiss, idents = 7)
Hor <- WhichCells(tiss, idents = 8)
Mix <- WhichCells(tiss, idents = c(3,7,8))
Str <- WhichCells(tiss, idents = c(0:2, 4:6,9))

tiss$mix <- rep("Mix",length(colnames(tiss)))
Idents(tiss) <- "mix"

df <- data.frame(row.names = row.names(tiss@assays$RNA))

for(i in 1:4){
  for(j in 1:10){
    list <- list()
    for(k in 1:10){
      Epi_Barcode <- sample(Cluster[[i]], Sampling[j])
      Str_Barcode <- sample(Str, 150-Sampling[j])
      Barcode <- c(Epi_Barcode, Str_Barcode)
      list[[k]] <- Barcode
    }
    
    for(k in 1:10){
      tiss_temp <- subset(tiss, cells=list[[k]])
      Exp <- AverageExpression(tiss_temp)
      df <- cbind(df, Exp[[1]])
    }
  }
}

Percentage <- seq(100,10,-10)
label <- paste(rep(c("Basal", "Alv", "Hor", "Mix"), each=10), Percentage, sep = "_")
label <- rep(label, each=10)
label <- paste(label, rep(1:10,40), sep="_")

colnames(df) <- label

meta <- data.frame(row.names = label)
meta$Cluster <- rep(c("Basal", "Alv", "Hor", "Mixture"), each=100)
meta$Percentage <- rep(rep(Percentage, each=10), 4) 

write.csv(df, "...zenodo/PseudoRNAseq/PseudoRNA_TabulaMuris_df.csv")
write.csv(meta, "...zenodo/PseudoRNAseq/PseudoRNA_TabulaMuris_meta.csv")



##############################################################################
################# GSVA 2 #####################################################
##############################################################################
df <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_TabulaMuris_df.csv", row.names = 1)
meta <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_TabulaMuris_meta.csv", row.names = 1)

Stem_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Stem_cor_genes_top1000.rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Stem_gene_sets$Top_Stem_160, Basal_gene_sets$Top_Basal_240, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_200)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Stem_gene_sets, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

###
df <- as.matrix(df)
df_gsvaResult <- gsva(df, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
write.csv(df_gsvaResult, "...zenodo/PseudoRNAseq/PseudoRNA_TabulaMuris_gsva.csv")


