# STREAM

########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  


## Data loading 
### See "Mouse_integrated_data_preprocessing.R" to prepare the data
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")



########################################################################
###### Mouse STREAM data preparation ###################################
########################################################################
## Giraddi data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Idents(seu) <- "Study"
Giraddi <- subset(seu, idents=c("Giraddi"))
sub_data <- Giraddi@assays$integrated@data
write.table(sub_data, "...zenodo/STREAM/Giraddi/Giraddi_data.tsv",
            row.names = T, sep="\t")

sub_label <- Giraddi$Annotation
write.table(sub_label, "...zenodo/STREAM/Giraddi/sub_label.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro","L-Hor"),
                         col.clst)
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/Giraddi/sub_label_color.tsv", row.names = F, col.names = F, sep="\t")

levels(Giraddi@meta.data$orig.ident)
orig_label <- factor(Giraddi$orig.ident)
write.table(orig_label, "...zenodo/STREAM/Giraddi/orig_label.tsv", row.names = F, col.names = F, sep="\t")

factor(orig_label)
pal_npg(palette = c("nrc"))(6)
orig_label_color <- cbind(c("Adult_1(G)", "Adult_2(G)", "Adult_Basal(G)", "Embryonic_d16(G)", "Embryonic_d18(G)", "Postnatal_d4(G)"),
                          c("#E64B35FF", "#4DBBD5FF", "#00A087FF", "#3C5488FF", "#F39B7FFF", "#8491B4FF"))
orig_label_color <- as.matrix(orig_label_color) 
write.table(orig_label_color, "...zenodo/STREAM/Giraddi/orig_label_color.tsv", row.names = F, col.names = F, sep="\t")


## 500 cells %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Idents(seu) <- "orig.ident"
E16 = WhichCells(seu, idents = "Embryonic_d16(G)")
E18 = WhichCells(seu, idents = "Embryonic_d18(G)")

seu$STREAM <- seu$Annotation
meta <- seu@meta.data
meta$STREAM <- as.character(meta$STREAM)
meta$STREAM[rownames(meta) %in% E16] <- "E16"
meta$STREAM[rownames(meta) %in% E18] <- "E18"
seu@meta.data <- meta

Idents(seu) <- "STREAM"
UMAPPlot(seu)

E16 <- sample(WhichCells(seu, idents="E16"), 500)
E18 <- sample(WhichCells(seu, idents="E18"), 500)
L1 <- sample(WhichCells(seu, idents="MaSC/B-pro"), 500)
L2 <- sample(WhichCells(seu, idents="Basal"), 500)
L3 <- sample(WhichCells(seu, idents="LA-pro"), 500)
L4 <- sample(WhichCells(seu, idents="L-Alv"), 500)
L5 <- sample(WhichCells(seu, idents="LH-pro"), 500)
L6 <- sample(WhichCells(seu, idents="L-Hor"), 500)
sub <- subset(seu, cells = c(E16, E18, L1, L2, L3, L4, L5, L6))

UMAPPlot(sub, group.by="Stage")
sub_data <- sub@assays$integrated@data
write.table(sub_data, "...zenodo/STREAM/500_each/Sub_data.tsv",
            row.names = T, sep="\t")

### Annotation
sub_label <- sub$STREAM
write.table(sub_label, "...zenodo/STREAM/500_each/sub_label.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(c("E16", "E18", "MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro","L-Hor"),
                         c("#9986A5","#79402E","#FDBF6F","#FF7F00","#B2DF8A","#33A02C","#FB9A99","#E31A1C"))
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/500_each/sub_label_color.tsv", row.names = F, col.names = F, sep="\t")

### Stage
sub_label <- sub$Stage
write.table(sub_label, "...zenodo/STREAM/500_each/sub_label_stage.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(levels(sub_label),
                         col.stg)
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/500_each/sub_label_color_stage.tsv", row.names = F, col.names = F, sep="\t")


## 100 cells %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Idents(seu) <- "Annotation"
L1 <- sample(WhichCells(seu, idents="MaSC/B-pro"), 100)
L2 <- sample(WhichCells(seu, idents="Basal"), 100)
L3 <- sample(WhichCells(seu, idents="LA-pro"), 100)
L4 <- sample(WhichCells(seu, idents="L-Alv"), 100)
L5 <- sample(WhichCells(seu, idents="LH-pro"), 100)
L6 <- sample(WhichCells(seu, idents="L-Hor"), 100)
sub <- subset(seu, cells = c(L1, L2, L3, L4, L5, L6))

sub_data <- sub@assays$integrated@data
write.table(sub_data, "...zenodo/STREAM/100_each/Sub_data.tsv",
            row.names = T, sep="\t")

### Annotation
sub_label <- sub$Annotation
write.table(sub_label, "...zenodo/STREAM/100_each/sub_label.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro","L-Hor"),
                         col.clst)
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/100_each/sub_label_color.tsv", row.names = F, col.names = F, sep="\t")

### Stage
sub_label <- sub$Stage
write.table(sub_label, "...zenodo/STREAM/100_each/sub_label_stage.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(levels(sub_label),
                         col.stg)
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/100_each/sub_label_color_stage.tsv",
            row.names = F, col.names = F, sep="\t")


## all cells %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
all_data <- seu@assays$integrated@data
write.table(all_data, "...zenodo/STREAM/All/all_data.tsv",
            row.names = T, sep="\t")


### Annotation
label <- seu$Annotation
write.table(label, "...zenodo/STREAM/All/all_label.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro","L-Hor"),
                         col.clst)
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/All/all_label_color.tsv", 
            row.names = F, col.names = F, sep="\t")

### Stage
label <- seu$Stage
write.table(label, "...zenodo/STREAM/All/all_label_stage.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(levels(sub_label),
                         col.stg)
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/All/all_label_color_stage.tsv", row.names = F, col.names = F, sep="\t")

### Study
label <- seu$Study
write.table(label, "...zenodo/STREAM/All/all_label_study.tsv", row.names = F, col.names = F, sep="\t")

sub_label_color <- cbind(levels(label),
                         col.std)
sub_label_color <- as.matrix(sub_label_color) 
write.table(sub_label_color, "...zenodo/STREAM/All/all_label_color_study.tsv", row.names = F, col.names = F, sep="\t")


## Development %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Idents(seu) <- "orig.ident"
sub <- subset(seu, idents = c("Embryonic_d16(G)", "Embryonic_d18(G)", "Postnatal_d4(G)", "Adult_1(G)", "Adult_2(G)",
                              "Puberty_1(P)", "Puberty_2(P)", "Adult(P)", "Nulliparous_1(B)", "Nulliparous_2(B)",
                              "OVX(S)"))
sub_meta <- sub@meta.data
sub_meta$Development <- as.character(sub_meta$Stage)
sub_meta$Development[sub_meta$orig.ident == "Embryonic_d16(G)"] <- "Embryonic(E16)"
sub_meta$Development[sub_meta$orig.ident == "Embryonic_d18(G)"] <- "Embryonic(E18)"
sub@meta.data <- sub_meta
sub$Development <- factor(sub$Development, levels=c("Embryonic(E16)", "Embryonic(E18)", "Neonatal","Pubertal", "Virgin adult", "Menopause" ))
UMAPPlot(sub, group.by="Development")

Idents(sub) <- "Development"

E16 <- sample(WhichCells(sub, idents="Embryonic(E16)"),500)
E18 <- sample(WhichCells(sub, idents="Embryonic(E18)"),500)
P4 <- sample(WhichCells(sub, idents="Neonatal"),500)
Puberty <- sample(WhichCells(sub, idents="Pubertal"),500)
Virgin <- sample(WhichCells(sub, idents="Virgin adult"),500)
Menopause <- sample(WhichCells(sub, idents="Menopause"),500, replace = T)

##
Dev <- subset(sub, cells=c(E16, E18, P4, Puberty, Virgin, Menopause))

sub_data <- Dev@assays$integrated@data
write.table(sub_data, "...zenodo/STREAM/Development/Dev_data.tsv",
            row.names = T, sep="\t")

sub_label <- Dev$Development
write.table(sub_label, "...zenodo/STREAM/Development/Dev_label.tsv", 
            row.names = F, col.names = F, sep="\t")

### Pregnancy %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Idents(seu) <- "orig.ident"
sub <- subset(seu, idents = c("Nulliparous_1(B)", "Nulliparous_2(B)", "Gestation_1(B)", "Gestation_2(B)", "Lactation_1(B)", "Lactation_2(B)", 
                              "PostInvolution_1(B)", "PostInvolution_2(B)"))
sub$Stage <- factor(sub$Stage, levels=c("Virgin adult", "Pregnant", "Lactating", "Involuted"))
UMAPPlot(sub, group.by="Stage")

Idents(sub) <- "Stage"

Virgin <- sample(WhichCells(sub, idents="Virgin adult"),500)
Pregnant <- sample(WhichCells(sub, idents="Pregnant"),500)
Lactating <- sample(WhichCells(sub, idents="Lactating"),500)
Involuted <- sample(WhichCells(sub, idents="Involuted"),500)

Preg <- subset(sub, cells=c(Virgin, Pregnant, Lactating, Involuted))

sub_data <- Preg@assays$integrated@data
write.table(sub_data, "...zenodo/STREAM/Pregnancy/Preg_data.tsv",
            row.names = T, sep="\t")

sub_label <- Preg$Stage
write.table(sub_label, "...zenodo/STREAM/Pregnancy/Preg_label.tsv", 
            row.names = F, col.names = F, sep="\t")



#########################################################################
######### Human STREAM data preparation #################################
#########################################################################
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
Idents(Nguyen) <- "orig.ident"
Cells_Ind4 <- sample(WhichCells(Nguyen, idents = "Ind4"), 1000)
Cells_Ind5 <- sample(WhichCells(Nguyen, idents = "Ind5"), 1000)
Cells_Ind6 <- sample(WhichCells(Nguyen, idents = "Ind6"), 1000)
Cells_Ind7 <- sample(WhichCells(Nguyen, idents = "Ind7"), 1000)
Cells_STREAM <- c(Cells_Ind4, Cells_Ind5, Cells_Ind6, Cells_Ind7)
saveRDS(Cells_STREAM, "...zenodo/STREAM/Human_cells_STREAM.rds")

##
Nguyen <- ScaleData(Nguyen, features = rownames(Nguyen))
Nguyen <- RunPCA(Nguyen, features = VariableFeatures(object = Nguyen))
Nguyen_STREAM <- subset(Nguyen, cells=Cells_STREAM)

###
mat <- t(Nguyen_STREAM@reductions$pca@cell.embeddings[,1:10])
write.table(mat, "...zenodo/STREAM/Human/data_pca.tsv",
            row.names = T, sep="\t")

label <- as.character(Sub_STREAM$clust)
write.table(label, "...zenodo/STREAM/Human/label.tsv", row.names = F, col.names = F, sep="\t")

label_color <- cbind(c("B/Myo", "L1.1/L1.2", "L2"),
                     c("#FF7F00","#33A02C","#E31A1C"))
label_color <- as.matrix(label_color) 
write.table(label_color, "...zenodo/STREAM/Human/label_color.tsv", row.names = F, col.names = F, sep="\t")

###
label <- as.character(Sub_STREAM$orig.ident)
write.table(label, "...zenodo/STREAM/Human/label_dataset.tsv", row.names = F, col.names = F, sep="\t")

label_color <- cbind(c("Ind4", "Ind5", "Ind6", "Ind7"),
                     c('#1b9e77','#d95f02','#7570b3','#e7298a'))
label_color <- as.matrix(label_color) 
write.table(label_color, "...zenodo/STREAM/Human/label_dataset_color.tsv", row.names = F, col.names = F, sep="\t")


###all
mat <- t(Nguyen@reductions$pca@cell.embeddings[,1:10])
write.table(mat, "...zenodo/STREAM/Human/data_all_pca.tsv",
            row.names = T, sep="\t")

label <- as.character(Nguyen$clust)
write.table(label, "...zenodo/STREAM/Human/label_all.tsv", row.names = F, col.names = F, sep="\t")

label_color <- cbind(c("B/Myo", "L1.1/L1.2", "L2"),
                     c("#FF7F00","#33A02C","#E31A1C"))
label_color <- as.matrix(label_color) 
write.table(label_color, "...zenodo/STREAM/Human/label_color_all.tsv", row.names = F, col.names = F, sep="\t")


###
label <- as.character(Nguyen$orig.ident)
write.table(label, "...zenodo/STREAM/Human/label_all_dataset.tsv", row.names = F, col.names = F, sep="\t")

label_color <- cbind(c("Ind4", "Ind5", "Ind6", "Ind7"),
                     c('#1b9e77','#d95f02','#7570b3','#e7298a'))
label_color <- as.matrix(label_color) 
write.table(label_color, "...zenodo/STREAM/Human/label_dataset_color_all.tsv", row.names = F, col.names = F, sep="\t")




