# TCGA_processing



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}



########################################################################
###### Data retirieval #################################################
########################################################################
query.BRCA <- GDCquery(project = "TCGA-BRCA", 
                       data.category = "Transcriptome Profiling", 
                       data.type = "Gene Expression Quantification", 
                       workflow.type = "HTSeq - FPKM-UQ",
                       sample.type = c("Primary solid Tumor","Solid Tissue Normal"))

GDCdownload(query.BRCA, directory = "...your_folder/TCGA")
brca.exp <- GDCprepare(query = query.BRCA, summarizedExperiment = T, 
                       directory = "...your_folder/TCGA",
                       save = T, save.filename = "...zenodo/TCGA/brca.exp.rd")



########################################################################
###### Data processing #################################################
########################################################################
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode

Exp <- assay(data)

row <- rowData(data)
geneData <- row@listData
row.names(Exp) <- geneData$external_gene_name

# Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
# Genes <- row.names(Nguyen@assays$RNA)
# saveRDS(Genes, "...zenodo/Others/human_genes.rds")
Genes <- readRDS("...zenodo/Others/human_genes.rds")
Sub_exp <- Exp[row.names(Exp) %in% Genes,]



########################################################################
###### GSVA ############################################################
########################################################################
Curated_stem <-  readRDS("...zenodo/GSVA/Human/Curated_Stem(m2h).rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Human/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Human/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Human/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Curated_stem$`Curated_Stem(m2h)`, Basal_gene_sets$Top_Basal_1000, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_240)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Curated_stem, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

BRCA_gsvaResult <- gsva(Sub_exp, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
BRCA_gsvaResult <- t(BRCA_gsvaResult)
write.csv(BRCA_gsvaResult, "...zenodo/TCGA/TCGA_GSVA.csv")



########################################################################
###### Stromal Percentage ##############################################
########################################################################
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
portion_ID <- substr(sampleData$barcode, 1, 19)
tumor_portion_ID <- portion_ID[sampleData$shortLetterCode == "TP"]

## Slide information was retrieved from GDC and modified
slide <- read.table("...zenodo/TCGA/slide_modified.txt", header=T)
slide$portion_submitter_id <- as.character(slide$portion_submitter_id)
slide <- slide[slide$portion_submitter_id %in% tumor_portion_ID,]
stroma <- slide[,c("portion_submitter_id", "percent_stromal_cells", "percent_tumor_cells", "section_location")]
stroma <- na.omit(stroma)
range(stroma$percent_tumor_cells)

unique_ID <- unique(stroma$portion_submitter_id)
hoge <- NULL


for(i in 1:length(unique_ID)){       
  hoge <- rbind(hoge, apply(stroma[which(stroma$portion_submitter_id == unique_ID[i]), 2:3], 2, mean, na.rm=TRUE))
}                                      
rownames(hoge) <- unique_ID   

stroma_unique <- as.data.frame(hoge)
stroma_unique$portion <- row.names(stroma_unique)


###
df <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)
meta <- meta[row.names(df),]
df <- data.frame(df, meta)

df$portion <- substr(row.names(df), 1, 19)
df$barcode <- row.names(df)
df <- df[df$Tissue == "TP",]

Merged <- merge(df, stroma_unique, by.x="portion", by.y="portion")
Merged <- na.omit(Merged)

write.csv(Merged, "...zenodo/TCGA/Merged_stroma.csv")
