# scBRCA



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}


########################################################################
###### Data preparation ################################################
########################################################################
# GSE75688
expr <- read.table("...zenodo/scBRCA/GSE75688_GEO_processed_Breast_Cancer_raw_TPM_matrix.txt", header=T)
expr <- expr[expr$gene_type == "protein_coding",]
expr <- expr[!duplicated(expr$gene_name),]
row.names(expr) <- expr$gene_name

metadata <- read.table("...zenodo/scBRCA/GSE75688_final_sample_information.txt", header=T)
metadata <- metadata[metadata$type == "SC",]

expr <- expr[, colnames(expr) %in% metadata$sample]

pt <- str_sub(metadata$sample, 1, 4)
metadata$patient <- pt
tissue <- grepl("LN", metadata$sample)
metadata$tissue[tissue] <- "LN"
metadata$tissue[!tissue] <- "Primary"

rownames(metadata) <- metadata$sample

metadata$Subtype[metadata$patient == "BC01" | metadata$patient == "BC02"] <- "LumA"
metadata$Subtype[metadata$patient == "BC03"] <- "LumB"
metadata$Subtype[metadata$patient == "BC04" | metadata$patient == "BC05"| metadata$patient == "BC06"] <- "HER2"
metadata$Subtype[metadata$patient == "BC07" | metadata$patient == "BC08"| metadata$patient == "BC09"|
                   metadata$patient == "BC10"| metadata$patient == "BC11"] <- "TNBC"

### build Seurat object & QC####
HBC <- CreateSeuratObject(expr, meta.data = metadata, min.cells = 3, min.features = 200)
HBC[["percent.mt"]] <- PercentageFeatureSet(HBC, pattern = "^MT-")
p1 <- VlnPlot(HBC, "percent.mt", group.by = "patient")+NoLegend()
p2 <- VlnPlot(HBC, "nCount_RNA", group.by = "patient")+NoLegend()
p3 <- VlnPlot(HBC, "nFeature_RNA", group.by = "patient")+NoLegend()
plot_grid(p1, p2, p3, ncol=3)


### Subset tumor cells ####
Idents(HBC) <- "index3"
sub <- subset(HBC, idents = "Tumor")

sub <- NormalizeData(sub)
sub <- FindVariableFeatures(sub, selection.method = "vst", nfeatures = 2000)
all.genes <- rownames(sub)
sub <- ScaleData(sub, features = all.genes)
sub <- RunPCA(sub, features = VariableFeatures(object = sub))
ElbowPlot(sub)

sub <- RunUMAP(sub, dims = 1:5)
sub <- FindNeighbors(sub, dims = 1:5)
sub <- FindClusters(sub, resolution = 0.5)


saveRDS(sub, "...zenodo/scBRCA/HBC_tumor.rds")