# Supplementary fig 10



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  



#######################################################################################
###### SFig 10A ########################################################################
#######################################################################################
#
cor_all <- read.csv("...zenodo/GSVA/Mouse/cor_all_pseudotime_ranked_annotated.csv", row.names = 1)
cor_temp <- cbind(cor_all[, c(grep("S4", colnames(cor_all)))], cor_all$category)
colnames(cor_temp)[8] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data <- cor_temp[cor_temp$S4_rank %in% c(5, 11, 22, 36, 22534, 22540)|
                         cor_temp$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data) <- paste(label_data$S4_rank, row.names(label_data), sep=".")
Sfig10A <- ggplot(cor_temp, aes(x=S4_rank, y=S4_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data, aes(x=S4_rank, y=S4_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data, S4_mean > 0.15),
    aes(label=row.names(subset(label_data, S4_mean > 0.15))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data, S4_mean < -0.15),
    aes(label=row.names(subset(label_data, S4_mean < -0.15))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_temp)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 5 studies)") +
  ggtitle("Feature correlation with S4_pseudotime (Basal)") +
  guides(color=F)



#######################################################################################
###### SFig 10B ########################################################################
#######################################################################################
#
cor_all <- read.csv("...zenodo/GSVA/Mouse/cor_all_pseudotime_ranked_annotated.csv", row.names = 1)
cor_temp <- cbind(cor_all[, c(grep("S2", colnames(cor_all)))], cor_all$category)
colnames(cor_temp)[8] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data <- cor_temp[cor_temp$S2_rank %in% c(2,3,13,22541,22546)|
                         cor_temp$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data) <- paste(label_data$S2_rank, row.names(label_data), sep=".")
Sfig10B <- ggplot(cor_temp, aes(x=S2_rank, y=S2_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data, aes(x=S2_rank, y=S2_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data, S2_mean > 0.15),
    aes(label=row.names(subset(label_data, S2_mean > 0.15))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data, S2_mean < -0.15),
    aes(label=row.names(subset(label_data, S2_mean < -0.15))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_temp)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 5 studies)") +
  ggtitle("Feature correlation with S2_pseudotime (Alv)") +
  guides(color=F)



#######################################################################################
###### SFig 10C ########################################################################
#######################################################################################
#
cor_all <- read.csv("...zenodo/GSVA/Mouse/cor_all_pseudotime_ranked_annotated.csv", row.names = 1)
cor_temp <- cbind(cor_all[, c(grep("S1", colnames(cor_all)))], cor_all$category)
colnames(cor_temp)[8] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data <- cor_temp[cor_temp$S1_rank %in% c(9,12,13,14, 22544, 22547, 22549)|
                         cor_temp$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data) <- paste(label_data$S1_rank, row.names(label_data), sep=".")
Sfig10C <- ggplot(cor_temp, aes(x=S1_rank, y=S1_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data, aes(x=S1_rank, y=S1_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data, S1_mean > 0.2),
    aes(label=row.names(subset(label_data, S1_mean > 0.2))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data, S1_mean < -0.2),
    aes(label=row.names(subset(label_data, S1_mean < -0.2))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_temp)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 5 studies)") +
  ggtitle("Feature correlation with S1_pseudotime (Hor)") +
  guides(color=F)



#######################################################################################
###### SFig 10D ########################################################################
#######################################################################################
Mouse_res_meta <- read.csv("...zenodo/GSVA/Mouse/Mouse_res_meta.csv", row.names = 1)
meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)
Mouse_res_meta$Annotation <- factor(Mouse_res_meta$Annotation,
                                    levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Mouse_res_meta$Study <- factor(Mouse_res_meta$Study,
                               levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
meta <- meta[row.names(Mouse_res_meta),]
Mouse_res <- cbind(Mouse_res_meta, meta)


p1 <- ggplot(Mouse_res, aes(x=S5_pseudotime, y=Curated_Stem))+
  geom_point(aes(col=Annotation))+
  scale_color_manual(values = col.clst)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Stem Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p2 <- ggplot(Mouse_res, aes(x=S5_pseudotime, y=Curated_Stem))+
  geom_point(aes(col=Study))+
  scale_color_manual(values = col.std)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Stem Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p3 <- ggplot(Mouse_res, aes(x=S4_pseudotime, y=Curated_Basal))+
  geom_point(aes(col=Annotation))+
  scale_color_manual(values = col.clst)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Basal Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p4 <- ggplot(Mouse_res, aes(x=S4_pseudotime, y=Curated_Basal))+
  geom_point(aes(col=Study))+
  scale_color_manual(values = col.std)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Basal Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p5 <- ggplot(Mouse_res, aes(x=S2_pseudotime, y=Curated_Alv))+
  geom_point(aes(col=Annotation))+
  scale_color_manual(values = col.clst)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Alv Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p6 <- ggplot(Mouse_res, aes(x=S2_pseudotime, y=Curated_Alv))+
  geom_point(aes(col=Study))+
  scale_color_manual(values = col.std)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Alv Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p7 <- ggplot(Mouse_res, aes(x=S1_pseudotime, y=Curated_Hor))+
  geom_point(aes(col=Annotation))+
  scale_color_manual(values = col.clst)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Hor Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p8 <- ggplot(Mouse_res, aes(x=S1_pseudotime, y=Curated_Hor))+
  geom_point(aes(col=Study))+
  scale_color_manual(values = col.std)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("GSVA score")+
  ggtitle("Curated Hor Gene Sets")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

Sfig10D <- plot_grid(p1, p2, p3, p4, p5, p6, p7, p8, ncol = 2, align='hv')

