# Supplementary fig 11



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C") 

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}


#######################################################################
############## Supplementary fig11A ###################################
#######################################################################
Mouse_res_meta <- read.csv("...zenodo/GSVA/Mouse/Mouse_res_meta.csv", row.names = 1)
Mouse_res_meta$Annotation <- factor(Mouse_res_meta$Annotation,
                                    levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Mouse_res_meta$Study <- factor(Mouse_res_meta$Study,
                               levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))

## Base trajectory
Giraddi_res <- Mouse_res_meta[Mouse_res_meta$Study == "Giraddi",]
data <- Giraddi_res[,1:4]
data.umap <- umap(data[,2:4], verbose=T)

saveRDS(data.umap, "...zenodo/UMAP/Mouse_base_umap_3d.rds")

## All data
data_all <- Mouse_res_meta[,2:4]
All.umap <- predict(data.umap, data_all)
write.csv(All.umap, "...zenodo/UMAP/Mouse_all_umap_3dim.csv")

#
All.umap <- as.data.frame(All.umap)
p1 <- ggplot(All.umap, aes(x=V1, y=V2, col=Mouse_res_meta$Annotation))+
  geom_point(size=1)+
  scale_color_manual(values=col.clst)+ 
  labs(col = "Cluster")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  ggtitle("All data (by cluster)")+
  theme_classic()+
  NoLegend()+
  theme(plot.title = element_text(size=24, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title=element_text(size=12,face="bold"),)

p2 <- ggplot(All.umap, aes(x=V1, y=V2, col=Mouse_res_meta$Study))+
  geom_point(size=1)+
  scale_color_manual(values=col.std)+ 
  labs(col = "Cluster")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  ggtitle("All data (by study)")+
  theme_classic()+
  NoLegend()+
  theme(plot.title = element_text(size=24, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title=element_text(size=12,face="bold"),)

Sfig11A <- plot_grid(p1, p2, ncol=2)



#######################################################################
############## Supplementary fig11B ###################################
#######################################################################
Mouse_res_meta <- read.csv("...zenodo/GSVA/Mouse/Mouse_res_meta.csv", row.names = 1)
Mouse_res_meta$Annotation <- factor(Mouse_res_meta$Annotation,
                                    levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Mouse_res_meta$Study <- factor(Mouse_res_meta$Study,
                               levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
colnames(Mouse_res_meta)[1:4] <- c("Stem", "Basal", "Alv", "Hor")

##
Mouse_res_meta$Stem <- range01(Mouse_res_meta$Stem)
Mouse_res_meta$Basal <- range01(Mouse_res_meta$Basal)
Mouse_res_meta$Alv <- range01(Mouse_res_meta$Alv)
Mouse_res_meta$Hor <- range01(Mouse_res_meta$Hor)

##
Sfig11B <- ggtern(data=Mouse_res_meta,aes(Basal,Alv,Hor))+
  geom_point(aes(color=Annotation), alpha=0.5)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = col.clst)+
  ggtitle("Visualization by ternary plot")+
  facet_wrap(.~Study, ncol=3)



#######################################################################
############## Supplementary fig11C ###################################
#######################################################################
Mouse_res_meta <- read.csv("...zenodo/GSVA/Mouse/Mouse_res_meta.csv", row.names = 1)
Mouse_res_meta$Annotation <- factor(Mouse_res_meta$Annotation,
                                    levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Mouse_res_meta$Study <- factor(Mouse_res_meta$Study,
                               levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))

##
p1 <- ggplot(Mouse_res_meta, aes(x=Annotation, y=Curated_Stem, fill=Annotation))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = col.clst)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Stem gene set")+
  labs(fill="Cluster")

p2 <- ggplot(Mouse_res_meta, aes(x=Annotation, y=Curated_Basal, fill=Annotation))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = col.clst)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal gene set")+
  labs(fill="Cluster")

p3 <- ggplot(Mouse_res_meta, aes(x=Annotation, y=Curated_Alv, fill=Annotation))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = col.clst)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Alv gene set")+
  labs(fill="Cluster")

p4 <- ggplot(Mouse_res_meta, aes(x=Annotation, y=Curated_Hor, fill=Annotation))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = col.clst)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Hor gene set")+
  labs(fill="Cluster")

SFig11C <- plot_grid(p1,p2,p3,p4, ncol=2, align = "hv")

