# Supplementary fig 12



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")



##########################################################################################
#################### Data preparation ####################################################
##########################################################################################

### See "...zenodo/Processing_Analysis/Human_sample_preprocessing.R" to prepare the data.

Ind4 <- readRDS("...zenodo/Human_normal_breast_data/Ind4/Ind4_cleaned.rds")
Ind5 <- readRDS("...zenodo/Human_normal_breast_data/Ind5/Ind5_cleaned.rds")
Ind6 <- readRDS("...zenodo/Human_normal_breast_data/Ind6/Ind6_cleaned.rds")
Ind7 <- readRDS("...zenodo/Human_normal_breast_data/Ind7/Ind7_cleaned.rds")

Nguyen <- merge(Ind4, y = c(Ind5, Ind6, Ind7), 
                add.cell.ids = NULL, project = "Nguyen")


Pred_ind4 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind4.csv", row.names = 1)
Pred_ind5 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind5.csv", row.names = 1)
Pred_ind6 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind6.csv", row.names = 1)
Pred_ind7 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind7.csv", row.names = 1)
Prediction <- rbind(Pred_ind4, Pred_ind5, Pred_ind6, Pred_ind7)

Nguyen <- AddMetaData(Nguyen, metadata=Prediction)



##########################################################################################
#################### Supplementary fig 12A ###############################################
##########################################################################################
Ind5 <- AddMetaData(Ind5, Pred_ind5)
Ind5 <- NormalizeData(Ind5)
Ind5 <- FindVariableFeatures(Ind5, selection.method = "vst", nfeatures = 2000)
Ind5 <- ScaleData(Ind5, features = rownames(Ind5))
Ind5 <- RunPCA(Ind5, features = VariableFeatures(object = Ind5))
Ind5 <- RunUMAP(Ind5, dims=1:10)
Ind5 <- FindNeighbors(Ind5, dims = 1:10)
Ind5 <- FindClusters(Ind5, resolution = 0.3)

Ind5$predicted.id <- factor(Ind5$predicted.id, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))


FP <- wes_palette("Zissou1", 5, type = "discrete")

p1 <- FeaturePlot(Ind5, "KRT14", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
p2 <- FeaturePlot(Ind5, "KRT18", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))

p3 <- FeaturePlot(Ind5, "SLPI", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
p4 <- FeaturePlot(Ind5, "ANKRD30A", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))
Sfig11A_2 <- plot_grid(p1, p2, p3, p4, align='hv')


p5 <- UMAPPlot(Ind5, group.by="clust", cols=col.human, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind5_Definitive annotation")

p6 <- UMAPPlot(Ind5, group.by="predicted.id", cols=col.clst, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind5_Transferred annotation")

Sfig12A_1 <- plot_grid(p5, p6, align='hv', ncol=1)



##########################################################################################
#################### Supplementary fig 12B ###############################################
##########################################################################################
###
Ind4 <- AddMetaData(Ind4, Pred_ind4)
Ind4 <- NormalizeData(Ind4)
Ind4 <- FindVariableFeatures(Ind4, selection.method = "vst", nfeatures = 2000)
Ind4 <- ScaleData(Ind4, features = rownames(Ind4))
Ind4 <- RunPCA(Ind4, features = VariableFeatures(object = Ind4))
Ind4 <- RunUMAP(Ind4, dims=1:10)
Ind4 <- FindNeighbors(Ind4, dims = 1:10)
Ind4 <- FindClusters(Ind4, resolution = 0.3)

Ind4$predicted.id <- factor(Ind4$predicted.id, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))

p1 <- UMAPPlot(Ind4, group.by="clust", cols=col.human, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind4_Definitive annotation")

p2 <- UMAPPlot(Ind4, group.by="predicted.id", cols=col.clst, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind4_Transferred annotation")


###
Ind7 <- AddMetaData(Ind7, Pred_ind7)
Ind7 <- NormalizeData(Ind7)
Ind7 <- FindVariableFeatures(Ind7, selection.method = "vst", nfeatures = 2000)
Ind7 <- ScaleData(Ind7, features = rownames(Ind7))
Ind7 <- RunPCA(Ind7, features = VariableFeatures(object = Ind7))
Ind7 <- RunUMAP(Ind7, dims=1:10)
Ind7 <- FindNeighbors(Ind7, dims = 1:10)
Ind7 <- FindClusters(Ind7, resolution = 0.3)

Ind7$predicted.id <- factor(Ind7$predicted.id, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))

p3 <- UMAPPlot(Ind7, group.by="clust", cols=col.human, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind7_Definitive annotation")

p4 <- UMAPPlot(Ind7, group.by="predicted.id", cols=col.clst, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Ind7_Transferred annotation")

###
Sfig12B <- plot_grid(p1, p2, p3, p4, ncol=2, align='hv')



##########################################################################################
#################### Supplementary fig 12C ################################################
##########################################################################################
stat <- as.data.frame(table(Nguyen$clust, Nguyen$predicted.id, Nguyen$orig.ident))
colnames(stat) <- c("Definitive", "Transferred", "Individual", "Number")
stat$Transferred <- factor(stat$Transferred, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))

Sfig12C <- ggplot() + 
  geom_bar(aes(y = Number, x = Definitive, fill = Transferred), position = "fill", data = stat, stat="identity")+
  facet_grid(.~Individual)+
  scale_fill_manual(values = col.clst)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"),
        legend.text = element_text(size=14),
        legend.title = element_text(size=14,face="bold"),
        strip.text.x = element_text(size=16,face="bold"))+
  xlab("Definitive annotation")+
  ylab("Proportion")+ 
  labs(fill = "Transferred")+
  ggtitle("Human breast epithelium (Nguyen et al.)")

