# Supplementary fig 13



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")



##########################################################################################
#################### Supplementary fig 13A ###############################################
##########################################################################################

### See "...zenodo/Processing_Analysis/Human_sample_preprocessing.R" to prepare the data.

Ind4 <- readRDS("...zenodo/Human_normal_breast_data/Ind4/Ind4_cleaned.rds")
Ind5 <- readRDS("...zenodo/Human_normal_breast_data/Ind5/Ind5_cleaned.rds")
Ind6 <- readRDS("...zenodo/Human_normal_breast_data/Ind6/Ind6_cleaned.rds")
Ind7 <- readRDS("...zenodo/Human_normal_breast_data/Ind7/Ind7_cleaned.rds")

Nguyen <- merge(Ind4, y = c(Ind5, Ind6, Ind7), 
                add.cell.ids = NULL, project = "Nguyen")

Pred_ind4 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind4.csv", row.names = 1)
Pred_ind5 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind5.csv", row.names = 1)
Pred_ind6 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind6.csv", row.names = 1)
Pred_ind7 <- read.csv("...zenodo/Human_normal_breast_data/Predicted_annotation_ind7.csv", row.names = 1)
Prediction <- rbind(Pred_ind4, Pred_ind5, Pred_ind6, Pred_ind7)

Nguyen <- AddMetaData(Nguyen, metadata=Prediction)

Nguyen <- NormalizeData(Nguyen)
Nguyen <- FindVariableFeatures(Nguyen, selection.method = "vst", nfeatures = 2000)
Nguyen <- ScaleData(Nguyen, features = rownames(Nguyen))
Nguyen <- RunPCA(Nguyen, features = VariableFeatures(object = Nguyen))
Nguyen <- RunUMAP(Nguyen, dims=1:10)

p1 <- UMAPPlot(Nguyen, group.by="orig.ident", pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Individual")

p2 <- UMAPPlot(Nguyen, group.by="clust", cols=col.human, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Definitive annotation")

Sfig13A <- plot_grid(p1, p2, align='hv', ncol=1)



##########################################################################################
#################### Supplementary fig 13B ###############################################
##########################################################################################
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
Nguyen$predicted.id <- factor(Nguyen$predicted.id,
                              levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Cytotrace <- read.csv("...zenodo/CytoTRACE/Human_CytoTRACE_score.csv",
                      row.names = 1)
Nguyen <- ScaleData(Nguyen, features = rownames(Nguyen))
Nguyen <- RunPCA(Nguyen, features = VariableFeatures(object = Nguyen))
Nguyen <- RunUMAP(Nguyen, dims = 1:10)


p1 <- UMAPPlot(Nguyen, group.by="orig.ident", pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Individual")

p2 <- UMAPPlot(Nguyen, group.by="clust", cols=col.human, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Definitive annotation")

p3 <- UMAPPlot(Nguyen, group.by="predicted.id", cols=col.clst, pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Transferred annotation")


sub <- subset(Nguyen, cells=row.names(Cytotrace))
sub <- AddMetaData(sub, Cytotrace)

p4 <- FeaturePlot(sub, "CytoTRACE", cols=viridis_pal()(100), min.cutoff = "q10", max.cutoff = "q90", pt.size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14,face="bold"),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("CytoTRACE score")

Sfig13B <- plot_grid(p1,p2,p3,p4, ncol=2, align='hv')



##########################################################################################
#################### Supplementary fig 13C ###############################################
##########################################################################################
## Refer to "...zenodo/STREAM/Human_all_output/"


##########################################################################################
#################### Supplementary fig 13D ###############################################
##########################################################################################
## Refer to "...zenodo/STREAM/Human_all_output/"


##########################################################################################
#################### Supplementary fig 13E ###############################################
##########################################################################################
cor_GSVA_Stem <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Stem.csv")
cor_GSVA_Basal <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Basal.csv")
cor_GSVA_Alv <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Alv.csv")
cor_GSVA_Hor <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Hor.csv")

colnames(cor_GSVA_Stem)[1] <- "Ind"
colnames(cor_GSVA_Stem)[2:101] <- 1:100
temp_stem <- melt(cor_GSVA_Stem, id="Ind", measure = colnames(cor_GSVA_Stem)[2:101])
temp_stem$value <- -1 * temp_stem$value
temp_stem$variable <- as.numeric(temp_stem$variable)
temp_stem$Category <- rep("Stem", length(row.names(temp_stem)))

colnames(cor_GSVA_Basal)[1] <- "Ind"
colnames(cor_GSVA_Basal)[2:101] <- 1:100
temp_Basal <- melt(cor_GSVA_Basal, id="Ind", measure = colnames(cor_GSVA_Basal)[2:101])
temp_Basal$value <- -1 * temp_Basal$value
temp_Basal$variable <- as.numeric(temp_Basal$variable)
temp_Basal$Category <- rep("Basal", length(row.names(temp_Basal)))

colnames(cor_GSVA_Alv)[1] <- "Ind"
colnames(cor_GSVA_Alv)[2:101] <- 1:100
temp_Alv <- melt(cor_GSVA_Alv, id="Ind", measure = colnames(cor_GSVA_Alv)[2:101])
temp_Alv$value <- -1 * temp_Alv$value
temp_Alv$variable <- as.numeric(temp_Alv$variable)
temp_Alv$Category <- rep("Alv", length(row.names(temp_Alv)))

colnames(cor_GSVA_Hor)[1] <- "Ind"
colnames(cor_GSVA_Hor)[2:101] <- 1:100
temp_Hor <- melt(cor_GSVA_Hor, id="Ind", measure = colnames(cor_GSVA_Hor)[2:101])
temp_Hor$value <- -1 * temp_Hor$value
temp_Hor$variable <- as.numeric(temp_Hor$variable)
temp_Hor$Category <- rep("Hor", length(row.names(temp_Hor)))

df <- rbind(temp_stem, temp_Basal, temp_Alv, temp_Hor)
cols <- c(wes_palette("IsleofDogs1", 1),"#FF7F00","#33A02C","#E31A1C")
df$Category <- factor(df$Category, levels = c("Stem", "Basal", "Alv", "Hor"))

###
cor_GSVA_Stem <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Stem_1000.csv")
cor_GSVA_Basal <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Basal_1000.csv")
cor_GSVA_Alv <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Alv_1000.csv")
cor_GSVA_Hor <- read.csv("...zenodo/GSVA/Human/cor_GSVA_Hor_1000.csv")

coln <- seq(120, 1000, 20)

colnames(cor_GSVA_Stem)[1] <- "Ind"
colnames(cor_GSVA_Stem)[2:46] <- coln
temp_stem <- melt(cor_GSVA_Stem, id="Ind", measure = colnames(cor_GSVA_Stem)[2:46])
temp_stem$value <- -1 * temp_stem$value
temp_stem$variable <- as.numeric(temp_stem$variable)
temp_stem$Category <- rep("Stem", length(row.names(temp_stem)))

colnames(cor_GSVA_Basal)[1] <- "Ind"
colnames(cor_GSVA_Basal)[2:46] <- coln
temp_Basal <- melt(cor_GSVA_Basal, id="Ind", measure = colnames(cor_GSVA_Basal)[2:46])
temp_Basal$value <- -1 * temp_Basal$value
temp_Basal$variable <- as.numeric(temp_Basal$variable)
temp_Basal$Category <- rep("Basal", length(row.names(temp_Basal)))

colnames(cor_GSVA_Alv)[1] <- "Ind"
colnames(cor_GSVA_Alv)[2:46] <- coln
temp_Alv <- melt(cor_GSVA_Alv, id="Ind", measure = colnames(cor_GSVA_Alv)[2:46])
temp_Alv$value <- -1 * temp_Alv$value
temp_Alv$variable <- as.numeric(temp_Alv$variable)
temp_Alv$Category <- rep("Alv", length(row.names(temp_Alv)))

colnames(cor_GSVA_Hor)[1] <- "Ind"
colnames(cor_GSVA_Hor)[2:46] <- coln
temp_Hor <- melt(cor_GSVA_Hor, id="Ind", measure = colnames(cor_GSVA_Hor)[2:46])
temp_Hor$value <- -1 * temp_Hor$value
temp_Hor$variable <- as.numeric(temp_Hor$variable)
temp_Hor$Category <- rep("Hor", length(row.names(temp_Hor)))

df2 <- rbind(temp_stem, temp_Basal, temp_Alv, temp_Hor)
cols <- c(wes_palette("IsleofDogs1", 1),"#FF7F00","#33A02C","#E31A1C")
df2$Category <- factor(df2$Category, levels = c("Stem", "Basal", "Alv", "Hor"))
df2$variable <- rep(coln, each=4)
df3 <- rbind(df,df2)



p1 <- ggplot(df3[df3$Category=="Stem",], aes(x=variable, y=value))+
  geom_smooth(col=wes_palette("IsleofDogs1", 1))+
  geom_point(aes(color=Ind))+
  ggtitle("GSVA_Stem_gene_sets")
p2 <- ggplot(df3[df3$Category=="Basal",], aes(x=variable, y=value))+
  geom_smooth(col="#FF7F00")+
  geom_point(aes(color=Ind))+
  ggtitle("GSVA_Basal_gene_sets")
p3 <- ggplot(df3[df3$Category=="Alv",], aes(x=variable, y=value))+
  geom_smooth(col="#33A02C")+
  geom_point(aes(color=Ind))+
  ggtitle("GSVA_Alv_gene_sets")
p4 <- ggplot(df3[df3$Category=="Hor",], aes(x=variable, y=value))+
  geom_smooth(col="#E31A1C")+
  geom_point(aes(color=Ind))+
  ggtitle("GSVA_Hor_gene_sets")
Sfig13E <- plot_grid(p2,p3,p4, ncol=3, align='hv')



#######################################################################################
###### SFig 13F #######################################################################
#######################################################################################
cor_all <- read.csv("...zenodo/GSVA/Human/cor_all_pseudotime_ranked_annotated.csv", row.names = 1)

### S3
cor_temp <- cbind(cor_all[, c(grep("S3", colnames(cor_all)))], cor_all$category)
colnames(cor_temp)[7] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data_S3 <- cor_temp[cor_temp$S3_rank %in% c(2, 13.5, 15)|
                         cor_temp$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data_S3) <- paste(label_data_S3$S3_rank, row.names(label_data_S3), sep=".")
p1 <- ggplot(cor_temp, aes(x=S3_rank, y=S3_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_S3, aes(x=S3_rank, y=S3_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data_S3, S3_mean > 0.2),
    aes(label=row.names(subset(label_data_S3, S3_mean > 0.2))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data_S3, S3_mean < -0.2),
    aes(label=row.names(subset(label_data_S3, S3_mean < -0.2))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_temp)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 4 individuals)") +
  ggtitle("Feature correlation with S3_pseudotime (Stem)") +
  guides(color=F)


###S4
cor_temp <- cbind(cor_all[, c(grep("S4", colnames(cor_all)))], cor_all$category)
colnames(cor_temp)[7] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data_S4 <- cor_temp[cor_temp$S4_rank %in% c(1, 3, 6, 9, 22561)|
                         cor_temp$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data_S4) <- paste(label_data_S4$S4_rank, row.names(label_data_S4), sep=".")
p2 <- ggplot(cor_temp, aes(x=S4_rank, y=S4_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_S4, aes(x=S4_rank, y=S4_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data_S4, S4_mean > 0.2),
    aes(label=row.names(subset(label_data_S4, S4_mean > 0.2))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data_S4, S4_mean < -0.2),
    aes(label=row.names(subset(label_data_S4, S4_mean < -0.2))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_temp)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 4 individuals)") +
  ggtitle("Feature correlation with S4_pseudotime (Basal)") +
  guides(color=F)


###S2
cor_temp <- cbind(cor_all[, c(grep("S2", colnames(cor_all)))], cor_all$category)
colnames(cor_temp)[7] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data_S2 <- cor_temp[cor_temp$S2_rank %in% c(4, 9, 22561)|
                         cor_temp$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data_S2) <- paste(label_data_S2$S2_rank, row.names(label_data_S2), sep=".")
p3 <- ggplot(cor_temp, aes(x=S2_rank, y=S2_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_S2, aes(x=S2_rank, y=S2_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data_S2, S2_mean > 0.2),
    aes(label=row.names(subset(label_data_S2, S2_mean > 0.2))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data_S2, S2_mean < -0.2),
    aes(label=row.names(subset(label_data_S2, S2_mean < -0.2))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_temp)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 4 individuals)") +
  ggtitle("Feature correlation with S2_pseudotime (Alv)") +
  guides(color=F)


###S1
cor_temp <- cbind(cor_all[, c(grep("S1", colnames(cor_all)))], cor_all$category)
colnames(cor_temp)[7] <- "category"  

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 22000, 2000), zero = 0)
tick_y <- length(rownames(cor_all))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

label_data_S1 <- cor_temp[cor_temp$S1_rank %in% c(3, 7, 32)|
                         cor_temp$category %in% c("Curated", "Biological", "CytoTRACE"),] 
row.names(label_data_S1) <- paste(label_data_S1$S1_rank, row.names(label_data_S1), sep=".")
p4 <- ggplot(cor_temp, aes(x=S1_rank, y=S1_mean))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_S1, aes(x=S1_rank, y=S1_mean, color=category), size=2)+
  geom_text_repel(
    data          = subset(label_data_S1, S1_mean > 0.2),
    aes(label=row.names(subset(label_data_S1, S1_mean > 0.2))),
    nudge_x       = 5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0,
    fontface      = "bold"
  ) +
  geom_text_repel(
    data          = subset(label_data_S1, S1_mean < -0.2),
    aes(label=row.names(subset(label_data_S1, S1_mean < -0.2))),
    nudge_x       = -5000,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1,
    fontface      = "bold"
  )+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = length(rownames(cor_temp)), 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  xlab("Features by ranking")+
  ylab("Correlation with pseudotime \n (Averaged value from 4 individuals)") +
  ggtitle("Feature correlation with S1_pseudotime (Hor)") +
  guides(color=F)

Sfig13F <- plot_grid(p2,p3,p4, ncol=3, align='hv')

