# Supplementary fig 14



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}



#######################################################################
############ SFig. 14A    #############################################
#######################################################################
Normal <- read.csv("...zenodo/GSVA/Human/Normal_breast_GSVA.csv", row.names=1)
data.umap <- readRDS("...zenodo/UMAP/Human_normal_breast_umap.rds")

temp <- as.data.frame(data.umap$layout)


q1 <- ggplot(temp, aes(x=V1, y=V2, col=Normal$Curated_Stem))+
  geom_point(size=1)+ 
  labs(col = "Score")+
  xlab("UMAP1")+
  ylab("UMAP2")+ 
  scale_color_gradient2(midpoint = 0, low = "grey24", mid = "lightgrey",
                        high = "#ad2dfe")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("GSVA(Stem)")
q2 <- ggplot(temp, aes(x=V1, y=V2, col=Normal$Curated_Basal))+
  geom_point(size=1)+ 
  labs(col = "Score")+
  xlab("UMAP1")+
  ylab("UMAP2")+ 
  scale_color_gradient2(midpoint = -0.1, low = "grey24", mid = "lightgrey",
                        high = "#FF7F00")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("GSVA(Basal)")
q3 <- ggplot(temp, aes(x=V1, y=V2, col=Normal$Curated_Alv))+
  geom_point(size=1)+ 
  labs(col = "Score")+
  xlab("UMAP1")+
  ylab("UMAP2")+ 
  scale_color_gradient2(midpoint = -0.05, low = "grey24", mid = "lightgrey",
                        high = "#33A02C")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("GSVA(Alv)")
q4 <- ggplot(temp, aes(x=V1, y=V2, col=Normal$Curated_Hor))+
  geom_point(size=1)+ 
  labs(col = "Score")+
  xlab("UMAP1")+
  ylab("UMAP2")+ 
  scale_color_gradient2(midpoint = 0.1, low = "grey24", mid = "lightgrey",
                        high = "#E31A1C")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("GSVA(Hor)")
Sfig14A <- plot_grid(q1, q2, q3, q4, align='hv', ncol=2)



#######################################################################
############ SFig. 14B    #############################################
#######################################################################
Normal <- read.csv("...zenodo/GSVA/Human/Normal_breast_GSVA.csv", row.names=1)
data.umap <- readRDS("...zenodo/UMAP/Human_normal_breast_umap.rds")

temp <- as.data.frame(data.umap$layout)

###
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
Nguyen$predicted.id <- factor(Nguyen$predicted.id,
                              levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor"))
Cytotrace <- read.csv("...zenodo/CytoTRACE/Human_CytoTRACE_score.csv",
                      row.names = 1)
meta <- Nguyen@meta.data
meta <- meta[row.names(Normal),]

###
q1 <- ggplot(temp, aes(x=V1, y=V2, col=meta$clust))+
  geom_point(size=1)+ 
  labs(col = "Clust")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  scale_color_manual(values = c("#FF7F00", "#33A02C", "#E31A1C"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("Definitive annotation")

q2 <- ggplot(temp, aes(x=V1, y=V2, col=meta$orig.ident))+
  geom_point(size=1)+ 
  labs(col = "Individual")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("Individual")

q3 <- ggplot(temp, aes(x=V1, y=V2, col=meta$predicted.id))+
  geom_point(size=1)+ 
  labs(col = "Clust")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  scale_color_manual(values=col.clst)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("Transfered annotation")

sub <- temp[row.names(temp) %in% row.names(Cytotrace),]
Cytotrace <- Cytotrace[row.names(sub),]

q4 <- ggplot(sub, aes(x=V1, y=V2, col=Cytotrace$CytoTRACE))+
  geom_point(size=1)+ 
  labs(col = "Score")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  scale_color_viridis()+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ggtitle("CytoTRACE")

Sfig14B <- plot_grid(q1, q2, q3, q4, ncol=2, align='hv')



#######################################################################
############ SFig. 14C    #############################################
#######################################################################
Normal <- read.csv("...zenodo/GSVA/Human/Normal_breast_GSVA.csv", row.names=1)

p1 <- ggplot(Normal, aes(x=clust, y=Curated_Stem, fill=clust))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = c("#FF7F00", "#33A02C", "#E31A1C"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Stem gene set")

p2 <- ggplot(Normal, aes(x=clust, y=Curated_Basal, fill=clust))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = c("#FF7F00", "#33A02C", "#E31A1C"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal gene set")

p3 <- ggplot(Normal, aes(x=clust, y=Curated_Alv, fill=clust))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = c("#FF7F00", "#33A02C", "#E31A1C"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Alv gene set")

p4 <- ggplot(Normal, aes(x=clust, y=Curated_Hor, fill=clust))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2), size=0.1)+
  scale_fill_manual(values = c("#FF7F00", "#33A02C", "#E31A1C"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Hor gene set")

SFig13C <- plot_grid(p1,p2,p3,p4, ncol=2, align = "hv")



#######################################################################
############ SFig. 14D    #############################################
#######################################################################
Normal <- read.csv("...zenodo/GSVA/Human/Normal_breast_GSVA.csv", row.names=1)

###
Cytotrace <- read.csv("...zenodo/CytoTRACE/Human_CytoTRACE_score.csv",
                      row.names = 1)

###
sub <- Normal[row.names(Normal) %in% row.names(Cytotrace),]
Cytotrace <- Cytotrace[row.names(sub),]
sub <- data.frame(sub, Cytotrace)

###
p1 <- ggscatter(sub, x = "CytoTRACE", y = "Curated_Stem", color="orig.ident", 
                add = "reg.line", conf.int = TRUE, 
                cor.coef = F, cor.method = "pearson", add.params = list(fill = "darkgray"),
                alpha = 0.3, legend="right", size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  stat_cor(method = "spearman", size=5)+
  ylab("GSVA score (Stem)")+
  ggtitle("CytoTRACE")+
  labs(color="Individual")

p2 <- ggscatter(sub, x = "GCS", y = "Curated_Stem", color="orig.ident", 
                add = "reg.line", conf.int = TRUE, 
                cor.coef = F, cor.method = "pearson", add.params = list(fill = "darkgray"),
                alpha = 0.3, legend="right", size=1)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  stat_cor(method = "spearman", size=5)+
  ylab("GSVA score (Stem)")+
  ggtitle("GCS")+
  labs(color="Individual")

SFig13D <- plot_grid(p1,p2, ncol=2, align = "hv")

