# Supplementary fig 15



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}



#######################################################################
############ SFig. 15A    #############################################
#######################################################################
Normal <- read.csv("...zenodo/GSVA/Human/Normal_breast_GSVA.csv", row.names=1)
colnames(Normal)[1:4] <- c("Stem", "Basal", "Alv", "Hor")
Normal$Basal <- range01(Normal$Basal)
Normal$Alv <- range01(Normal$Alv)
Normal$Hor <- range01(Normal$Hor)


SFig15A <- ggtern(data=Normal,aes(Basal,Alv,Hor))+
  geom_point(aes(color=clust), alpha=0.5)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = col.human)+
  ggtitle("Human breast epithelium")+
  facet_wrap(.~orig.ident, ncol=2)



#######################################################################
############ SFig. 15B    #############################################
#######################################################################
# Original data was retroeved from GEO (GSE113197)
Ind1_expr <- read.table("...zenodo/Human_normal_breast_data/Ind1.txt", header=T, row.names = 1)
Ind2_expr <- read.table("...zenodo/Human_normal_breast_data/Ind2.txt", header=T, row.names = 1)
Ind3_expr <- read.table("...zenodo/Human_normal_breast_data/Ind3.txt", header=T, row.names = 1)
expr <- cbind(Ind1_expr, Ind2_expr, Ind3_expr)

metadata <- data.frame(row.names = colnames(expr))
metadata$Individual <- c(rep("Ind1", length(colnames(Ind1_expr))), 
                         rep("Ind2", length(colnames(Ind2_expr))), 
                         rep("Ind3", length(colnames(Ind3_expr))))

seu <- CreateSeuratObject(expr, meta.data = metadata, min.cells = 3, min.features = 900)
seu[["percent.mt"]] <- PercentageFeatureSet(seu, pattern = "^MT-")
seu.list <- SplitObject(seu, split.by = "Individual")
for (i in 1:length(seu.list)) {
  seu.list[[i]] <- NormalizeData(seu.list[[i]], verbose = FALSE)
  seu.list[[i]] <- FindVariableFeatures(seu.list[[i]], selection.method = "vst", 
                                        nfeatures = 2000, verbose = FALSE)
}
seu.anchors <- FindIntegrationAnchors(object.list = seu.list, dims = 1:30)
seu.integrated <- IntegrateData(anchorset = seu.anchors, dims = 1:30)

seu.integrated <- ScaleData(seu.integrated, verbose = FALSE)
seu.integrated <- RunPCA(seu.integrated, npcs = 30, verbose = FALSE)
seu.integrated <- RunUMAP(seu.integrated, reduction = "pca", dims = 1:10)
seu.integrated <- FindNeighbors(seu.integrated, dims = 1:10)
seu.integrated <- FindClusters(seu.integrated, resolution = 0.2)
Cells.retained <- WhichCells(seu.integrated, idents = c(0,1))

###
seu <- subset(seu, cells = Cells.retained)

seu.list <- SplitObject(seu, split.by = "Individual")
for (i in 1:length(seu.list)) {
  seu.list[[i]] <- NormalizeData(seu.list[[i]], verbose = FALSE)
  seu.list[[i]] <- FindVariableFeatures(seu.list[[i]], selection.method = "vst", 
                                        nfeatures = 2000, verbose = FALSE)
}
seu.anchors <- FindIntegrationAnchors(object.list = seu.list, dims = 1:30, k.filter = 100)
seu.integrated <- IntegrateData(anchorset = seu.anchors, dims = 1:30)

seu.integrated <- ScaleData(seu.integrated, verbose = FALSE)
seu.integrated <- RunPCA(seu.integrated, npcs = 30, verbose = FALSE)
seu.integrated <- RunUMAP(seu.integrated, reduction = "pca", dims = 1:10)
seu.integrated <- FindNeighbors(seu.integrated, dims = 1:10)
seu.integrated <- FindClusters(seu.integrated, resolution = 0.3)

meta <- seu.integrated@meta.data
meta$Annotation[meta$seurat_clusters == 0] <- "Basal (B)"
meta$Annotation[meta$seurat_clusters == 1] <- "Luminal1 (L1)"
meta$Annotation[meta$seurat_clusters == 2] <- "Luminal2 (L2)"
seu.integrated@meta.data <- meta

#
p1 <- UMAPPlot(seu.integrated, group.by = "Annotation")
p2 <- UMAPPlot(seu.integrated, group.by="Individual")
p3 <- plot_grid(p1, p2, ncol=1, align = "hv")

###
FP <- wes_palette("Zissou1", 5, type = "discrete")
p4 <- FeaturePlot(seu.integrated, "KRT14", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))
p5 <- FeaturePlot(seu.integrated, "KRT18", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("KRT18")
p6 <- FeaturePlot(seu.integrated, "PROM1", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("PROM1")
p7 <- FeaturePlot(seu.integrated, "ANKRD30A", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("ANKRD30A")

p8 <- plot_grid(p1, p2, p3, p4, ncol=2, align = "hv")

ggsave("FigB.pdf", plot=q, width = 10, height = 8)
ggsave("FigB.tiff", plot=q, width = 10, height = 8)

SFig15B <- plot_grid(p3, p8)



#######################################################################
############ SFig. 15C    #############################################
#######################################################################
seu <- seu.integrated

Curated_stem <-  readRDS("...zenodo/GSVA/Human/Curated_Stem(m2h).rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Human/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Human/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Human/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Curated_stem$`Curated_Stem(m2h)`, Basal_gene_sets$Top_Basal_1000, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_240)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Curated_stem, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

### assay=RNA, slot=scaled.data
seu@active.assay <- "RNA"
seu <- ScaleData(seu)
mat <- seu@assays$RNA@scale.data
meta <- seu@meta.data

gsvaResult <- gsva(mat, Curated_gene_sets, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
gsvaResult <- as.data.frame(t(gsvaResult))
gsvaResult <- data.frame(gsvaResult, meta)

colnames(gsvaResult)[1:4] <- c("Stem", "Basal", "Alv", "Hor")
gsvaResult$Basal <- range01(gsvaResult$Basal)
gsvaResult$Alv <- range01(gsvaResult$Alv)
gsvaResult$Hor <- range01(gsvaResult$Hor)


p1 <- ggtern(data=gsvaResult,aes(Basal,Alv,Hor))+
  geom_point(aes(color=Annotation), alpha=0.5)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  ggtitle("Ind1-3(Fluidigm C1, Nguyen et al)")

p2 <- ggtern(data=gsvaResult,aes(Basal,Alv,Hor))+
  geom_point(aes(color=Individual), alpha=0.5)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  ggtitle("Ind1-3(Fluidigm C1, Nguyen et al)")

SFig15C <- plot_grid(p1, p2)



#######################################################################
############ SFig. 15D    #############################################
#######################################################################
# "HOM_AllOrganism.rpt" was downloaded from http://www.informatics.jax.org/homology.shtml
# Then, list was modified to generate "Homologene.csv".
HG <- read.csv("...zenodo/TCGA/Homologene.csv", header=T)
Mouse <- HG[HG$TaxonID == 10090,]
Human <- HG[HG$TaxonID == 9606,]
HG <- merge(Mouse, Human, by.x = "HomoloGeneID", by.y= "HomoloGeneID", all = T)
HG <- HG[, c(3,5)]
colnames(HG) <- c("Mouse", "Human")

# Gene conversion
# Mouse gene set
Stem_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Stem_cor_genes_top1000.rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Mouse/Hor_cor_genes_top1000.rds")
Curated_gene_sets <- list(Stem_gene_sets$Top_Stem_160, Basal_gene_sets$Top_Basal_240, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_200)
names(Curated_gene_sets) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Stem_gene_sets, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

# Gene conversion
m_Stem <- Curated_gene_sets$Curated_Stem
HG_Stem <- HG[HG$Mouse %in% m_Stem,]
h_Stem <- HG_Stem$Human
h_Stem <- na.omit(h_Stem)

m_Basal <- Curated_gene_sets$Curated_Basal
HG_Basal <- HG[HG$Mouse %in% m_Basal,]
h_Basal <- HG_Basal$Human
h_Basal <- na.omit(h_Basal)

m_Hor <- Curated_gene_sets$Curated_Hor
HG_Hor <- HG[HG$Mouse %in% m_Hor,]
h_Hor <- HG_Hor$Human
h_Hor <- na.omit(h_Hor)

m_Alv <- Curated_gene_sets$Curated_Alv
HG_Alv <- HG[HG$Mouse %in% m_Alv,]
h_Alv <- HG_Alv$Human
h_Alv <- na.omit(h_Alv)

Genesets_m <- list(h_Stem, h_Basal, h_Alv, h_Hor)
names(Genesets_m) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")


# Human gene set 
Curated_stem <-  readRDS("...zenodo/GSVA/Human/Curated_Stem(m2h).rds")
Basal_gene_sets <- readRDS("...zenodo/GSVA/Human/Basal_cor_genes_top1000.rds")
Alv_gene_sets <- readRDS("...zenodo/GSVA/Human/Alv_cor_genes_top1000.rds")
Hor_gene_sets <- readRDS("...zenodo/GSVA/Human/Hor_cor_genes_top1000.rds")
Genesets_h <- list(Stem_gene_sets$Top_Stem_100, Basal_gene_sets$Top_Basal_1000, Alv_gene_sets$Top_Alv_500, Hor_gene_sets$Top_Hor_240)
names(Genesets_h) <- c("Curated_Stem", "Curated_Basal", "Curated_Alv", "Curated_Hor")
remove(Stem_gene_sets, Basal_gene_sets, Alv_gene_sets, Hor_gene_sets)
gc();gc()

Genesets_m <- readRDS("./Curated_gene_sets_m_to_h.rds")

### Basal
Basal_h <- Genesets_h$Curated_Basal
Basal_m <- Genesets_m$Curated_Basal

Basal_common <- Basal_m[Basal_m %in% Basal_h]
Basal_h_spec <- Basal_h[!Basal_h %in% Basal_common]
Basal_m_spec <- Basal_m[!Basal_m %in% Basal_common]

# SFig15D-1
venn.diagram(
  x = list(Basal_h, Basal_m),
  main = "Basal gene list",
  main.fontfamily = "sans",
  main.fontface = "bold", main.col = "black",
  main.cex = 0.7, main.pos = c(0.25, 1.1),
  category.names = c("Human", "Mouse"),
  filename = 'Basal.tiff',
  output=TRUE,
  
  # Output features
  imagetype="tiff" ,
  height =  500 , 
  width = 500 , 
  resolution = 300,
  compression = "lzw",
  
  # Circles
  lwd = 2,
  fill = c("white", "lightgrey"),
  
  # Numbers
  cex = .6,
  fontface = "bold",
  fontfamily = "sans",
  cat.pos = c(-25,25),
  cat.dist = c(0.04, 0.04),
  
  # Set names
  cat.cex = 0.6,
  cat.default.pos = "outer",
  cat.fontfamily = "sans"
)


### Alv
Alv_h <- Genesets_h$Curated_Alv
Alv_m <- Genesets_m$Curated_Alv

Alv_common <- Alv_m[Alv_m %in% Alv_h]
Alv_h_spec <- Alv_h[!Alv_h %in% Alv_common]
Alv_m_spec <- Alv_m[!Alv_m %in% Alv_common]


# SFig15D-2
venn.diagram(
  x = list(Alv_h, Alv_m),
  main = "Alv gene list",
  main.fontfamily = "sans",
  main.fontface = "bold", main.col = "black",
  main.cex = 0.7, main.pos = c(0.25, 1.1),
  category.names = c("Human", "Mouse"),
  filename = 'Alv.tiff',
  output=TRUE,
  
  # Output features
  imagetype="tiff" ,
  height =  500 , 
  width = 500 , 
  resolution = 300,
  compression = "lzw",
  
  # Circles
  lwd = 2,
  fill = c("white", "lightgrey"),
  
  # Numbers
  cex = .6,
  fontface = "bold",
  fontfamily = "sans",
  cat.pos = c(-25,25),
  cat.dist = c(0.05, 0.05),
  
  # Set names
  cat.cex = 0.6,
  cat.default.pos = "outer",
  cat.fontfamily = "sans"
)


### Hor
Hor_h <- Genesets_h$Curated_Hor
Hor_m <- Genesets_m$Curated_Hor

Hor_common <- Hor_m[Hor_m %in% Hor_h]
Hor_h_spec <- Hor_h[!Hor_h %in% Hor_common]
Hor_m_spec <- Hor_m[!Hor_m %in% Hor_common]


# SFig15D-3
venn.diagram(
  x = list(Hor_h, Hor_m),
  main = "Hor gene list",
  main.fontfamily = "sans",
  main.fontface = "bold", main.col = "black",
  main.cex = 0.7, main.pos = c(0.25, 1.1),
  category.names = c("Human", "Mouse"),
  filename = 'Hor.tiff',
  output=TRUE,
  
  # Output features
  imagetype="tiff" ,
  height =  500 , 
  width = 500 , 
  resolution = 300,
  compression = "lzw",
  
  # Circles
  lwd = 2,
  fill = c("white", "lightgrey"),
  
  # Numbers
  cex = .6,
  fontface = "bold",
  fontfamily = "sans",
  cat.pos = c(-25,25),
  cat.dist = c(0.05, 0.05),
  
  # Set names
  cat.cex = 0.6,
  cat.default.pos = "outer",
  cat.fontfamily = "sans"
)

### Gene_list
Lineage_genes <- list(Basal_common, Basal_h_spec, Basal_m_spec,
                      Alv_common, Alv_h_spec, Alv_m_spec,
                      Hor_common, Hor_h_spec, Hor_m_spec)
names(Lineage_genes) <- c("Basal_common", "Basal_h_spec", "Basal_m_spec",
                          "Alv_common", "Alv_h_spec", "Alv_m_spec",
                          "Hor_common", "Hor_h_spec", "Hor_m_spec")

Basal_common <- c(Basal_common, rep(NA, 1000-length(Basal_common)))
Basal_h_spec <- c(Basal_h_spec, rep(NA, 1000-length(Basal_h_spec)))
Basal_m_spec <- c(Basal_m_spec, rep(NA, 1000-length(Basal_m_spec)))
Alv_common <- c(Alv_common, rep(NA, 1000-length(Alv_common)))
Alv_h_spec <- c(Alv_h_spec, rep(NA, 1000-length(Alv_h_spec)))
Alv_m_spec <- c(Alv_m_spec, rep(NA, 1000-length(Alv_m_spec)))
Hor_common <- c(Hor_common, rep(NA, 1000-length(Hor_common)))
Hor_h_spec <- c(Hor_h_spec, rep(NA, 1000-length(Hor_h_spec)))
Hor_m_spec <- c(Hor_m_spec, rep(NA, 1000-length(Hor_m_spec)))

Supplementary_Table_10 <- cbind(Basal_common, Basal_h_spec, Basal_m_spec,
                  Alv_common, Alv_h_spec, Alv_m_spec,
                  Hor_common, Hor_h_spec, Hor_m_spec)

### Supplementary Table 11
library("org.Hs.eg.db")
m_df <- msigdbr(species = "Homo sapiens")
m_df_H <- m_df[m_df$gs_cat == "H", ]
m_df_C2 <- m_df[m_df$gs_cat == "C2", ]
m_df_C5 <- m_df[m_df$gs_cat == "C5", ]

m_df_H <- m_df_H %>% dplyr::select(gs_name, entrez_gene)
m_df_C2 <- m_df_C2 %>% dplyr::select(gs_name, entrez_gene)
m_df_C5 <- m_df_C5 %>% dplyr::select(gs_name, entrez_gene)

# Basal_common
Basal_common <- Lineage_genes$Basal_common
Basal_common_ID = bitr(Basal_common, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Basal_common_H <- enricher(Basal_common_ID$ENTREZID, TERM2GENE=m_df_H)
Basal_common_C2 <- enricher(Basal_common_ID$ENTREZID, TERM2GENE=m_df_C2)
Basal_common_C5 <- enricher(Basal_common_ID$ENTREZID, TERM2GENE=m_df_C5)
Basal_common_H_res <- Basal_common_H@result
Basal_common_C2_res <- Basal_common_C2@result
Basal_common_C5_res <- Basal_common_C5@result

# Basal_h_spec
Basal_h_spec <- Lineage_genes$Basal_h_spec
Basal_h_spec_ID = bitr(Basal_h_spec, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Basal_h_spec_H <- enricher(Basal_h_spec_ID$ENTREZID, TERM2GENE=m_df_H)
Basal_h_spec_C2 <- enricher(Basal_h_spec_ID$ENTREZID, TERM2GENE=m_df_C2)
Basal_h_spec_C5 <- enricher(Basal_h_spec_ID$ENTREZID, TERM2GENE=m_df_C5)
Basal_h_spec_H_res <- Basal_h_spec_H@result
Basal_h_spec_C2_res <- Basal_h_spec_C2@result
Basal_h_spec_C5_res <- Basal_h_spec_C5@result

# Basal_m_spec
Basal_m_spec <- Lineage_genes$Basal_m_spec
Basal_m_spec_ID = bitr(Basal_m_spec, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Basal_m_spec_H <- enricher(Basal_m_spec_ID$ENTREZID, TERM2GENE=m_df_H)
Basal_m_spec_C2 <- enricher(Basal_m_spec_ID$ENTREZID, TERM2GENE=m_df_C2)
Basal_m_spec_C5 <- enricher(Basal_m_spec_ID$ENTREZID, TERM2GENE=m_df_C5)
Basal_m_spec_H_res <- Basal_m_spec_H@result
Basal_m_spec_C2_res <- Basal_m_spec_C2@result
Basal_m_spec_C5_res <- Basal_m_spec_C5@result

# Alv_common
Alv_common <- Lineage_genes$Alv_common
Alv_common_ID = bitr(Alv_common, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Alv_common_H <- enricher(Alv_common_ID$ENTREZID, TERM2GENE=m_df_H)
Alv_common_C2 <- enricher(Alv_common_ID$ENTREZID, TERM2GENE=m_df_C2)
Alv_common_C5 <- enricher(Alv_common_ID$ENTREZID, TERM2GENE=m_df_C5)
Alv_common_H_res <- Alv_common_H@result
Alv_common_C2_res <- Alv_common_C2@result
Alv_common_C5_res <- Alv_common_C5@result

# Alv_h_spec
Alv_h_spec <- Lineage_genes$Alv_h_spec
Alv_h_spec_ID = bitr(Alv_h_spec, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Alv_h_spec_H <- enricher(Alv_h_spec_ID$ENTREZID, TERM2GENE=m_df_H)
Alv_h_spec_C2 <- enricher(Alv_h_spec_ID$ENTREZID, TERM2GENE=m_df_C2)
Alv_h_spec_C5 <- enricher(Alv_h_spec_ID$ENTREZID, TERM2GENE=m_df_C5)
Alv_h_spec_H_res <- Alv_h_spec_H@result
Alv_h_spec_C2_res <- Alv_h_spec_C2@result
Alv_h_spec_C5_res <- Alv_h_spec_C5@result

# Alv_m_spec
Alv_m_spec <- Lineage_genes$Alv_m_spec
Alv_m_spec_ID = bitr(Alv_m_spec, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Alv_m_spec_H <- enricher(Alv_m_spec_ID$ENTREZID, TERM2GENE=m_df_H)
Alv_m_spec_C2 <- enricher(Alv_m_spec_ID$ENTREZID, TERM2GENE=m_df_C2)
Alv_m_spec_C5 <- enricher(Alv_m_spec_ID$ENTREZID, TERM2GENE=m_df_C5)
Alv_m_spec_H_res <- Alv_m_spec_H@result
Alv_m_spec_C2_res <- Alv_m_spec_C2@result
Alv_m_spec_C5_res <- Alv_m_spec_C5@result

# Hor_common
Hor_common <- Lineage_genes$Hor_common
Hor_common_ID = bitr(Hor_common, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Hor_common_H <- enricher(Hor_common_ID$ENTREZID, TERM2GENE=m_df_H)
Hor_common_C2 <- enricher(Hor_common_ID$ENTREZID, TERM2GENE=m_df_C2)
Hor_common_C5 <- enricher(Hor_common_ID$ENTREZID, TERM2GENE=m_df_C5)
Hor_common_H_res <- Hor_common_H@result
Hor_common_C2_res <- Hor_common_C2@result
Hor_common_C5_res <- Hor_common_C5@result

# Hor_h_spec
Hor_h_spec <- Lineage_genes$Hor_h_spec
Hor_h_spec_ID = bitr(Hor_h_spec, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Hor_h_spec_H <- enricher(Hor_h_spec_ID$ENTREZID, TERM2GENE=m_df_H)
Hor_h_spec_C2 <- enricher(Hor_h_spec_ID$ENTREZID, TERM2GENE=m_df_C2)
Hor_h_spec_C5 <- enricher(Hor_h_spec_ID$ENTREZID, TERM2GENE=m_df_C5)
Hor_h_spec_H_res <- Hor_h_spec_H@result
Hor_h_spec_C2_res <- Hor_h_spec_C2@result
Hor_h_spec_C5_res <- Hor_h_spec_C5@result

# Hor_m_spec
Hor_m_spec <- Lineage_genes$Hor_m_spec
Hor_m_spec_ID = bitr(Hor_m_spec, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Hs.eg.db")
Hor_m_spec_H <- enricher(Hor_m_spec_ID$ENTREZID, TERM2GENE=m_df_H)
Hor_m_spec_C2 <- enricher(Hor_m_spec_ID$ENTREZID, TERM2GENE=m_df_C2)
Hor_m_spec_C5 <- enricher(Hor_m_spec_ID$ENTREZID, TERM2GENE=m_df_C5)
Hor_m_spec_H_res <- Hor_m_spec_H@result
Hor_m_spec_C2_res <- Hor_m_spec_C2@result
Hor_m_spec_C5_res <- Hor_m_spec_C5@result