# Supplementary fig 16



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}

data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}


##############################################################################
################# Supplementary Fig.16A ######################################
##############################################################################
df_gsvaResult <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_mouse_gsva.csv", row.names = 1)
meta <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_mouse_meta.csv", row.names = 1)

df_gsvaResult <- as.data.frame(t(df_gsvaResult))
colnames(df_gsvaResult)[1:4] <- c("Stem", "Basal", "Alv", "Hor")

df_gsvaResult$Stem <- range01(df_gsvaResult$Stem)
df_gsvaResult$Basal <- range01(df_gsvaResult$Basal)
df_gsvaResult$Alv <- range01(df_gsvaResult$Alv)
df_gsvaResult$Hor <- range01(df_gsvaResult$Hor)

meta$Cluster <- factor(meta$Cluster, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor", "Mixture"))
meta$Sampling <- as.factor(meta$Sampling)

Sfig16A <- ggtern(data=df_gsvaResult,aes(Basal,Alv,Hor))+
  geom_point(aes(shape=meta$Sampling, color=meta$Cluster), alpha=0.5, size=4)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst, "darkgrey"))+
  ggtitle("Pseudo bulk RNAseq")+
  labs(color="Cluster", shape="Sampling #")



##############################################################################
################# Supplementary Fig.16B ######################################
##############################################################################
tiss <- readRDS("...zenodo/PseudoRNAseq/Annotated_TM.rds")
Remove_Barcode <- readRDS("...zenodo/PseudoRNAseq/Remove_Barcode.rds")

Retained <- colnames(tiss)[!colnames(tiss) %in% Remove_Barcode]
tiss <- subset(tiss, cells = Retained)

tiss <- NormalizeData(tiss)
tiss <- FindVariableFeatures(tiss, selection.method = "vst", nfeatures = 2000)
tiss <- ScaleData(tiss, features = rownames(tiss))
tiss <- RunPCA(tiss, features = VariableFeatures(object = tiss))
tiss <- RunUMAP(tiss, dims=1:10)
tiss <- FindNeighbors(tiss, dims = 1:10)
tiss <- FindClusters(tiss, resolution = 0.1)

tiss$Int_Annotation <- factor(tiss$Int_Annotation, levels = c("MaSC/B-pro", "Basal", "LA-pro", "L-Alv", "LH-pro", "L-Hor", "Stroma"))

table(tiss@active.ident)

## Basic characteristics
p1 <- UMAPPlot(tiss, label=T, label.size=8)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Tabula Muris")+
  NoLegend()
p2 <- UMAPPlot(tiss, group.by="annotation", label=T, label.size=3)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Annotation(original)")+
  NoLegend()
p3 <- UMAPPlot(tiss, group.by="Int_Annotation")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))+
  ggtitle("Annotation(this study)")+
  scale_color_manual(values = c(col.clst, "darkgrey"))

Sfig16B <- plot_grid(p1,p2,p3, ncol=3)



##############################################################################
################# Supplementary Fig.16C ######################################
##############################################################################
df_gsvaResult <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_TabulaMuris_gsva.csv", row.names = 1)
df_gsvaResult <- as.data.frame(t(df_gsvaResult))
colnames(df_gsvaResult)[1:4] <- c("Stem", "Basal", "Alv", "Hor")
meta <- read.csv("...zenodo/PseudoRNAseq/PseudoRNA_TabulaMuris_meta.csv", row.names = 1)
meta$Cluster <- factor(meta$Cluster, levels = c("Basal", "Alv", "Hor", "Mixture"))
meta$Percentage <- as.factor(meta$Percentage)

meta_sub <- meta[meta$Percentage %in% c(50,60,70,80,90,100),]
df_gsvaResult_sub <- df_gsvaResult[row.names(meta_sub),]

df_gsvaResult_sub$Stem <- range01(df_gsvaResult_sub$Stem)
df_gsvaResult_sub$Basal <- range01(df_gsvaResult_sub$Basal)
df_gsvaResult_sub$Alv <- range01(df_gsvaResult_sub$Alv)
df_gsvaResult_sub$Hor <- range01(df_gsvaResult_sub$Hor)


SFig16C <- ggtern(data=df_gsvaResult_sub,aes(Basal,Alv,Hor))+
  geom_point(aes(shape=meta_sub$Percentage, color=meta_sub$Cluster), alpha=0.5, size=4)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst[2], col.clst[4], col.clst[6], "darkgrey"))+
  ggtitle("Pseudo bulk RNAseq (Tabula Muris)")+
  labs(color="Cell type", shape="Epithelial %")



##############################################################################
################# Supplementary Fig.16D ######################################
##############################################################################
stat <- data.frame(df_gsvaResult_sub, meta_sub)
Percentage <- seq(100,10,-10)
stat$Percentage <- factor(stat$Percentage, levels = Percentage[1:6])

stat_Stem <- data_summary(stat, varname="Stem", 
                    groupnames=c("Cluster", "Percentage"))
stat_Basal <- data_summary(stat, varname="Basal", 
                          groupnames=c("Cluster", "Percentage"))
stat_Alv <- data_summary(stat, varname="Alv", 
                          groupnames=c("Cluster", "Percentage"))
stat_Hor <- data_summary(stat, varname="Hor", 
                          groupnames=c("Cluster", "Percentage"))

p1 <- ggplot(stat_Stem, aes(x=Percentage, y=Stem, group=Cluster, color=Cluster)) + 
  geom_line(size=1.5) +
  geom_point(size=3)+
  geom_errorbar(aes(ymin=Stem-sd, ymax=Stem+sd), width=.2,
                position=position_dodge(0.05))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst[2], col.clst[4], col.clst[6], "darkgrey"))+
  ggtitle("Stem score")+
  labs(color="Cell type")+
  ylab("Stem score")+
  xlab("Epithelial cell %")

p2 <- ggplot(stat_Basal, aes(x=Percentage, y=Basal, group=Cluster, color=Cluster)) + 
  geom_line(size=1.5) +
  geom_point(size=3)+
  geom_errorbar(aes(ymin=Basal-sd, ymax=Basal+sd), width=.2,
                position=position_dodge(0.05))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst[2], col.clst[4], col.clst[6], "darkgrey"))+
  ggtitle("Basal score")+
  labs(color="Cell type")+
  ylab("Basal score")+
  xlab("Epithelial cell %")

p3 <- ggplot(stat_Alv, aes(x=Percentage, y=Alv, group=Cluster, color=Cluster)) + 
  geom_line(size=1.5) +
  geom_point(size=3)+
  geom_errorbar(aes(ymin=Alv-sd, ymax=Alv+sd), width=.2,
                position=position_dodge(0.05))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst[2], col.clst[4], col.clst[6], "darkgrey"))+
  ggtitle("Alv score")+
  labs(color="Cell type")+
  ylab("Alv score")+
  xlab("Epithelial cell %")

p4 <- ggplot(stat_Hor, aes(x=Percentage, y=Hor, group=Cluster, color=Cluster)) + 
  geom_line(size=1.5) +
  geom_point(size=3)+
  geom_errorbar(aes(ymin=Hor-sd, ymax=Hor+sd), width=.2,
                position=position_dodge(0.05))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst[2], col.clst[4], col.clst[6], "darkgrey"))+
  ggtitle("Hor score")+
  labs(color="Cell type")+
  ylab("Hor score")+
  xlab("Epithelial cell %")

SFig16D <- plot_grid(p1, p2, p3, p4, ncol = 2, align ='hv')



##############################################################################
################# Supplementary Fig.16E ######################################
##############################################################################
### Mouse
df_gsvaResult <- read.csv("...zenodo/Lim_microarray/Lim_mouse_gsva.csv", row.names = 1)
df_gsvaResult <- as.data.frame(t(df_gsvaResult))
colnames(df_gsvaResult)[1:4] <- c("Stem", "Basal", "Alv", "Hor")

meta <- read.table("...zenodo/Lim_microarray/GSE19446/mouse_meta.txt", header=T)
meta$Cell_type <- factor(meta$Cell_type, levels = c("MS(Basal)", "LP(Alv)", "ML(Hor)", "Stroma"))
meta$Replicates <- as.factor(meta$Replicates)

meta_sub <- meta[!(meta$Cell_type == "Stroma"),]
row.names(meta_sub) <- meta_sub$Sample
df_gsvaResult_sub <- df_gsvaResult[row.names(meta_sub),]

df_gsvaResult_sub$Stem <- range01(df_gsvaResult_sub$Stem)
df_gsvaResult_sub$Basal <- range01(df_gsvaResult_sub$Basal)
df_gsvaResult_sub$Alv <- range01(df_gsvaResult_sub$Alv)
df_gsvaResult_sub$Hor <- range01(df_gsvaResult_sub$Hor)


SFig16E_1 <- ggtern(data=df_gsvaResult_sub,aes(Basal,Alv,Hor))+
  geom_point(aes(shape=meta_sub$Replicates, color=meta_sub$Cell_type), alpha=0.5, size=4)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst[2], col.clst[4], col.clst[6], "darkgrey"))+
  ggtitle("FACS-sorted microarray(Mouse)")+
  labs(color="Cell type", shape="Replicates")


### Human
df_gsvaResult <- read.csv("...zenodo/Lim_microarray/Lim_human_gsva.csv", row.names = 1)
df_gsvaResult <- as.data.frame(t(df_gsvaResult))
colnames(df_gsvaResult)[1:4] <- c("Stem", "Basal", "Alv", "Hor")

meta <- read.table("...zenodo/Lim_microarray/GSE16997/human_meta.txt", header=T)
meta$Cell_type <- factor(meta$Cell_type, levels = c("MS(Basal)", "LP(Alv)", "ML(Hor)", "Stroma"))
meta$Patient <- as.factor(meta$Patient)

meta_sub <- meta[!(meta$Cell_type == "Stroma"),]
row.names(meta_sub) <- meta_sub$Sample
df_gsvaResult_sub <- df_gsvaResult[row.names(meta_sub),]

df_gsvaResult_sub$Stem <- range01(df_gsvaResult_sub$Stem)
df_gsvaResult_sub$Basal <- range01(df_gsvaResult_sub$Basal)
df_gsvaResult_sub$Alv <- range01(df_gsvaResult_sub$Alv)
df_gsvaResult_sub$Hor <- range01(df_gsvaResult_sub$Hor)


SFig16E_2 <- ggtern(data=df_gsvaResult_sub,aes(Basal,Alv,Hor))+
  geom_point(aes(shape=meta_sub$Patient, color=meta_sub$Cell_type), alpha=0.5, size=4)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"),
        strip.text=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(col.clst[2], col.clst[4], col.clst[6], "darkgrey"))+
  ggtitle("FACS-sorted microarray(Human)")+
  labs(color="Cell type", shape="Replicates")

