# Supplementary Fig 17



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}



######################################################################################
################ Supplementary Fig 17A ###############################################
######################################################################################
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta <- na.omit(meta)

Exp <- assay(data)
row <- rowData(data)
geneData <- row@listData
row.names(Exp) <- geneData$external_gene_name
Exp <- Exp[,row.names(meta)]

###
TCGA <- CreateSeuratObject(Exp, meta.data = meta, min.cells = 3)
TCGA <- NormalizeData(TCGA)
TCGA <- FindVariableFeatures(TCGA, selection.method = "vst", nfeatures = 2000)

TCGA <- ScaleData(TCGA, features = rownames(TCGA))
TCGA <- RunPCA(TCGA, features = VariableFeatures(object = TCGA))
TCGA <- RunUMAP(TCGA, dims = 1:10)
TCGA <- FindNeighbors(TCGA, dims = 1:10)
TCGA <- FindClusters(TCGA, resolution = 0.1)

temp <- as.data.frame(TCGA@reductions$umap@cell.embeddings)

SFig17A <- ggplot(temp, aes(x=UMAP_1, y=UMAP_2, col=TCGA$Subtype))+
  geom_point(size=1)+
  scale_color_manual(values = c(pam50.col, "darkgrey"))+ 
  labs(col = "Subtype")+
  xlab("UMAP1")+
  ylab("UMAP2")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ggtitle("TCGA_BRCA(whole transcriptome)")



######################################################################################
################ Supplementary Fig 17B ###############################################
######################################################################################
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta <- na.omit(meta)

BRCA_gsvaResult <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)
BRCA_gsvaResult <- BRCA_gsvaResult[row.names(meta),]


###
df <- data.frame(BRCA_gsvaResult, meta)
p1 <- ggplot(df, aes(x=Subtype, y=Curated_Stem, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Stem gene set")
p2 <- ggplot(df, aes(x=Subtype, y=Curated_Basal, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal gene set")
p3 <- ggplot(df, aes(x=Subtype, y=Curated_Alv, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Alv gene set")
p4 <- ggplot(df, aes(x=Subtype, y=Curated_Hor, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Hor gene set")
SFig17B <- plot_grid(p1,p2,p3,p4, ncol=2, align = "hv")



######################################################################################
################ Supplementary Fig 17C ###############################################
######################################################################################
df <- read.csv("...zenodo/TCGA/Merged_stroma.csv", row.names=1)
df$Subtype <- as.character(df$Subtype)
df$Subtype[df$Subtype == "Normal"] <- "Normal-like"

p1 <- ggscatter(df, x = "percent_stromal_cells", y = "Curated_Stem", color="Subtype", 
          add = "reg.line", conf.int = TRUE, 
          cor.coef = F, cor.method = "pearson", add.params = list(fill = "darkgray"),
          alpha = 0.5, legend="right")+
  scale_color_manual(values = c(pam50.col))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  stat_cor(method = "spearman", size=5, cor.coef.name = "rho")+
  ylab("GSVA score")+
  ggtitle("Stem gene set")+
  ylim(0.9,2)


p2 <- ggscatter(df, x = "percent_stromal_cells", y = "Curated_Basal", color="Subtype", 
                add = "reg.line", conf.int = TRUE, 
                cor.coef = F, cor.method = "pearson", add.params = list(fill = "darkgray"),
                alpha = 0.5, legend="right")+
  scale_color_manual(values = c(pam50.col))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  stat_cor(method = "spearman", size=5, cor.coef.name = "rho")+
  ylab("GSVA score")+
  ggtitle("Basal gene set")


p3 <- ggscatter(df, x = "percent_stromal_cells", y = "Curated_Alv", color="Subtype", 
                add = "reg.line", conf.int = TRUE, 
                cor.coef = F, cor.method = "pearson", add.params = list(fill = "darkgray"),
                alpha = 0.5, legend="right")+
  scale_color_manual(values = c(pam50.col))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  stat_cor(method = "spearman", size=5, cor.coef.name = "rho")+
  ylab("GSVA score")+
  ggtitle("Alv gene set")


p4 <- ggscatter(df, x = "percent_stromal_cells", y = "Curated_Hor", color="Subtype", 
                add = "reg.line", conf.int = TRUE, 
                cor.coef = F, cor.method = "pearson", add.params = list(fill = "darkgray"),
                alpha = 0.5, legend="right")+
  scale_color_manual(values = c(pam50.col))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  stat_cor(method = "spearman", size=5, cor.coef.name = "rho")+
  ylab("GSVA score")+
  ggtitle("Hor gene set")+
  ylim(0.4, 1.05)

SFig17C <- plot_grid(p1, p2, p3, p4, align='hv', ncol=2)


######################################################################################
################ Supplementary Fig 17D ###############################################
######################################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
all.markers <- FindAllMarkers(seu, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
gene_list <- split(all.markers$gene, all.markers$cluster)

# "HOM_AllOrganism.rpt" was downloaded from http://www.informatics.jax.org/homology.shtml
# Then, list was modified to generate "Homologene.csv".
HG <- read.csv("...zenodo/TCGA/Homologene.csv", header=T)
Mouse <- HG[HG$Taxon == 10090,]
Human <- HG[HG$Taxon == 9606,]
HG <- merge(Mouse, Human, by.x = "HomoloGeneID", by.y= "HomoloGeneID", all = T)
HG <- HG[, c(3,5)]
HG[is.na(HG)] <- "-"
colnames(HG) <- c("Mouse", "Human")

## Conversion
m_MaSC <- gene_list$`MaSC/B-pro`
HG_MaSC <- HG[HG$Mouse %in% m_MaSC,]
h_MaSC <- HG_MaSC$Human
h_MaSC <- h_MaSC[!h_MaSC=="-"]

m_Basal <- gene_list$Basal
HG_Basal <- HG[HG$Mouse %in% m_Basal,]
h_Basal <- HG_Basal$Human
h_Basal <- h_Basal[!h_Basal=="-"]

m_LA_pro <- gene_list$`LA-pro`
HG_LA_pro <- HG[HG$Mouse %in% m_LA_pro,]
h_LA_pro <- HG_LA_pro$Human
h_LA_pro <- h_LA_pro[!h_LA_pro=="-"]

m_L_Alv <- gene_list$`L-Alv`
HG_L_Alv <- HG[HG$Mouse %in% m_L_Alv,]
h_L_Alv <- HG_L_Alv$Human
h_L_Alv <- h_L_Alv[!h_L_Alv=="-"]

m_LH_pro <- gene_list$`LH-pro`
HG_LH_pro <- HG[HG$Mouse %in% m_LH_pro,]
h_LH_pro <- HG_LH_pro$Human
h_LH_pro <- h_LH_pro[!h_LH_pro=="-"]

m_L_Hor <- gene_list$`L-Hor`
HG_L_Hor <- HG[HG$Mouse %in% m_L_Hor,]
h_L_Hor <- HG_L_Hor$Human
h_L_Hor <- h_L_Hor[!h_L_Hor=="-"]

h_gene_list <- list(h_MaSC, h_Basal, h_LA_pro, h_L_Alv, h_LH_pro, h_L_Hor)
names(h_gene_list) <- names(gene_list)

###
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
Genes <- row.names(Nguyen@assays$RNA)
Sub_exp <- Exp[row.names(Exp) %in% Genes,]

###
BRCA_gsvaResult <- gsva(Sub_exp, h_gene_list, verbose=TRUE, kcdf="Gaussian", method="ssgsea")
BRCA_gsvaResult <- t(BRCA_gsvaResult)
BRCA_gsvaResult <- BRCA_gsvaResult[row.names(meta),]

###
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta <- na.omit(meta)


###
df <- data.frame(BRCA_gsvaResult, meta)

p1 <- ggplot(df, aes(x=Subtype, y=MaSC.B.pro, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("MaSC/B-pro score")

p2 <- ggplot(df, aes(x=Subtype, y=Basal, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal score")

p3 <- ggplot(df, aes(x=Subtype, y=LA.pro, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("LA-pro score")

p4 <- ggplot(df, aes(x=Subtype, y=L.Alv, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("L-Alv score")

p5 <- ggplot(df, aes(x=Subtype, y=LH.pro, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("LH-pro score")

p6 <- ggplot(df, aes(x=Subtype, y=L.Hor, fill=Subtype))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(pam50.col, "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("L-Hor score")


SFig17D <- plot_grid(p1,p3,p5,p2,p4,p6, ncol=3, align = "hv")