# Supplementary Fig 18



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}



######################################################################################
################ Supplementary Fig 18A ###############################################
######################################################################################
results <- readRDS("...zenodo/PAM50/TCGA_claudin.rds")

load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta$histology <- sampleData$primary_diagnosis
meta$class <- "Other histology"
levels(as.factor(sampleData$primary_diagnosis))
meta$class[meta$histology == "Metaplastic carcinoma, NOS"] <- "Metaplastic carcinoma"
meta$class[meta$Subtype == "Normal_MG" ] <- "Normal_MG" 
meta$claudin <- as.character(results$Call)
meta$claudin[meta$Subtype == "Normal_MG" ] <- "Normal_MG" 
meta$claudin[meta$claudin =="Claudin"] <- "Claudin-low"
meta$claudin2 <- "Others"
meta$claudin2[meta$Subtype == "Basal" & meta$claudin =="Claudin"] <- "Claudin-low"
meta$claudin2[meta$Subtype == "Normal_MG" ] <- "Normal_MG" 
meta <- na.omit(meta)

BRCA_gsvaResult <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)
data.umap <- readRDS("...zenodo/UMAP/TCGA_umap.rds")

temp <- as.data.frame(data.umap$layout)
temp <- temp[row.names(meta),]


###
colnames(BRCA_gsvaResult)[1] <- "Curated_Stem"
BRCA_gsvaResult <- BRCA_gsvaResult[row.names(meta),]

data_tern <- BRCA_gsvaResult
data_tern$Curated_Stem <- range01(data_tern$Curated_Stem)
data_tern$Curated_Basal <- range01(data_tern$Curated_Basal)
data_tern$Curated_Alv <- range01(data_tern$Curated_Alv)
data_tern$Curated_Hor <- range01(data_tern$Curated_Hor)

colnames(data_tern) <- c("Stem", "Basal", "Alv", "Hor")

SFig18A_1 <- ggtern(data=data_tern, aes(Basal, Alv, Hor))+
  geom_point(aes(color=meta$class), alpha=0.5)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  scale_color_manual(values=c("red", "black", "darkgrey"))+ 
  labs(col = "histology")+
  ggtitle("TCGA_BRCA(Histology)")

SFig18A_2 <- ggtern(data=data_tern, aes(Basal, Alv, Hor))+
  geom_point(aes(color=meta$claudin), alpha=0.5)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  scale_color_manual(values=c("red", "black", "darkgrey"))+ 
  labs(col = "Subtype")+
  ggtitle("TCGA_BRCA(Claudin-low subtype)")



######################################################################################
################ Supplementary Fig 18B ###############################################
######################################################################################
results <- readRDS("...zenodo/PAM50/TCGA_claudin.rds")

load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50

meta <- data.frame(Tissue, Subtype)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta$histology <- sampleData$primary_diagnosis
meta$class <- "Others"
levels(as.factor(sampleData$primary_diagnosis))
meta$class[meta$histology == "Metaplastic carcinoma, NOS"] <- "Metaplastic"
meta$class[meta$Subtype == "Normal_MG" ] <- "Normal_MG" 
meta$claudin <- as.character(results$Call)
meta$claudin[meta$Subtype == "Normal_MG" ] <- "Normal_MG" 
meta$claudin[meta$claudin =="Claudin"] <- "Claudin-low"
meta$claudin2 <- "Others"
meta$claudin2[meta$Subtype == "Basal" & meta$claudin =="Claudin"] <- "Claudin-low"
meta$claudin2[meta$Subtype == "Normal_MG" ] <- "Normal_MG" 
meta <- na.omit(meta)

BRCA_gsvaResult <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)

###
meta <- meta[meta$Tissue=="TP",]
df <- BRCA_gsvaResult[row.names(meta),]
df <- data.frame(df, meta)

p1 <- ggplot(df, aes(x=class, y=Curated_Stem, fill=class))+
  geom_violin(alpha=0.5)+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c("red", "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Stem gene set")+
  guides(fill=F)+
  xlab("")

p2 <- ggplot(df, aes(x=class, y=Curated_Basal, fill=class))+
  geom_violin(alpha=0.5)+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c("red", "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal gene set")+
  guides(fill=F)+
  xlab("")

p3 <- ggplot(df, aes(x=class, y=Curated_Alv, fill=class))+
  geom_violin(alpha=0.5)+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c("red", "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Alv gene set")+
  guides(fill=F)+
  xlab("")

p4 <- ggplot(df, aes(x=class, y=Curated_Hor, fill=class))+
  geom_violin(alpha=0.5)+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c("red", "darkgrey"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Hor gene set")+
  guides(fill=F)+
  xlab("")

SFig18B <- plot_grid(p1,p2,p3,p4, ncol=4)



######################################################################################
################ Supplementary Fig 18C ###############################################
######################################################################################
# TNBC subtyping was retrieved from Jovanovic et al. paper
TNBCsub <- read.csv("...zenodo/TCGA/Jovanovic_TNBC_subtyping.csv", header = T, row.names = 1)

load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50
Age <- sampleData$age_at_diagnosis
Age.y <- Age/365

meta <- data.frame(Tissue, Subtype, Age.y)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta <- na.omit(meta)
meta <- cbind(row.names(meta), meta)
colnames(meta)[1]="ID"

TNBCsub <- cbind(row.names(TNBCsub), TNBCsub)
colnames(TNBCsub)[1]="ID"

meta.TNBC <- merge(meta, TNBCsub, by.x="ID", by.y="ID", all=T)
colnames(meta.TNBC)[3:4] <- c("PAM50", "TNBC") 
meta.TNBC$TNBC[is.na(meta.TNBC$TNBC)==T] <- "Others"
meta.TNBC$TNBC[meta.TNBC$TNBC=="UNC"] <- "Others"

###
BRCA_gsvaResult <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)
BRCA_gsvaResult <- BRCA_gsvaResult[meta.TNBC$ID,]
colnames(BRCA_gsvaResult)[1] <- "Curated_Stem"

data_tern <- BRCA_gsvaResult
data_tern$Curated_Stem <- range01(data_tern$Curated_Stem)
data_tern$Curated_Basal <- range01(data_tern$Curated_Basal)
data_tern$Curated_Alv <- range01(data_tern$Curated_Alv)
data_tern$Curated_Hor <- range01(data_tern$Curated_Hor)

colnames(data_tern) <- c("Stem", "Basal", "Alv", "Hor")

p1 <- ggtern(data=data_tern, aes(Basal, Alv, Hor))+
  geom_point(aes(color=meta.TNBC$TNBC), size=2)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(gg_color(4), "#A9A9A930"))+ 
  labs(col = "Subtype")+
  ggtitle("TCGA_TNBC_subtyping")

sub <- cbind(data_tern, meta.TNBC)
sub <- sub[sub$TNBC != "Others",]

p2 <- ggplot(sub, aes(x=TNBC, y=Stem, fill=TNBC))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = gg_color(4))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Stem score")

p3 <- ggplot(sub, aes(x=TNBC, y=Basal, fill=TNBC))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = gg_color(4))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal score")

p4 <- ggplot(sub, aes(x=TNBC, y=Alv, fill=TNBC))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = gg_color(4))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Alv score")

p5 <- ggplot(sub, aes(x=TNBC, y=Hor, fill=TNBC))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = gg_color(4))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Hor score")

p6 <- plot_grid(p2,p3,p4,p5, ncol=2, align = "hv")

SFig18C <- plot_grid(p1,p6, ncol=2)



######################################################################################
################ Supplementary Fig 18D ###############################################
######################################################################################
BRCA_gsvaResult <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)
BRCA_gsvaResult <- BRCA_gsvaResult[meta.TNBC$ID,]
colnames(BRCA_gsvaResult)[1] <- "Curated_Stem"

data_tern <- BRCA_gsvaResult
data_tern$Curated_Stem <- range01(data_tern$Curated_Stem)
data_tern$Curated_Basal <- range01(data_tern$Curated_Basal)
data_tern$Curated_Alv <- range01(data_tern$Curated_Alv)
data_tern$Curated_Hor <- range01(data_tern$Curated_Hor)

colnames(data_tern) <- c("Stem", "Basal", "Alv", "Hor")

BRCA_data <- cbind(data_tern, meta.TNBC)
BRCA_data <- BRCA_data[BRCA_data$Tissue == "TP",]
Trim_ID <- substr(BRCA_data$ID, 1, 12)
length(unique(Trim_ID))
BRCA_data <- cbind(BRCA_data, Trim_ID)

# BRCA status was retrieved from Kraya et al. paper
BRCA <- read.csv("...zenodo/TCGA/Kraya_S1_Table_BRCA.csv", header = T)
BRCA_data <- merge(BRCA_data, BRCA, by.x="Trim_ID", by.y="ID", all=T)
BRCA_data <- BRCA_data[is.na(BRCA_data$Stem) == F, ]
BRCA_data <- BRCA_data[is.na(BRCA_data$Gene_Altered) == F, ]
BRCA_data$BRCA <- "Others" 
BRCA_data$BRCA[BRCA_data$Gene_Altered == "BRCA1"] <- "BRCA1"
BRCA_data$BRCA[BRCA_data$Gene_Altered == "BRCA2"] <- "BRCA2"

p1 <- ggtern(data=BRCA_data, aes(Basal, Alv, Hor))+
  geom_point(aes(color=BRCA), size=2)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  scale_color_manual(values = c(gg_color(2), "#A9A9A930"))+ 
  labs(col = "Subtype")+
  ggtitle("TCGA_BRCA_mutation")

p2 <- ggplot(BRCA_data, aes(x=BRCA, y=Stem, fill=BRCA))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(gg_color(2), "#A9A9A9"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Stem score")

p3 <- ggplot(BRCA_data, aes(x=BRCA, y=Basal, fill=BRCA))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(gg_color(2), "#A9A9A9"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal score")

p4 <- ggplot(BRCA_data, aes(x=BRCA, y=Alv, fill=BRCA))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(gg_color(2), "#A9A9A9"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Alv score")

p5 <- ggplot(BRCA_data, aes(x=BRCA, y=Hor, fill=BRCA))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = c(gg_color(2), "#A9A9A9"))+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=15,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=15,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Hor score")

p6 <- plot_grid(p2,p3,p4,p5, ncol=2, align = "hv")

SFig18D <- plot_grid(p1,p6, ncol=2)



######################################################################################
################ Supplementary Fig 18E ###############################################
######################################################################################
load("...zenodo/TCGA/brca.exp.rd")
col <- colData(data)
sampleData <- col@listData
Barcode <- sampleData$barcode
Tissue <- sampleData$shortLetterCode
Subtype <- sampleData$subtype_BRCA_Subtype_PAM50
Age <- sampleData$age_at_diagnosis
Age.y <- Age/365

meta <- data.frame(Tissue, Subtype, Age.y)
row.names(meta) <- Barcode
meta$Subtype <- as.character(meta$Subtype)
meta$Subtype[meta$Tissue == "NT"] <- "Normal_MG" 
meta$Subtype[meta$Subtype == "Normal"] <- "Normal-like" 
meta <- na.omit(meta)
meta <- cbind(row.names(meta), meta)
colnames(meta)[1]="ID"

#
BRCA_gsvaResult <- read.csv("...zenodo/TCGA/TCGA_GSVA.csv", row.names = 1)
BRCA_gsvaResult <- BRCA_gsvaResult[meta.TNBC$ID,]
colnames(BRCA_gsvaResult)[1] <- "Curated_Stem"

data_tern <- BRCA_gsvaResult
data_tern$Curated_Stem <- range01(data_tern$Curated_Stem)
data_tern$Curated_Basal <- range01(data_tern$Curated_Basal)
data_tern$Curated_Alv <- range01(data_tern$Curated_Alv)
data_tern$Curated_Hor <- range01(data_tern$Curated_Hor)

colnames(data_tern) <- c("Stem", "Basal", "Alv", "Hor")
data_tern <- data_tern[row.names(meta), ]

p1 <- ggtern(data=data_tern, aes(Basal, Alv, Hor))+
  geom_point_swap(aes(fill=meta$Age.y), size=2)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+ 
  labs(fill = "Age")+
  ggtitle("Relationship_origin_and_age")

Cor_data <- cbind(data_tern, meta$Age.y)
colnames(Cor_data)[5] <- "Age"
M <- cor(Cor_data)
p2 <- ggcorrplot(M, hc.order = TRUE, type = "lower",
                 lab = TRUE,
                 ggtheme = ggplot2::theme_gray,
                 colors = c("#6D9EC1", "white", "#E46726"))

SFig18E <- plot_grid(p1,p2, ncol=2)