# Supplementary figure 19



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}



#######################################################################
############ SFig. 19A    #############################################
#######################################################################
HBC <- readRDS("...zenodo/scBRCA/HBC_tumor.rds")

HBC <- NormalizeData(HBC)
HBC <- FindVariableFeatures(HBC, selection.method = "vst", nfeatures = 2000)
all.genes <- rownames(HBC)
HBC <- ScaleData(HBC, features = all.genes)
HBC <- RunPCA(HBC, features = VariableFeatures(object = HBC))
ElbowPlot(HBC)
HBC$Subtype <- factor(HBC$Subtype, levels = c("TNBC", "HER2", "LumA", "LumB"))

HBC$PAM50 <- "LumB"
HBC$patient <- as.character(HBC$patient)
HBC$PAM50[HBC$patient %in% c("BC02")] <- "LumA"
HBC$PAM50[HBC$patient %in% c("BC04", "BC05")] <- "Her2"
HBC$PAM50[HBC$patient %in% c("BC08", "BC10")] <- "Normal"
HBC$PAM50[HBC$patient %in% c("BC11")] <- "Basal"

HBC <- RunUMAP(HBC, dims = 1:5)
HBC <- FindNeighbors(HBC, dims = 1:5)
HBC <- FindClusters(HBC, resolution = 0.5)

p1 <- UMAPPlot(HBC, group.by="patient", pt.size=2)+ggtitle("BRCA(scRNAseq)")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+ 
  labs(col = "Patient")
p2 <- UMAPPlot(HBC, group.by="PAM50", pt.size=2, cols=pam50.col)+ggtitle("BRCA(scRNAseq)")+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+ 
  labs(col = "Subtype")
Sfig19A <- plot_grid(p1, p2, ncol=2)



#######################################################################
############ SFig. 19B    #############################################
#######################################################################
HBC_res <- read.csv("...zenodo/GSVA/Human/HBC_GSVA.csv", row.names=1)
HBC_res$Subtype <- as.character(HBC_res$Subtype)
HBC_res$Subtype[HBC_res$Subtype == "HER2"] <- "Her2"
HBC_res$Subtype <- factor(HBC_res$Subtype, levels = c("TNBC", "Her2", "LumA", "LumB"))

HBC_res$PAM50 <- "LumB"
HBC_res$patient <- as.character(HBC_res$patient)
HBC_res$PAM50[HBC_res$patient %in% c("BC02")] <- "LumA"
HBC_res$PAM50[HBC_res$patient %in% c("BC04", "BC05")] <- "Her2"
HBC_res$PAM50[HBC_res$patient %in% c("BC08", "BC10")] <- "Normal"
HBC_res$PAM50[HBC_res$patient %in% c("BC11")] <- "Basal"

p1 <- ggplot(HBC_res, aes(x=patient, y=Curated_Stem, fill=PAM50))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = pam50.col)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Stem gene set")

p2 <- ggplot(HBC_res, aes(x=patient, y=Curated_Basal, fill=PAM50))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = pam50.col)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Basal gene set")

p3 <- ggplot(HBC_res, aes(x=patient, y=Curated_Alv, fill=PAM50))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = pam50.col)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Alv gene set")

p4 <- ggplot(HBC_res, aes(x=patient, y=Curated_Hor, fill=PAM50))+
  geom_violin()+ 
  geom_jitter(shape=16, position=position_jitter(0.2))+
  scale_fill_manual(values = pam50.col)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+
  ylab("GSVA score")+
  ggtitle("Hor gene set")

SFig19B <- plot_grid(p1,p2,p3,p4, ncol=2, align = "hv")



#######################################################################
############ SFig. 19C    #############################################
#######################################################################
HBC_res <- read.csv("...zenodo/GSVA/Human/HBC_GSVA.csv", row.names=1)
HBC_res$Subtype <- as.character(HBC_res$Subtype)
HBC_res$Subtype[HBC_res$Subtype == "HER2"] <- "Her2"
HBC_res$Subtype <- factor(HBC_res$Subtype, levels = c("TNBC", "Her2", "LumA", "LumB"))

HBC_res$PAM50 <- "LumB"
HBC_res$patient <- as.character(HBC_res$patient)
HBC_res$PAM50[HBC_res$patient %in% c("BC02")] <- "LumA"
HBC_res$PAM50[HBC_res$patient %in% c("BC04", "BC05")] <- "Her2"
HBC_res$PAM50[HBC_res$patient %in% c("BC08", "BC10")] <- "Normal"
HBC_res$PAM50[HBC_res$patient %in% c("BC11")] <- "Basal"

data_tern <- HBC_res
data_tern$Curated_Stem <- range01(data_tern$Curated_Stem)
data_tern$Curated_Basal <- range01(data_tern$Curated_Basal)
data_tern$Curated_Alv <- range01(data_tern$Curated_Alv)
data_tern$Curated_Hor <- range01(data_tern$Curated_Hor)

colnames(data_tern) <- c("Stem", "Basal", "Alv", "Hor")

SFig19C <- ggtern(data=data_tern, aes(Basal, Alv, Hor))+
  geom_point(aes(color=HBC_res$patient), alpha=0.5)+
  theme(plot.title = element_text(size=20, face="bold"),
        axis.text=element_text(size=12),
        axis.title=element_text(size=14,face="bold"),
        legend.text=element_text(size=12),
        legend.title=element_text(size=14,face="bold"))+ 
  labs(col = "Subtype")+
  ggtitle("BRCA(scRNAseq)")

