# Supplementary figure 2



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}



########################################################################
###### Data preparation ################################################
########################################################################

# See "zenodo/Code/Peocessing_Analysis/Mouse_sample_preprocessing.R" for data retrieval.

## Giraddi
data_dir <- "...your_folder/Giraddi/data"
list.files(data_dir)
#[1] "barcodes.tsv" "genes.tsv"    "matrix.mtx"
expression_matrix <- Read10X(data.dir = data_dir)
Giraddi = CreateSeuratObject(counts = expression_matrix, project = "Giraddi", min.cells = 3, min.features = 200)
Giraddi[["percent.mt"]] <- PercentageFeatureSet(Giraddi, pattern = "^mt-")
Giraddi@meta.data[,"Dataset"] <- rep("Giraddi", length(row.names(Giraddi@meta.data)))
Giraddi@meta.data$orig.ident <- factor(Giraddi@meta.data$orig.ident,
                                           levels=c("E16","E18","P4","Adu1","Adu2", "AduBas"))
Idents(Giraddi) <- "orig.ident"
current.cluster.ids <- c("E16","E18","P4","Adu1","Adu2", "AduBas")
new.cluster.ids <- c("Embryonic_d16(G)", "Embryonic_d18(G)",  "Postnatal_d4(G)","Adult_1(G)", "Adult_2(G)", "Adult_Basal(G)")
Giraddi@active.ident <- plyr::mapvalues(x = Giraddi@active.ident, from = current.cluster.ids, to = new.cluster.ids)
Giraddi@meta.data[,"Dataset"] <- rep("Giraddi", length(row.names(Giraddi@meta.data)))
Giraddi$orig.ident <- Giraddi@active.ident
Giraddi@meta.data$orig.ident <- factor(Giraddi@meta.data$orig.ident,
                                           levels=c("Embryonic_d16(G)", "Embryonic_d18(G)",  "Postnatal_d4(G)","Adult_1(G)", "Adult_2(G)", "Adult_Basal(G)"))
remove(data_dir, expression_matrix)

## Pal
### Adult epithelial 
Pal_dir <- "...your_folder/Pal/data/Adult_Epi"
list.files(Pal_dir) 
# barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
AduEpi = CreateSeuratObject(counts = expression_matrix, project = "Adult(P)", min.cells = 3, min.features = 200)
AduEpi[["percent.mt"]] <- PercentageFeatureSet(AduEpi, pattern = "^mt-")

### Adult basal 
Pal_dir <- "...your_folder/Pal/data/Adult_Bas"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
AduBas = CreateSeuratObject(counts = expression_matrix, project = "Adult_Basal(P)", min.cells = 3, min.features = 200)
AduBas[["percent.mt"]] <- PercentageFeatureSet(AduBas, pattern = "^mt-")

### Adult puberty_1 
Pal_dir <- "...your_folder/Pal/data/Puberty_1"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Pub1 = CreateSeuratObject(counts = expression_matrix, project = "Puberty_1(P)", min.cells = 3, min.features = 200)
Pub1[["percent.mt"]] <- PercentageFeatureSet(Pub1, pattern = "^mt-")

### Adult puberty_2 
Pal_dir <- "...your_folder/Pal/data/Puberty_2"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Pub2 = CreateSeuratObject(counts = expression_matrix, project = "Puberty_2(P)", min.cells = 3, min.features = 200)
Pub2[["percent.mt"]] <- PercentageFeatureSet(Pub2, pattern = "^mt-")

### Adult Diestrus 
Pal_dir <- "...your_folder/Pal/data/Adult_Diestrus"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Diestrus = CreateSeuratObject(counts = expression_matrix, project = "Adult_Diestrus(P)", min.cells = 3, min.features = 200)
Diestrus[["percent.mt"]] <- PercentageFeatureSet(Diestrus, pattern = "^mt-")

### Adult Estrus 
Pal_dir <- "...your_folder/Pal/data/Adult_Estrus"
list.files(Pal_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Pal_dir)
Estrus = CreateSeuratObject(counts = expression_matrix, project = "Adult_Estrus(P)", min.cells = 3, min.features = 200)
Estrus[["percent.mt"]] <- PercentageFeatureSet(Estrus, pattern = "^mt-")

###
Pal <- merge(AduEpi, y = c(AduBas, Diestrus, Estrus, Pub1, Pub2), 
             add.cell.ids = c("Pal_Epi", "Pal_Bas", "Pal_Die", "Pal_Est", "Pal_Pub1", "Pal_Pub2"), 
             project = "Pal")
Pal$orig.ident <- factor(Pal$orig.ident, 
                         levels=c("Puberty_1(P)","Puberty_2(P)","Adult(P)", "Adult_Diestrus(P)", "Adult_Estrus(P)", "Adult_Basal(P)"))
Pal@meta.data[,"Dataset"] <- rep("Pal", length(row.names(Pal@meta.data)))
remove(Pal_dir, expression_matrix, AduBas, AduEpi, Diestrus, Estrus, Pub1, Pub2)


## Bach
### Nulliparous 
Bach_dir <- "...your_folder/Bach/data/NP_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
NP1 = CreateSeuratObject(counts = expression_matrix, project = "Nulliparous_1(B)", min.cells = 3, min.features = 200)
NP1[["percent.mt"]] <- PercentageFeatureSet(NP1, pattern = "^mt-")
#
Bach_dir <- "...your_folder/Bach/data/NP_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
NP2 = CreateSeuratObject(counts = expression_matrix, project = "Nulliparous_2(B)", min.cells = 3, min.features = 200)
NP2[["percent.mt"]] <- PercentageFeatureSet(NP2, pattern = "^mt-")

### Gestation 
Bach_dir <- "...your_folder/Bach/data/G_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
G1 = CreateSeuratObject(counts = expression_matrix, project = "Gestation_1(B)", min.cells = 3, min.features = 200)
G1[["percent.mt"]] <- PercentageFeatureSet(G1, pattern = "^mt-")
##
Bach_dir <- "...your_folder/Bach/data/G_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
G2 = CreateSeuratObject(counts = expression_matrix, project = "Gestation_2(B)", min.cells = 3, min.features = 200)
G2[["percent.mt"]] <- PercentageFeatureSet(G2, pattern = "^mt-")

### Involution 
Bach_dir <- "...your_folder/Bach/data/PI_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
PI1 = CreateSeuratObject(counts = expression_matrix, project = "PostInvolution_1(B)", min.cells = 3, min.features = 200)
PI1[["percent.mt"]] <- PercentageFeatureSet(PI1, pattern = "^mt-")
##
Bach_dir <- "...your_folder/Bach/data/PI_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
PI2 = CreateSeuratObject(counts = expression_matrix, project = "PostInvolution_2(B)", min.cells = 3, min.features = 200)
PI2[["percent.mt"]] <- PercentageFeatureSet(PI2, pattern = "^mt-")

### Lactation 
Bach_dir <- "...your_folder/Bach/data/L_1"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
L1 = CreateSeuratObject(counts = expression_matrix, project = "Lactation_1(B)", min.cells = 3, min.features = 200)
L1[["percent.mt"]] <- PercentageFeatureSet(L1, pattern = "^mt-")
##
Bach_dir <- "...your_folder/Bach/data/L_2"
list.files(Bach_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = Bach_dir)
L2 = CreateSeuratObject(counts = expression_matrix, project = "Lactation_2(B)", min.cells = 3, min.features = 200)
L2[["percent.mt"]] <- PercentageFeatureSet(L2, pattern = "^mt-")

###
Bach <- merge(G1, y = c(G2, L1, L2, NP1, NP2, PI1, PI2),
              add.cell.ids = c("G1", "G2", "L1", "L2", "NP1", "NP2", "PI1", "PI2"), project = "Bach")
Bach@meta.data[,"Dataset"] <- rep("Bach", length(row.names(Bach@meta.data)))
Bach$orig.ident <- factor(Bach$orig.ident,
                          levels=c("Nulliparous_1(B)", "Nulliparous_2(B)", "Gestation_1(B)",
                                   "Gestation_2(B)", "Lactation_1(B)", "Lactation_2(B)",
                                   "PostInvolution_1(B)", "PostInvolution_2(B)"))
remove(G1, G2, L1, L2, NP1, NP2, PI1, PI2, expression_matrix, Bach_dir)


## TabulaMuris 
load("...your_folder/TabulaMuris/droplet_Mammary_seurat_tiss.Robj")
tiss <- UpdateSeuratObject(tiss)
colnames(tiss@meta.data)[1:2] <- c("nFeature_RNA", "nCount_RNA")
tiss[["percent.mt"]] <- PercentageFeatureSet(tiss, pattern = "^mt-")
Idents(tiss) <- "channel"
new.cluster.ids <- c("Adult_1(TM)", "Adult_2(TM)")
names(new.cluster.ids) <- levels(tiss)
tiss <- RenameIdents(tiss, new.cluster.ids)
tiss$orig.ident <- tiss@active.ident
tiss@meta.data <- tiss@meta.data[, c(1:3, 14)]
TabulaMuris <- tiss
TabulaMuris@meta.data[,"Dataset"] <- rep("TabulaMuris", length(row.names(TabulaMuris@meta.data)))
remove(new.cluster.ids, tiss)


### Saeki 
### OVX
data_dir <- "...your_folder/Saeki/data/OVX_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX(S)", min.cells = 3, min.features = 200)
OVX_20[["percent.mt"]] <- PercentageFeatureSet(OVX_20, pattern = "^mt-")

### E2
data_dir <- "...your_folder/Saeki/data/OVX_E2_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2(S)", min.cells = 3, min.features = 200)
OVX_E2_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_20, pattern = "^mt-")

### E2+PBDE 
data_dir <- "...your_folder/Saeki/data/OVX_E2_PBDE_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_PBDE_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2_PBDE(S)", min.cells = 3, min.features = 200)
OVX_E2_PBDE_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_PBDE_20, pattern = "^mt-")

### E2+P4 
data_dir <- "...your_folder/Saeki/data/OVX_E2_P4_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_P4_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2_P4(S)", min.cells = 3, min.features = 200)
OVX_E2_P4_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_P4_20, pattern = "^mt-")

### E2+P4+PBDE 
data_dir <- "...your_folder/Saeki/data/OVX_E2_P4_PBDE_20"
list.files(data_dir) # Should show barcodes.tsv, genes.tsv, and matrix.mtx
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_P4_PBDE_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2_P4_PBDE(S)", min.cells = 3, min.features = 200)
OVX_E2_P4_PBDE_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_P4_PBDE_20, pattern = "^mt-")

###
Saeki <- merge(OVX_20, y = c(OVX_E2_20, OVX_E2_PBDE_20, OVX_E2_P4_20, OVX_E2_P4_PBDE_20), 
              add.cell.ids = c("OVX", "OVX_E2", "OVX_E2_PBDE", "OVX_E2_P4", "OVX_E2_P4_PBDE"), project = "Saeki")
Saeki@meta.data[,"Dataset"] <- rep("Saeki", length(row.names(Saeki@meta.data)))
Saeki$orig.ident <- factor(Saeki$orig.ident,
                          levels=c("OVX(S)", "OVX_E2(S)", "OVX_E2_PBDE(S)",
                                   "OVX_E2_P4(S)", "OVX_E2_P4_PBDE(S)"))
remove(OVX_20, OVX_E2_20, OVX_E2_PBDE_20, OVX_E2_P4_20, OVX_E2_P4_PBDE_20, expression_matrix, data_dir)



########################################################################
###### Supplementary Fig. 2A ###########################################
########################################################################
seu <- merge(Giraddi, y = c(Pal, Bach, TabulaMuris, Saeki), add.cell.ids = NULL, project = "Combined")
Idents(seu) <- "Dataset"
col <- c(wes_palette("IsleofDogs1", 5))

p1 <- VlnPlot(seu, "nFeature_RNA",cols=col, pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p2 <- VlnPlot(seu, "nCount_RNA",cols=col, pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p3 <- VlnPlot(seu, "percent.mt",cols=col, pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))
Sfig2A <- plot_grid(p1, p2, p3, ncol=3)



########################################################################
###### Supplementary Fig. 2B ###########################################
########################################################################
col <- c(wes_palette("GrandBudapest1"), wes_palette("GrandBudapest2"))

p4 <- VlnPlot(Giraddi, "nFeature_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p5 <- VlnPlot(Giraddi, "nCount_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p6 <- VlnPlot(Giraddi, "percent.mt",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

Sfig2B <- plot_grid(p4, p5, p6, ncol=3)



########################################################################
###### Supplementary Fig. 2C ###########################################
########################################################################
p7 <- VlnPlot(Pal, "nFeature_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p8 <- VlnPlot(Pal, "nCount_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p9 <- VlnPlot(Pal, "percent.mt",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

Sfig2C <- plot_grid(p7, p8, p9, ncol=3)



########################################################################
###### Supplementary Fig. 2D ###########################################
########################################################################
p10 <- VlnPlot(Bach, "nFeature_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p11 <- VlnPlot(Bach, "nCount_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p12 <- VlnPlot(Bach, "percent.mt",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

Sfig2D <- plot_grid(p10, p11, p12, ncol=3)



########################################################################
###### Supplementary Fig. 2E ###########################################
########################################################################
p13 <- VlnPlot(TabulaMuris, "nFeature_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p14 <- VlnPlot(TabulaMuris, "nCount_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p15 <- VlnPlot(TabulaMuris, "percent.mt",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

Sfig2E <- plot_grid(p13, p14, p15, ncol=3)


########################################################################
###### Supplementary Fig. 2F ###########################################
########################################################################
p16 <- VlnPlot(Saeki, "nFeature_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p17 <- VlnPlot(Saeki, "nCount_RNA",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

p18 <- VlnPlot(Saeki, "percent.mt",cols=col, pt.size=0, group.by = "orig.ident")+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=16, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16,face="bold"))

Sfig2F <- plot_grid(p16, p17, p18, ncol=3)