# Supplementary figure 20



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')

## Function
range01 <- function(x){(x-min(x))/(max(x)-min(x))}



######################################################
#########Supplementary Fig. 20A ######################
######################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
seu$PAM50 <- PAM50Preds$subtype
seu$PAM50 <- factor(seu$PAM50, levels = c("Basal", "Her2", "LumA", "LumB", "Normal"))
Idents(seu) <- "PAM50"
levels(seu)

###
pam50 <- pam50
gene <- pam50$centroids.map$probe

human = biomaRt::useMart("ensembl", dataset = "hsapiens_gene_ensembl")
mouse = biomaRt::useMart("ensembl", dataset = "mmusculus_gene_ensembl")
gene.list = biomaRt::getLDS(attributes = c("hgnc_symbol"), filters = "hgnc_symbol", 
                            values = gene,
                            mart = human, attributesL = c("mgi_symbol"), martL = mouse, uniqueRows = T)
m.gene <- gene.list$MGI.symbol


###
Idents(seu) <- "Annotation"
MaSC <- sample(WhichCells(seu, idents="MaSC/B-pro"), 1000)
Basal <- sample(WhichCells(seu, idents="Basal"), 1000)
Pro_A <- sample(WhichCells(seu, idents="LA-pro"), 1000)
Alveolar <- sample(WhichCells(seu, idents="L-Alv"), 1000)
Pro_H <- sample(WhichCells(seu, idents="LH-pro"), 1000)
HR <- sample(WhichCells(seu, idents="L-Hor"), 1000)

sub <- subset(seu, cells=c(MaSC, Basal, Pro_A, Alveolar, Pro_H, HR))
UMAPPlot(sub, cols=pam50.col, group.by="PAM50")
saveRDS(sub, "...zenodo/PAM50/Mouse_Cluster_1000_sampled.rds")

sub <- readRDS("...zenodo/PAM50/Mouse_Cluster_1000_sampled.rds")
sub@active.assay <- "RNA"
sub <- ScaleData(sub)
heat.data <- sub@assays$RNA@scale.data
dim(heat.data)
range(heat.data)
hist(heat.data)

heat.data[heat.data < -2.5] <- -2.5
heat.data[heat.data > 2.5] <- 2.5
range(heat.data)
hist(heat.data)

heat.data <- heat.data[row.names(heat.data) %in% m.gene,]
heat.data <- as.matrix(heat.data)

pheatmap(heat.data,scale = "none", show_colnames = F)

#%
metadata <- sub@meta.data
metadata <- metadata[,c("Study", "PAM50", "Annotation")]
metadata <- metadata[colnames(heat.data),]
colnames(metadata)[3] <- "Cluster"
metadata$Barcode <- row.names(metadata)

metadata$Cluster <- as.character(metadata$Cluster)
metadata$Cluster[metadata$Cluster == "MaSC/B-pro"] <- "MaSC_Bpro"
metadata$Cluster[metadata$Cluster == "LA-pro"] <- "LA_pro"
metadata$Cluster[metadata$Cluster == "L-Alv"] <- "L_Alv"
metadata$Cluster[metadata$Cluster == "LH-pro"] <- "LH_pro"
metadata$Cluster[metadata$Cluster == "L-Hor"] <- "L_Hor"
metadata$Cluster <- factor(metadata$Cluster, levels = c("MaSC_Bpro", "Basal", "LA_pro", "L_Alv", "LH_pro", "L_Hor"))

metadata <- metadata %>% arrange(Study) %>% arrange(PAM50) %>% arrange(Cluster) 
heat.data <- heat.data[,metadata$Barcode]
row.names(metadata) <- metadata$Barcode

#%
my_colour = list(
  Cluster = c(MaSC_Bpro=col.clst[1], Basal=col.clst[2], 
              LA_pro=col.clst[3], L_Alv=col.clst[4],
              LH_pro=col.clst[5], L_Hor=col.clst[6]),
  Study = c(Giraddi=col.std[1], Pal=col.std[2],
            Bach=col.std[3], TabulaMuris=col.std[4],
            Saeki=col.std[5]),
  PAM50 = c(Basal=pam50.col[1], Her2=pam50.col[2], 
            LumA=pam50.col[3], LumB=pam50.col[4],
            Normal=pam50.col[5]))

pheatmap(heat.data, show_colnames = F, annotation_col = metadata[,1:3],
         cluster_cols = F,
         annotation_colors = my_colour,
         cutree_rows = 5, width=10, hight=8,
         treeheight_row = 20)



######################################################
#########Supplementary Fig. 20B ######################
######################################################
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")

PAM50Preds <- readRDS("...zenodo/PAM50/Nguyen_PAM50.rds")
Nguyen$PAM50 <- PAM50Preds$subtype

###
pam50 <- pam50
gene <- pam50$centroids.map$probe

#%
Idents(Nguyen) <- "clust"
B <- sample(WhichCells(Nguyen, idents="B/Myo"), 2000)
L1 <- sample(WhichCells(Nguyen, idents="L1.1/L1.2"), 2000)
L2 <- sample(WhichCells(Nguyen, idents="L2"), 2000)

sub <- subset(Nguyen, cells=c(B, L1, L2))
saveRDS(sub, "...zenodo/PAM50/Human_PAM50_2000_sampled.rds")

sub <- readRDS("...zenodo/PAM50/Human_PAM50_2000_sampled.rds")
sub@active.assay <- "RNA"
sub <- ScaleData(sub)
heat.data <- sub@assays$RNA@scale.data
dim(heat.data)
range(heat.data)
hist(heat.data)

heat.data[heat.data < -2.5] <- -2.5
heat.data[heat.data > 2.5] <- 2.5
range(heat.data)
hist(heat.data)

heat.data <- heat.data[row.names(heat.data) %in% gene,]
heat.data <- as.matrix(heat.data)

pheatmap(heat.data, show_colnames = F)

#%
metadata <- sub@meta.data
metadata <- metadata[,c("orig.ident", "PAM50", "clust")]
metadata <- metadata[colnames(heat.data),]
colnames(metadata)[c(1,3)] <- c("Individual", "Cluster")
metadata$Barcode <- row.names(metadata)

metadata$Cluster <- as.character(metadata$Cluster)
metadata$Cluster[metadata$Cluster == "B/Myo"] <- "B_Myo"
metadata$Cluster[metadata$Cluster == "L1.1/L1.2"] <- "L1"
metadata$Cluster <- factor(metadata$Cluster, levels = c("B_Myo", "L1", "L2"))
metadata$PAM50 <- factor(metadata$PAM50, levels = c("Basal", "Her2", "LumA", "LumB", "Normal"))

metadata <- metadata %>% arrange(Individual) %>% arrange(PAM50) %>% arrange(Cluster) 
heat.data <- heat.data[,metadata$Barcode]
row.names(metadata) <- metadata$Barcode

#%
my_colour = list(
  Cluster = c(B_Myo=col.clst[2], 
              L1=col.clst[4],
              L2=col.clst[6]),
  PAM50 = c(Basal=pam50.col[1], Her2=pam50.col[2], 
            LumA=pam50.col[3], LumB=pam50.col[4],
            Normal=pam50.col[5]))

pheatmap(heat.data, show_colnames = F, annotation_col = metadata[,1:3],
         cluster_cols = F,
         annotation_colors = my_colour,
         cutree_rows = 5, width=10, hight=8,
         treeheight_row = 20)


