# Supplementary figure 21



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
col.human <- c("#FF7F00", "#33A02C", "#E31A1C")
pam50.col <- c('#7fc97f','#beaed4','#fdc086','#ffff99','#386cb0')



####################################################################
################ Supplementary Fig.21A ##############################
####################################################################
###
Nguyen <- readRDS("...zenodo/Human_normal_breast_data/Nguyen_integrated_cleaned.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Nguyen_PAM50.rds")
Nguyen$PAM50 <- PAM50Preds$subtype

stat <- as.data.frame(table(Nguyen$clust, Nguyen$PAM50))
colnames(stat) <- c("Cluster", "PAM50", "Freq")
SFig21A_1 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Cluster, fill = PAM50), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = pam50.col)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "PAM50")+
  ggtitle("Human_breast(PAM50)")



###
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
seu$PAM50 <- PAM50Preds$subtype
UMAPPlot(seu, group.by="PAM50", cols=pam50.col)

stat <- as.data.frame(table(seu$Annotation, seu$PAM50))
colnames(stat) <- c("Cluster", "PAM50", "Freq")
SFig21A_2 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Cluster, fill = PAM50), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = pam50.col)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "PAM50")+
  ggtitle("Mouse MG(PAM50)")




####################################################################
################ Supplementary Fig.21B #############################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
seu$PAM50 <- PAM50Preds$subtype
Idents(seu) <- "orig.ident"
sub <- subset(seu, idents = c("Embryonic_d16(G)", "Embryonic_d18(G)", "Postnatal_d4(G)", "Adult_1(G)", "Adult_2(G)",
                              "Puberty_1(P)", "Puberty_2(P)", "Adult(P)", "Nulliparous_1(B)", "Nulliparous_2(B)",
                              "OVX(S)"))
sub_meta <- sub@meta.data
sub_meta$Development <- as.character(sub_meta$Stage)
sub_meta$Development[sub_meta$orig.ident == "Embryonic_d16(G)"] <- "Embryonic(E16)"
sub_meta$Development[sub_meta$orig.ident == "Embryonic_d18(G)"] <- "Embryonic(E18)"
sub@meta.data <- sub_meta
sub$Development <- factor(sub$Development, levels=c("Embryonic(E16)", "Embryonic(E18)", "Neonatal","Pubertal", "Virgin adult", "Menopause" ))

###
stat <- as.data.frame(table(sub$PAM50, sub$Development))
colnames(stat) <- c("PAM50", "Stage", "Freq")
SFig21B <- ggplot() + 
  geom_bar(aes(y = Freq, x = Stage, fill = PAM50), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = pam50.col)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "PAM50")+
  ggtitle("Development")



####################################################################
################ Supplementary Fig.21C ##############################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
seu$PAM50 <- PAM50Preds$subtype
Idents(seu) <- "orig.ident"
sub <- subset(seu, idents = c("Nulliparous_1(B)", "Nulliparous_2(B)", "Gestation_1(B)", "Gestation_2(B)", "Lactation_1(B)", "Lactation_2(B)", 
                              "PostInvolution_1(B)", "PostInvolution_2(B)"))
sub$Stage <- factor(sub$Stage, levels=c("Virgin adult", "Pregnant", "Lactating", "Involuted"))

###
stat <- as.data.frame(table(sub$PAM50, sub$Stage))
colnames(stat) <- c("PAM50", "Stage", "Freq")
SFig21C <- ggplot() + 
  geom_bar(aes(y = Freq, x = Stage, fill = PAM50), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = pam50.col)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "PAM50")+
  ggtitle("Pregnancy")



####################################################################
################ Supplementary Fig.21D ##############################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
seu$PAM50 <- PAM50Preds$subtype
Idents(seu) <- "orig.ident"
p1 <- UMAPPlot(seu, cells.highlight=WhichCells(seu, idents = "OVX(S)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("OVX")
p2 <- UMAPPlot(seu, cells.highlight=WhichCells(seu, idents = "OVX_E2(S)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("OVX+E2")
p3  <- UMAPPlot(seu, cells.highlight=WhichCells(seu, idents = "OVX_E2_PBDE(S)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("OVX+E2+PBDE")
p4  <- UMAPPlot(seu, cells.highlight=WhichCells(seu, idents = "OVX_E2_P4(S)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("OVX+E2+P4")
p5  <- UMAPPlot(seu, cells.highlight=WhichCells(seu, idents = "OVX_E2_P4_PBDE(S)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("OVX+E2+P4+PBDE")
SFig21D <- plot_grid(p1, p2, p3, p4, p5, ncol=5)



####################################################################
################ Supplementary Fig.21E ##############################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
seu$PAM50 <- PAM50Preds$subtype
Idents(seu) <- "Study"
sub <- subset(seu, idents="Saeki")
UMAPPlot(sub, cols=col.clst, group.by="Annotation", pt.size=1)+NoLegend()
seu$orig.ident <- factor(seu$orig.ident, levels=c("OVX(S)","OVX_E2(S)","OVX_E2_PBDE(S)","OVX_E2_P4(S)","OVX_E2_P4_PBDE(S)"  ))

stat <- as.data.frame(table(sub$PAM50, sub$orig.ident))
stat <- stat[106:130,]
colnames(stat) <- c('PAM50', 'Sample', 'Frequency')

# Total cell number was collected from Supplementary table

stat$Frequency[1:5] <- stat$Frequency[1:5]/3107*100
stat$Frequency[6:10] <- stat$Frequency[6:10]/2229*100
stat$Frequency[11:15] <- stat$Frequency[11:15]/3526*100
stat$Frequency[16:20] <- stat$Frequency[16:20]/3097*100
stat$Frequency[21:25] <- stat$Frequency[21:25]/2358*100

SFig21E <- ggplot(data=stat, aes(x=Sample, y=Frequency, fill=PAM50)) + 
  geom_bar(stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = pam50.col)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "PAM50")+
  ggtitle("OVX+HRT")



####################################################################
################ Supplementary Fig.21F #############################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
PAM50Preds <- readRDS("...zenodo/PAM50/Mouse_PAM50.rds")
seu$PAM50 <- PAM50Preds$subtype
Idents(seu) <- "orig.ident"
levels(seu)
sub <- subset(seu, idents = c("Adult_Estrus(P)", "Adult_Diestrus(P)"))

p1 <- UMAPPlot(seu, cells.highlight=WhichCells(seu, idents = "Adult_Estrus(P)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Estrus")
p2  <- UMAPPlot(seu, cells.highlight=WhichCells(seu, idents = "Adult_Diestrus(P)"))+
  theme(plot.title = element_text(size=24, face="bold"))+
  NoLegend()+
  NoAxes()+
  ggtitle("Diestrus")
SFig21F_1 <- plot_grid(p1, p2, ncol=2)



###
stat <- as.data.frame(table(sub$Annotation, sub$orig.ident))
stat <- stat[55:66,]
colnames(stat) <- c("Cluster", "Stage", "Freq")
SFig21F_2 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Stage, fill = Cluster), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = col.clst)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "Cluster")+
  ggtitle("Estrus cycle")



###
stat <- as.data.frame(table(sub$PAM50, sub$orig.ident))
stat <- stat[46:55,]
colnames(stat) <- c("PAM50", "Stage", "Freq")
SFig21F_3 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Stage, fill = PAM50), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=10),
        legend.title = element_text(size=10,face="bold"))+
  scale_fill_manual(values = pam50.col)+
  xlab("Stage")+
  ylab("Frequency")+ 
  labs(fill = "PAM50")+
  ggtitle("Estrus cycle")



####################################################################
################ Supplementary Fig.21G #############################
####################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
p1 <- FeaturePlot(seu, "Tnfsf11", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Tnsf11(RANKL)")


p2 <- VlnPlot(seu, "Tnfsf11", pt.size = 1, group.by= "orig.ident")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=14,face="bold"))+
  NoLegend()+
  ggtitle("Tnsf11(RANKL)")+
  xlab("")

p3 <- FeaturePlot(seu, "Areg", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Areg(Amphiregulin)")

p4 <- VlnPlot(seu, "Areg", pt.size = 1, group.by= "orig.ident")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=14),
        axis.title=element_text(size=14,face="bold"))+
  NoLegend()+
  ggtitle("Areg(Amphiregulin)")+
  xlab("")


Sfig21G <- ggdraw(xlim=c(0,4), ylim = c(0,2))+
  draw_plot(p3, x = 0, y = 1, width = 1, height = 1)+
  draw_plot(p4, x = 1, y = 1, width = 3, height = 1)+
  draw_plot(p1, x = 0, y = 0, width = 1, height = 1)+
  draw_plot(p2, x = 1, y = 0, width = 3, height = 1)