# Supplementary figure 4



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Cell cycle
ConvertHumanGeneListToMM <- function(x){
  # Load human ensembl attributes
  human = biomaRt::useMart("ensembl", dataset = "hsapiens_gene_ensembl")
  # Load mouse ensembl attributes
  mouse = biomaRt::useMart("ensembl", dataset = "mmusculus_gene_ensembl")
  # Link both datasets and retrieve mouse genes from the human genes
  genes.list = biomaRt::getLDS(attributes = c("hgnc_symbol"), filters = "hgnc_symbol", values = x , mart = human, attributesL = c("mgi_symbol"), martL = mouse, uniqueRows = T)
  # Get unique names of genes (in case gene names are duplicated)
  mouse.gene.list <- unique(genes.list[, 2])
  # # Print the first 6 genes found to the screen
  # print(head(mouse.gene.list))
  return(mouse.gene.list)
}
data(cc.genes)
mouse.cc.genes <- lapply(X = cc.genes, 
                         ConvertHumanGeneListToMM)
s.genes <- mouse.cc.genes$s.genes
g2m.genes <- mouse.cc.genes$g2m.genes

## Palette
FP <- wes_palette("Zissou1", 5, type = "discrete")

########################################################################
###### Data preparation ################################################
########################################################################

# See "zenodo/Code/Peocessing_Analysis/Mouse_sample_preprocessing.R" for data retrieval.

data_dir <- "...your_folder/Saeki/data/OVX_E2_20"
expression_matrix <- Read10X(data.dir = data_dir)
OVX_E2_20 = CreateSeuratObject(counts = expression_matrix, project = "OVX_E2(S)", min.cells = 3, min.features = 200)
OVX_E2_20[["percent.mt"]] <- PercentageFeatureSet(OVX_E2_20, pattern = "^mt-")
OVX_E2_20 <- subset(OVX_E2_20, subset = nFeature_RNA > 500 & nCount_RNA > 1000 & percent.mt < 10)

OVX_E2_20 <- NormalizeData(OVX_E2_20)
OVX_E2_20 <- FindVariableFeatures(OVX_E2_20, selection.method = "vst", nfeatures = 2000)
OVX_E2_20 <- ScaleData(OVX_E2_20, features = rownames(OVX_E2_20))
OVX_E2_20 <- RunPCA(OVX_E2_20, features = VariableFeatures(object = OVX_E2_20))

OVX_E2_20 <- RunUMAP(OVX_E2_20, dims=1:10)
OVX_E2_20 <- FindNeighbors(OVX_E2_20, dims = 1:10)
OVX_E2_20 <- FindClusters(OVX_E2_20, resolution = 0.5)


########################################################################
###### Supplementary Fig. 4A ###########################################
########################################################################
p1 <- UMAPPlot(OVX_E2_20, label=T, label.size=8)+
  NoLegend()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("OVX_E2(S)")
p2 <- VlnPlot(OVX_E2_20, "nFeature_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))
p3 <- VlnPlot(OVX_E2_20, "nCount_RNA",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))
p4 <- VlnPlot(OVX_E2_20, "percent.mt",pt.size=0)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))

SFig4A <- plot_grid(p1, p2, p3, p4, ncol=4)


########################################################################
###### Supplementary Fig. 4B ###########################################
########################################################################
markers <- FindAllMarkers(OVX_E2_20, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
top10 <- markers %>% group_by(cluster) %>% top_n(n = 5, wt = avg_logFC)
palette <- wes_palette("Zissou1", 100, type = "continuous")
p5 <- DoHeatmap(OVX_E2_20, features = top10$gene, label = T) +
  scale_fill_gradientn(colors = palette) 

SFig4B <- plot_grid(p5, ncol=1)



########################################################################
###### Supplementary Fig. 4C ###########################################
########################################################################
OVX_E2_20 <- CellCycleScoring(OVX_E2_20, s.features = s.genes, g2m.features = g2m.genes, set.ident = TRUE)
p6 <- UMAPPlot(OVX_E2_20, group.by="Phase")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  ggtitle("Cell cycle")

stat <- as.data.frame(table(OVX_E2_20$seurat_clusters, OVX_E2_20$Phase))
p7 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle("Cell cycle")
Idents(OVX_E2_20) <- "seurat_clusters"
SFig4C <- plot_grid(p6, p7, ncol=2)



########################################################################
###### Supplementary Fig. 4D ###########################################
########################################################################
annotations <- OVX_E2_20@active.ident
homotypic.prop <- modelHomotypic(annotations) 
# pK=19% ,doublet formation rate 20%
nExp_poi <- round(0.2*length(colnames(x = OVX_E2_20)))  ## Assuming 20% doublet formation rate - tailor for your dataset
nExp_poi.adj <- round(nExp_poi*(1-homotypic.prop))
#364
OVX_E2_20 <- doubletFinder_v3(OVX_E2_20, PCs = 1:14, pN = 0.25, pK = 0.19, nExp = nExp_poi.adj, reuse.pANN = FALSE, sct = FALSE)
p8 <-UMAPPlot(OVX_E2_20, group.by="DF.classifications_0.25_0.19_372")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  ggtitle("DoubletFinder")

stat <- as.data.frame(table(OVX_E2_20$seurat_clusters,OVX_E2_20@meta.data$DF.classifications_0.25_0.19_372))
p9 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Var1, fill = Var2), position = "fill", data = stat, stat="identity")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle("DoubletFinder")
SFig4D <- plot_grid(p8, p9, ncol=2)



########################################################################
###### Supplementary Fig. 4E ###########################################
########################################################################
p10 <- FeaturePlot(OVX_E2_20, "Krt14", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))
p11 <- FeaturePlot(OVX_E2_20, "Krt18", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))
p12 <- FeaturePlot(OVX_E2_20, "Ly6d", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))
p13 <- FeaturePlot(OVX_E2_20, "Csn3", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))
SFig4E <- plot_grid(p10, p11, p12, p13, ncol=4)



########################################################################
###### Supplementary Fig. 4F ###########################################
########################################################################
cluster.averages <- AverageExpression(OVX_E2_20)
Av <- cluster.averages[[1]]
Av.var <- Av[row.names(Av) %in% OVX_E2_20@assays$RNA@var.features, ]
colnames(Av.var) <- c("C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", "C8", "C9")
Hypo_C1_C5 <- (Av.var[,2]+Av.var[,6])/2
Av.var <- cbind(Av.var, Hypo_C1_C5)

corr <- round(cor(Av.var), 2)
p14 <- ggcorrplot(corr, type = "lower", lab = TRUE, lab_size = 2)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=12),
        legend.title = element_text(size=12))+
  ggtitle("Correlation")
SFig4F <- plot_grid(p18, ncol=1)



########################################################################
###### Supplementary Fig. 4G ###########################################
########################################################################
p15 <- FeaturePlot(OVX_E2_20, "Mki67", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))

p16 <- FeaturePlot(OVX_E2_20, "Col1a1", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))

p17 <- FeaturePlot(OVX_E2_20, "Vim", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))

p18 <- FeaturePlot(OVX_E2_20, "Ptprc", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))

p19 <- FeaturePlot(OVX_E2_20, "Cd52", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))

p20 <- FeaturePlot(OVX_E2_20, "Cdh5", cols = FP, 
                   pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10,face="bold"),
        axis.title=element_text(size=12,face="bold"))

SFig4G <- plot_grid(p15, p16, p17, p18, p19, p20, ncol=3)

