# Supplementary figure 5

########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  


## Data loading 
### See "...zenodo/Processing_Analysis/Mouse_integration.R" to prepare the data.
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
##
seu@active.assay <- "RNA"
seu <- NormalizeData(seu)
seu <- FindVariableFeatures(seu, selection.method = "vst", nfeatures = 2000)
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:5)
seu <- FindNeighbors(seu, dims = 1:5)
seu <- FindClusters(seu, resolution = 0.5)

########################################################################
###### Supplementary Fig. 5A ###########################################
########################################################################
p1 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Merged data")
p2 <- VlnPlot(seu, "nFeature_RNA", pt.size=0, group.by="Study", cols=col.std)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))
p3 <- VlnPlot(seu, "nCount_RNA", pt.size=0, group.by="Study", cols=col.std)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))
p4 <- VlnPlot(seu, "percent.mt", pt.size=0, group.by="Study", cols=col.std)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mitochondrial gene percentage")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))
SFig5A <- plot_grid(p1, p2, p3, p4, ncol.std=4)



########################################################################
###### Supplementary Fig. 5B ###########################################
########################################################################
Idents(seu) <- "orig.ident"
Bulk <- AverageExpression(seu, assays = "RNA")
Bulk <- Bulk[[1]]
Bulk <- t(Bulk)
Label <- c(rep("Bach", 8), rep("Giraddi", 6), rep("Pal", 5), rep("Saeki", 5), rep("TabulaMuris", 2))
Label <- factor(Label , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
res.pca <- PCA(Bulk, graph = FALSE)
p5 <- fviz_pca_ind(res.pca,
                   repel = TRUE,
                   col.std.ind = Label, 
                   palette = col.std,
                   addEllipses = F, 
                   legend.title = "Study",
                   alpha.ind=0.7,
                   invisible=c("ind.sup", "quali"),
                   pointsize = 3,
                   labelsize = 3)+
  labs(title ="Before integration", x = "PC1", y = "PC2")+
  theme(axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        plot.title = element_text(size=18, face="bold"))+
  NoLegend()

Bulk <- AverageExpression(seu, assays = "integrated")
Bulk <- Bulk[[1]]
Bulk <- t(Bulk)
res.pca <- PCA(Bulk, graph = FALSE)
p6 <- fviz_pca_ind(res.pca,
                   repel = TRUE,
                   col.std.ind = Label, 
                   palette = col.std,
                   addEllipses = F, 
                   legend.title = "Study",
                   alpha.ind=0.7,
                   invisible=c("ind.sup", "quali"),
                   pointsize = 3,
                   labelsize = 3)+
  labs(title ="After integration", x = "PC1", y = "PC2")+
  theme(axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        plot.title = element_text(size=18, face="bold"))+
  NoLegend()
SFig5B <- plot_grid(p5, p6, ncol.std=2)



########################################################################
###### Supplementary Fig. 5C ###########################################
########################################################################

# Integrated data with other reference datasets are not provided.
# Please See "...zenodo/Processing_Analysis/Mouse_integration.R" to prepare the data to prepare these data.

## ref none
seu <- readRDS("...your_folder/IntData_ref_none.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p7 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Ref none")

## ref Giraddi
seu <- readRDS("...your_folder/IntData_ref_G.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p8 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Ref Giraddi")

## ref Bach
seu <- readRDS("...your_folder/IntData_ref_B.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p9 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Ref Bach")

## ref TabulaMuris
seu <- readRDS("...your_folder/IntData_ref_T.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p10 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Ref TabulaMuris")

## ref Saeki
seu <- readRDS("...your_folder/IntData_ref_S.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p11 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Ref Saeki")

## ref Giraddi and Pal
seu <- readRDS("...your_folder/IntData_ref_GP.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p12 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Ref Giraddi and Pal")

## ref Pal and Bach
seu <- readRDS("...your_folder/IntData_ref_PB.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p13 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Ref Pal and Bach")

## ref Giraddi, Pal and Bach
seu <- readRDS("...your_folder/IntData_ref_GPB.rds")
Idents(seu) <- "Study"
new.cluster.ids <- c("Bach", "Giraddi", "Pal", "Saeki", "TabulaMuris")
names(new.cluster.ids) <- levels(seu)
seu <- RenameIdents(seu, new.cluster.ids)
seu@active.ident <- factor(seu@active.ident , levels = c("Giraddi", "Pal", "Bach", "TabulaMuris", "Saeki"))
seu$Study <- seu@active.ident
seu <- ScaleData(seu, features = rownames(seu))
seu <- RunPCA(seu, features = VariableFeatures(object = seu))
seu <- RunUMAP(seu, dims=1:10)
p14 <- UMAPPlot(seu, group.by="Study")+
  theme(plot.title = element_text(size=14, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=8,face="bold"))+
  ggtitle("Ref Giraddi, Pal and Bach")+
  scale_col.stdor_manual(values=col.std, labels=c("Giraddi", "Pal", "Bach", "TM", "Saeki"))

##
SFig5C <- plot_grid(p7, p8, p9, p10, p11, p12, p13, p14, ncol.std=4)


