# Supplementary figure 6



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
FP <- wes_palette("Zissou1", 5, type = "discrete")

## Data loading 
### See "...zenodo/Processing_Analysis/Mouse_integration.R" to prepare the data.
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")


########################################################################
###### Supplementary Fig. 6A ###########################################
########################################################################
p1 <- VlnPlot(seu, "nFeature_RNA", pt.size=0, cols=col.clst)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nFeature_RNA")+
  xlab("")+
  ylab("Gene count")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=8),
        axis.title=element_text(size=12,face="bold"))+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                            "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                            "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))
p2 <- VlnPlot(seu, "nCount_RNA", pt.size=0, cols = col.clst)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("nCount_RNA")+
  xlab("")+
  ylab("UMI count")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=8),
        axis.title=element_text(size=12,face="bold"))+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                            "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                            "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))
p3 <- VlnPlot(seu, "percent.mt", pt.size=0, cols = col.clst)+ 
  geom_boxplot(width=0.15, fill="white")+
  NoLegend()+
  ggtitle("percent.mt")+
  xlab("")+
  ylab("Mito gene %")+ 
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=8),
        axis.title=element_text(size=12,face="bold"))+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                            "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                            "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))
SFig6A <- plot_grid(p1, p2, p3, ncol=3)



########################################################################
###### Supplementary Fig. 6B ###########################################
########################################################################
stat <- as.data.frame(table(seu$Modified.ident, seu$Study, seu$Stage, seu$Strain))
colnames(stat) <- c("Cluster", "Study", "stage", "Strain", "Freq")
p4 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Cluster, fill = Study), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                            "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                            "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=8),
        axis.text.x =element_text(size=8, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=8))+
  scale_fill_manual(values = col.std)+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle("Study")
p5 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Cluster, fill = Strain), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                            "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                            "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=8),
        axis.text.x =element_text(size=8, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=8))+
  scale_fill_manual(values = col.str)+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle("Strain")
p6 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Cluster, fill = stage), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                            "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                            "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=8),
        axis.text.x =element_text(size=8, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"),
        legend.text = element_text(size=8))+
  scale_fill_manual(values = col.stg)+
  xlab("Cluster")+
  ylab("Frequency")+ 
  labs(fill = "")+
  ggtitle("Stage")
SFig6B <- plot_grid(p4, p5, p6, ncol=3)



########################################################################
###### Supplementary Fig. 6C ###########################################
########################################################################
markers <- FindAllMarkers(seu, only.pos = TRUE, min.pct = 0.25, logfc.threshold = 0.25)
top10 <- markers %>% group_by(cluster) %>% top_n(n = 10, wt = avg_logFC)
col <- wes_palette("Zissou1", 5)
SFig6C <- DoHeatmap(seu, features = as.character(top10$gene), label = T) +
  scale_fill_gradientn(colors = c(col[1], col[3], col[5]))+
  scale_x_discrete(labels=c("1" = "Cluster 1 \n (Krt14+)", "2" = "Cluster 2 \n (Krt14+)",
                            "3" = "Cluster 3 \n (Krt18+Csn3+)", "4" = "Cluster 4 \n (Krt18+Csn3+)",
                            "5" = "Cluster 5 \n (Krt18+Areg+)", "6" = "Cluster 6 \n (Krt18+Areg+)"))



########################################################################
###### Supplementary Fig. 6D ###########################################
########################################################################
p7 <- FeaturePlot(seu, "Birc5", cols = FP, 
            pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p8 <- FeaturePlot(seu, "Hmgb2", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p9 <- FeaturePlot(seu, "Stmn1", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p10 <- FeaturePlot(seu, "Acta2", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p11 <- FeaturePlot(seu, "Krt17", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p12 <- FeaturePlot(seu, "Myl9", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p13 <- FeaturePlot(seu, "Lalba", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p14 <- FeaturePlot(seu, "Csn2", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p15 <- FeaturePlot(seu, "Spp1", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p16 <- FeaturePlot(seu, "Cited1", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p17 <- FeaturePlot(seu, "Ly6d", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

p18 <- FeaturePlot(seu, "Prlr", cols = FP, 
                  pt.size = 1, min.cutoff = "q10", max.cutoff = "q90")+
  NoAxes()+
  theme(plot.title = element_text(size=18, face="bold"),
        legend.text=element_text(size=8))

SFig6D <- plot_grid(p7, p8, p9, p10, p11, p12, p13, p14, p15, p16, p17, p18, ncol=3, align = 'hv')






