# Supplementary figure 7


########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  
FP <- wes_palette("Zissou1", 5, type = "discrete")

## Data loading 
### See "...zenodo/Processing_Analysis/Mouse_integration.R" to prepare the data.
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")

### See "...zenodo/Processing_Analysis/CytoTRACE.R" to prepare the data.
CytoTRACE <- read.csv("...zenodo/CytoTRACE/Mouse_CytoTRACE_score.csv",
                      row.names = 1)

########################################################################
###### Supplementary Fig. 7A ###########################################
########################################################################
label <- row.names(CytoTRACE)
sub <- subset(seu, cells = label)
sub <- AddMetaData(sub, metadata = CytoTRACE)

Idents(sub) <- "orig.ident"
sub <- subset(sub, idents = c("Embryonic_d16(G)", "Embryonic_d18(G)", "Postnatal_d4(G)", "Adult_1(G)", "Adult_2(G)",
                              "Puberty_1(P)", "Puberty_2(P)", "Adult(P)", "Nulliparous_1(B)", "Nulliparous_2(B)",
                              "Gestation_1(B)", "Gestation_2(B)", "Lactation_1(B)", "Lactation_2(B)", 
                              "PostInvolution_1(B)", "PostInvolution_2(B)", "OVX(S)"))

df<- sub@meta.data
SFig7A <- FeaturePlot(sub, "CytoTRACE", cols=viridis_pal()(100))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  ggtitle("CytoTRACE")



########################################################################
###### Supplementary Fig. 7B ###########################################
########################################################################
SFig7B <- ggboxplot(df, x = "Stage", y = "CytoTRACE",
          col = "Stage", palette =col.stg, 
          add = "jitter",                         
          add.params = list(size = 0.05, jitter = 0.2))+
  NoLegend()+
  xlab("Stages")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=12),
        axis.text.x =element_text(size=12, angle = 45, hjust = 1),
        axis.title=element_text(size=14,face="bold"))



########################################################################
###### Supplementary Fig. 7C ###########################################
########################################################################
# See "...zenodo/Processing_Analysis/Mouse_sample_preprocessing.R" to prepare the data.

Giraddi <- readRDS("...your_folder/Giraddi/Giraddi_cleaned.rds")
G.expr <- as.data.frame(Giraddi@assays$RNA@counts)
G.pheno <- Giraddi$orig.ident

g.results <- CytoTRACE(G.expr)
plotCytoTRACE(g.results, phenotype = G.pheno)



########################################################################
###### Supplementary Fig. 7D ###########################################
########################################################################
# See "...zenodo/Processing_Analysis/Mouse_sample_preprocessing.R" to prepare the data.
Bach <- readRDS("...your_folder/Bach/Bach_cleaned.rds")
B.expr <- as.data.frame(Bach@assays$RNA@counts)
B.pheno <- Bach$orig.ident

b.results <- CytoTRACE(B.expr)
plotCytoTRACE(b.results, phenotype = B.pheno)



########################################################################
###### Supplementary Fig. 7E ###########################################
########################################################################
# install_github("immunogenomics/harmony")
library(harmony)
library(Seurat)

## Data 
# See "...zenodo/Processing_Analysis/Mouse_sample_preprocessing.R" to prepare the data.
Bach <- readRDS("...your_folder/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...your_folder/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...your_folder/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...your_folder/Pal/Pal_cleaned.rds")
TM <- readRDS("...your_folder//TabulaMuris/TabulaMuris_cleaned.rds")

library(stringr)
TM_col <- str_hData(colnames(TM), start = 9, end = -1)
TM <- RenameCells(TM, new.names = TM_col) 

IntData <- merge(Bach, c(Giraddi, Pal, Saeki, TM), add.cell.ids = NULL, project = "IntData")
remove(Bach, Giraddi, Pal, Saeki, TM)
gc()
gc()

###
IntData <- NormalizeData(IntData, verbose = T)
IntData <- FindVariableFeatures(IntData, selection.method = "vst", nfeatures = 2000)
all.genes <- rownames(IntData)
IntData <- ScaleData(IntData, features = all.genes)
IntData <- RunPCA(IntData, features = VariableFeatures(object = IntData))

### Default, all pca = 50
hData <- RunHarmony(IntData, "Dataset", plot_convergence = TRUE)
hData <- RunUMAP(hData, reduction = "harmony", dims = 1:6)

# Metadata
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
meta <- seu@meta.data
hData <- AddMetaData(hData, metadata = meta)
UMAPPlot(hData, group.by="Annotation")

p1 <- UMAPPlot(hData, group.by="Annotation", cols=col.clst)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Harmony_Annotated cluster")
p2 <- UMAPPlot(hData, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Harmony_Study")
p3 <- UMAPPlot(hData, group.by="Strain", cols=col.str)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Harmony_Strain")
p4 <- UMAPPlot(hData, group.by="Stage", cols=col.stg)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("Harmony_Stage")
SFig7E <- plot_grid(p1, p2, p3, p4, ncol = 4, align='hv')



########################################################################
###### Supplementary Fig. 7F ###########################################
########################################################################
# install_github('MacoskoLab/liger')
library(liger)

# See "...zenodo/Processing_Analysis/Mouse_sample_preprocessing.R" to prepare the data.
Bach <- readRDS("...your_folder/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...your_folder/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...your_folder/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...your_folder/Pal/Pal_cleaned.rds")
TM <- readRDS("...your_folder//TabulaMuris/TabulaMuris_cleaned.rds")

seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
meta <- seu@meta.data


library(stringr)
TM_col <- str_sub(colnames(TM), start = 9, end = -1)
TM <- RenameCells(TM, new.names = TM_col) 

IntData <- merge(Bach, c(Giraddi, Pal, Saeki, TM), add.cell.ids = NULL, project = "IntData")
IntData <- AddMetaData(IntData, meta)
IntData <- subset(IntData, cells = c(colnames(IntData)[!is.na(IntData$Annotation)]))
remove(Bach, Giraddi, Pal, Saeki, TM, seu)
gc()
gc()

###
IntData <- NormalizeData(IntData)
IntData <- FindVariableFeatures(IntData)
IntData <- ScaleData(IntData, split.by = "Dataset", do.center = FALSE)

IntData_L5 <- RunOptimizeALS(IntData, k = 20, lambda = 5, split.by = "Dataset")
IntData_L5 <- RunQuantileNorm(IntData_L5, split.by = "Dataset")
IntData_L5 <- RunUMAP(IntData_L5, reduction = "iNMF", dims = 1:20)
IntData_L5 <- AddMetaData(IntData_L5, meta)

p1 <- UMAPPlot(IntData_L5, group.by="Annotation", cols=col.clst)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("LIGER_Annotated cluster")
p2 <- UMAPPlot(IntData_L5, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("LIGER_Study")
p3 <- UMAPPlot(IntData_L5, group.by="Strain", cols=col.str)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("LIGER_Strain")
p4 <- UMAPPlot(IntData_L5, group.by="Stage", cols=col.stg)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("LIGER_Stage")
SFig7F <- plot_grid(p1, p2, p3, p4, ncol = 4, align='hv')



########################################################################
###### Supplementary Fig. 7G ###########################################
########################################################################
# BiocManager::install("scAlign")
library(scAlign)

# See "...zenodo/Processing_Analysis/Mouse_sample_preprocessing.R" to prepare the data.
Bach <- readRDS("...your_folder/Bach/Bach_cleaned.rds")
Saeki <- readRDS("...your_folder/Saeki/Saeki_cleaned.rds")
Giraddi <- readRDS("...your_folder/Giraddi/Giraddi_cleaned.rds")
Pal <- readRDS("...your_folder/Pal/Pal_cleaned.rds")
TM <- readRDS("...your_folder//TabulaMuris/TabulaMuris_cleaned.rds")

library(stringr)
TM_col <- str_sub(colnames(TM), start = 9, end = -1)
TM <- RenameCells(TM, new.names = TM_col) 

IntData <- merge(Bach, c(Giraddi, Pal, Saeki, TM), add.cell.ids = NULL, project = "IntData")
remove(Bach, Giraddi, Pal, Saeki, TM)
gc()
gc()

seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
meta <- seu@meta.data
IntData <- AddMetaData(IntData, meta)

remove(seu, meta)
gc()
gc()

###
IntData.list = SplitObject(IntData, split.by = "Study")

for (i in 1:length(IntData.list)) {
  IntData.list[[i]] <- NormalizeData(IntData.list[[i]])
  IntData.list[[i]] <- ScaleData(IntData.list[[i]], do.scale=T, do.center=T, display.progress=T)
  IntData.list[[i]] <- FindVariableFeatures(IntData.list[[i]], nFeatures = 3000)
}

genes.use = Reduce(intersect, lapply(IntData.list, function(seurat.obj) VariableFeatures(seurat.obj)))
IntData.sce.list = lapply(IntData.list,
                          function(seurat.obj){
                            SingleCellExperiment(assays = list(counts = seurat.obj@assays$RNA@counts[genes.use,],
                                                               logcounts = seurat.obj@assays$RNA@data[genes.use,],
                                                               scale.data = seurat.obj@assays$RNA@scale.data[genes.use,]),
                                                 colData = seurat.obj@meta.data)
                          })
scAlignIntData = scAlignCreateObject(sce.objects = IntData.sce.list,
                                     genes.use = genes.use,
                                     cca.reduce=T,
                                     ccs.compute=10,
                                     project.name = "scAlign_IntData")
scAlignIntData_multi = scAlignMulti(scAlignIntData,
                                    options=scAlignOptions(steps=15000,
                                                           log.every=5000,
                                                           batch.size=300,
                                                           perplexity=30,
                                                           norm=TRUE,
                                                           batch.norm.layer=FALSE,
                                                           architecture="large",  ## 3 layer neural network
                                                           num.dim=64),            ## Number of latent dimensions
                                    encoder.data="MultiCCA",
                                    decoder.data="scale.data", 
                                    reference.data = "Giraddi",
                                    supervised='none',
                                    run.encoder=TRUE,
                                    run.decoder=TRUE,
                                    log.results=TRUE,
                                    log.dir=file.path('./tmp'),
                                    device="CPU")

scAlignSeuratObj = as.Seurat(scAlignIntData_multi, counts="counts", data="logcounts", assay="RNA")
seu <- RunUMAP(scAlignSeuratObj, reduction = "ALIGNED.MultiCCA", dims = 1:64)

p1 <- UMAPPlot(seu, group.by="Annotation", cols=col.clst)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("scAlign_Annotated cluster")
p2 <- UMAPPlot(seu, group.by="Study", cols=col.std)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("scAlign_Study")
p3 <- UMAPPlot(seu, group.by="Strain", cols=col.str)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("scAlign_Strain")
p4 <- UMAPPlot(seu, group.by="Stage", cols=col.stg)+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text=element_text(size=10),
        axis.title=element_text(size=12,face="bold"))+
  ggtitle("scAlign_Stage")

SFig7G <- plot_grid(p1, p2, p3, p4, ncol = 4, align='hv')