# Supplementary figure 8


########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}


#################################################################
############### Supplementary fig 8A ############################
#################################################################
## Refer to "...zenodo/STREAM/Giraddi_output"



#################################################################
############### Supplementary fig 8B ############################
#################################################################
## Refer to "...zenodo/STREAM/All_output"



#################################################################
############### Supplementary fig 8C ############################
#################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
seu_meta <- seu@meta.data
stream_meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)
stream_meta <- stream_meta[row.names(seu_meta),]
stat <- as.data.frame(table(seu_meta$Annotation, seu_meta$Study, seu_meta$Stage, seu_meta$Strain, stream_meta$branch_id_alias))
colnames(stat) <- c("Cluster", "Study", "Stage", "Strain", "Branch", "Freq")
stat$Branch <- factor(stat$Branch, levels = c("S5_S3", "S3_S0", "S0_S1", "S0_S2", "S3_S4"))

p1 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Study), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  scale_fill_manual(values = col.std)+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Study")+
  ggtitle("Study")

p2 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Stage), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  scale_fill_manual(values = col.stg)+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Stage")+
  ggtitle("Stage")

p3 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Strain), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  scale_fill_manual(values = col.str)+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Strain")+
  ggtitle("Strain")

SFig18C <- plot_grid(p1, p2, p3, ncol=3)



#################################################################
############### Supplementary fig 8D ############################
#################################################################
#
seu_meta_Bach <- seu_meta[seu_meta$Study == "Bach", ]
stream_meta_Bach <- stream_meta[row.names(seu_meta_Bach),]

stat <- as.data.frame(table(seu_meta_Bach$Annotation, seu_meta_Bach$Study, 
                            seu_meta_Bach$Stage, seu_meta_Bach$Strain, seu_meta_Bach$orig.ident, 
                            stream_meta_Bach$branch_id_alias))
colnames(stat) <- c("Cluster", "Study", "Stage", "Strain", "Sample" , "Branch", "Freq")
stat$Branch <- factor(stat$Branch, levels = c("S5_S3", "S3_S0", "S0_S1", "S0_S2", "S3_S4"))

stat <- stat[stat$Freq != 0, ]

p1 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Sample), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Study")+
  ggtitle("Bach data")

p2 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Sample), data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Study")+
  ggtitle("Bach data")

p3 <- plot_grid(p6, p5, ncol=2)

#
seu_meta_Pal <- seu_meta[seu_meta$Study == "Pal", ]
stream_meta_Pal <- stream_meta[row.names(seu_meta_Pal),]

stat <- as.data.frame(table(seu_meta_Pal$Annotation, seu_meta_Pal$Study, 
                            seu_meta_Pal$Stage, seu_meta_Pal$Strain, seu_meta_Pal$orig.ident, 
                            stream_meta_Pal$branch_id_alias))
colnames(stat) <- c("Cluster", "Study", "Stage", "Strain", "Sample" , "Branch", "Freq")
stat$Branch <- factor(stat$Branch, levels = c("S5_S3", "S3_S0", "S0_S1", "S0_S2", "S3_S4"))

stat <- stat[stat$Freq != 0, ]

p4 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Sample), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Study")+
  ggtitle("Pal data")

p5 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Sample), data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Study")+
  ggtitle("Pal data")

p6 <- plot_grid(p9, p8, ncol=2)

#
seu_meta_Giraddi <- seu_meta[seu_meta$Study == "Giraddi", ]
stream_meta_Giraddi <- stream_meta[row.names(seu_meta_Giraddi),]

stat <- as.data.frame(table(seu_meta_Giraddi$Annotation, seu_meta_Giraddi$Study, 
                            seu_meta_Giraddi$Stage, seu_meta_Giraddi$Strain, seu_meta_Giraddi$orig.ident, 
                            stream_meta_Giraddi$branch_id_alias))
colnames(stat) <- c("Cluster", "Study", "Stage", "Strain", "Sample" , "Branch", "Freq")
stat$Branch <- factor(stat$Branch, levels = c("S5_S3", "S3_S0", "S0_S1", "S0_S2", "S3_S4"))

stat <- stat[stat$Freq != 0, ]

p7 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Sample), position = "fill", data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Study")+
  ggtitle("Giraddi data")

p8 <- ggplot() + 
  geom_bar(aes(y = Freq, x = Branch, fill = Sample), data = stat, stat="identity")+
  scale_x_discrete(labels=c("S5_S3" = "S5_S3 \n MaSC", "S3_S0" = "S3_S0 \n Bi-Luminal",
                            "S0_S1" = "S0_S1 \n L-Hor", "S0_S2" = "S0_S2 \n L-Alv",
                            "S3_S4" = "S3_S4 \n Basal"))+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text.y =element_text(size=10),
        axis.text.x =element_text(size=10, angle = 45, hjust = 1),
        axis.title=element_text(size=12,face="bold"),
        legend.text = element_text(size=10))+
  xlab("Branch")+
  ylab("Frequency")+ 
  labs(fill = "Study")+
  ggtitle("Giraddi data")

p9 <- plot_grid(p12, p11, ncol=2)
SFig8D <- plot_grid(p3, p6, p9, ncol=1)



#################################################################
############### Supplementary fig 8E ############################
#################################################################
seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
metadata <- read.csv("...zenodo/STREAM/500_each_output/metadata_modified.csv",
                     row.names = 1)
metadata <- cbind(row.names(metadata),metadata)
colnames(metadata)[1] <- "Cell_id"

### S3_S4 transition
S3S4 <- metadata[metadata$branch_id_alias=="S3_S4",]
S3S4 <- S3S4 %>% arrange(S5_pseudotime)

S3S4_gene <- read.table("...zenodo/STREAM/500_each_output/transition_genes/transition_genes_S3_S4.tsv", 
                        header=T, sep='\t', row.names = 1)
S3S4_gene <- cbind(row.names(S3S4_gene), S3S4_gene)
colnames(S3S4_gene)[1] <- "Symbol"

## q value
S3_gene <- S3S4_gene[S3S4_gene$stat<0,]
S4_gene <- S3S4_gene[S3S4_gene$stat>0,]

top_S3 <- S3_gene %>% top_n(n = -20, wt = qval)
top_S4 <- S4_gene %>% top_n(n = -20, wt = qval)

top <- rbind(top_S3, top_S4)
top <- top %>% arrange(stat)

#
hdata <- seu@assays$integrated@scale.data
hdata <- hdata[row.names(top), S3S4$Cell_id]
hdata[hdata < -2.5] <- -2.5
hdata[hdata > 2.5] <- 2.5

#
meta <- seu@meta.data
meta <- meta[S3S4$Cell_id,]

my_sample_col <- data.frame(meta$Annotation)
row.names(my_sample_col) <- S3S4$Cell_id
colnames(my_sample_col) <- "Cluster"
my_sample_col$Cluster <- as.character(my_sample_col$Cluster)

my_sample_col$Cluster[my_sample_col$Cluster == "MaSC/B-pro"] <- "MaSC_B_pro"
my_sample_col$Cluster[my_sample_col$Cluster == "L-Alv"] <- "L_Alv"
my_sample_col$Cluster[my_sample_col$Cluster == "L-Hor"] <- "L_Hor"
my_sample_col$Cluster[my_sample_col$Cluster == "LA-pro"] <- "LA_pro"
my_sample_col$Cluster[my_sample_col$Cluster == "LH-pro"] <- "LH_pro"

my_colour = list(Cluster = c(MaSC_B_pro="#FDBF6F", Basal="#FF7F00", 
                             LA_pro="#B2DF8A", L_Alv="#33A02C",
                             LH_pro="#FB9A99", L_Hor="#E31A1C"))


pheatmap(hdata, cluster_rows = T,color= viridis(100), cutree_rows=2, fontsize = 8,
         cluster_cols = F, show_rownames = T, show_colnames = F, height = 4,
         annotation_col = my_sample_col, 
         annotation_colors = my_colour, 
         filename = "SFig8E-1.pdf")

### S0_S1 transition
S0S1 <- metadata[metadata$branch_id_alias=="S0_S1",]
S0S1 <- S0S1 %>% arrange(S5_pseudotime)

S0S1_gene <- read.table("...zenodo/STREAM/500_each_output/transition_genes/transition_genes_S0_S1.tsv", 
                        header=T, sep='\t', row.names = 1)
S0S1_gene <- cbind(row.names(S0S1_gene), S0S1_gene)
colnames(S0S1_gene)[1] <- "Symbol"

## q value
S0_gene <- S0S1_gene[S0S1_gene$stat<0,]
S1_gene <- S0S1_gene[S0S1_gene$stat>0,]

top_S0 <- S0_gene %>% top_n(n = -20, wt = qval)
top_S1 <- S1_gene %>% top_n(n = -20, wt = qval)

top <- rbind(top_S0, top_S1)
top <- top %>% arrange(stat)

#
hdata <- seu@assays$integrated@scale.data
hdata <- hdata[row.names(top), S0S1$Cell_id]
hdata[hdata < -2.5] <- -2.5
hdata[hdata > 2.5] <- 2.5

#
meta <- seu@meta.data
meta <- meta[S0S1$Cell_id,]

my_sample_col <- data.frame(meta$Annotation)
row.names(my_sample_col) <- S0S1$Cell_id
colnames(my_sample_col) <- "Cluster"
my_sample_col$Cluster <- as.character(my_sample_col$Cluster)

my_sample_col$Cluster[my_sample_col$Cluster == "MaSC/B-pro"] <- "MaSC_B_pro"
my_sample_col$Cluster[my_sample_col$Cluster == "L-Alv"] <- "L_Alv"
my_sample_col$Cluster[my_sample_col$Cluster == "L-Hor"] <- "L_Hor"
my_sample_col$Cluster[my_sample_col$Cluster == "LA-pro"] <- "LA_pro"
my_sample_col$Cluster[my_sample_col$Cluster == "LH-pro"] <- "LH_pro"

my_colour = list(Cluster = c(MaSC_B_pro="#FDBF6F", Basal="#FF7F00", 
                             LA_pro="#B2DF8A", L_Alv="#33A02C",
                             LH_pro="#FB9A99", L_Hor="#E31A1C"))


pheatmap(hdata, cluster_rows = T,color= viridis(100), cutree_rows=2, fontsize = 8,
         cluster_cols = F, show_rownames = T, show_colnames = F, height = 4,
         annotation_col = my_sample_col, 
         annotation_colors = my_colour, 
         filename = "SFig8E-2.pdf")


### S0_S2 transition
S0S2 <- metadata[metadata$branch_id_alias=="S0_S2",]
S0S2 <- S0S2 %>% arrange(S5_pseudotime)

S0S2_gene <- read.table("...zenodo/STREAM/500_each_output/transition_genes/transition_genes_S0_S2.tsv", 
                        header=T, sep='\t', row.names = 1)
S0S2_gene <- cbind(row.names(S0S2_gene), S0S2_gene)
colnames(S0S2_gene)[1] <- "Symbol"

## q value
S0_gene <- S0S2_gene[S0S2_gene$stat<0,]
S2_gene <- S0S2_gene[S0S2_gene$stat>0,]

top_S0 <- S0_gene %>% top_n(n = -20, wt = qval)
top_S2 <- S2_gene %>% top_n(n = -20, wt = qval)

top <- rbind(top_S0, top_S2)
top <- top %>% arrange(stat)

#
hdata <- seu@assays$integrated@scale.data
hdata <- hdata[row.names(top), S0S2$Cell_id]
hdata[hdata < -2.5] <- -2.5
hdata[hdata > 2.5] <- 2.5

#
meta <- seu@meta.data
meta <- meta[S0S2$Cell_id,]

my_sample_col <- data.frame(meta$Annotation)
row.names(my_sample_col) <- S0S2$Cell_id
colnames(my_sample_col) <- "Cluster"
my_sample_col$Cluster <- as.character(my_sample_col$Cluster)

my_sample_col$Cluster[my_sample_col$Cluster == "MaSC/B-pro"] <- "MaSC_B_pro"
my_sample_col$Cluster[my_sample_col$Cluster == "L-Alv"] <- "L_Alv"
my_sample_col$Cluster[my_sample_col$Cluster == "L-Hor"] <- "L_Hor"
my_sample_col$Cluster[my_sample_col$Cluster == "LA-pro"] <- "LA_pro"
my_sample_col$Cluster[my_sample_col$Cluster == "LH-pro"] <- "LH_pro"

my_colour = list(Cluster = c(MaSC_B_pro="#FDBF6F", Basal="#FF7F00", 
                             LA_pro="#B2DF8A", L_Alv="#33A02C",
                             LH_pro="#FB9A99", L_Hor="#E31A1C"))


pheatmap(hdata, cluster_rows = T,color= viridis(100), cutree_rows=2, fontsize = 8,
         cluster_cols = F, show_rownames = T, show_colnames = F, height = 4,
         annotation_col = my_sample_col, 
         annotation_colors = my_colour, 
         filename = "SFig8E-3.pdf")



#######################################################################
###### Supplementary Data 5 ###########################################
#######################################################################
#Pathway
library("org.Mm.eg.db")
m_df <- msigdbr(species = "Mus musculus")
m_df_H <- m_df[m_df$gs_cat == "H", ]
m_df_C2 <- m_df[m_df$gs_cat == "C2", ]
m_df_C5 <- m_df[m_df$gs_cat == "C5", ]

m_df_H <- m_df_H %>% dplyr::select(gs_name, entrez_gene)
m_df_C2 <- m_df_C2 %>% dplyr::select(gs_name, entrez_gene)
m_df_C5 <- m_df_C5 %>% dplyr::select(gs_name, entrez_gene)

#S3_S4

S3S4_gene <- read.table("...zenodo/STREAM/500_each_output/transition_genes/transition_genes_S3_S4.tsv", 
                        header=T, sep='\t', row.names = 1)
S3S4_gene <- cbind(row.names(S3S4_gene), S3S4_gene)
colnames(S3S4_gene)[1] <- "Symbol"

## 
S3_gene <- S3S4_gene[S3S4_gene$stat<0,]
S4_gene <- S3S4_gene[S3S4_gene$stat>0,]

##
S3_gene_ID = bitr(S3_gene$Symbol, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Mm.eg.db")
S3_H <- enricher(S3_gene_ID$ENTREZID, TERM2GENE=m_df_H)
S3_C2 <- enricher(S3_gene_ID$ENTREZID, TERM2GENE=m_df_C2)
S3_C5 <- enricher(S3_gene_ID$ENTREZID, TERM2GENE=m_df_C5)
S3_H_res <- S3_H@result
S3_C2_res <- S3_C2@result
S3_C5_res <- S3_C5@result


##
S4_gene_ID = bitr(S4_gene$Symbol, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Mm.eg.db")
S4_H <- enricher(S4_gene_ID$ENTREZID, TERM2GENE=m_df_H)
S4_C2 <- enricher(S4_gene_ID$ENTREZID, TERM2GENE=m_df_C2)
S4_C5 <- enricher(S4_gene_ID$ENTREZID, TERM2GENE=m_df_C5)
S4_H_res <- S4_H@result
S4_C2_res <- S4_C2@result
S4_C5_res <- S4_C5@result


#S0_S1
S0S1 <- metadata[metadata$branch_id_alias=="S0_S1",]
S0S1 <- S0S1 %>% arrange(S5_pseudotime)

S0S1_gene <- read.table("...zenodo/STREAM/500_each_output/transition_genes/transition_genes_S0_S1.tsv", 
                        header=T, sep='\t', row.names = 1)
S0S1_gene <- cbind(row.names(S0S1_gene), S0S1_gene)
colnames(S0S1_gene)[1] <- "Symbol"

## 
S0_gene <- S0S1_gene[S0S1_gene$stat<0,]
S1_gene <- S0S1_gene[S0S1_gene$stat>0,]

##
S0_gene_ID = bitr(S0_gene$Symbol, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Mm.eg.db")
S0_H <- enricher(S0_gene_ID$ENTREZID, TERM2GENE=m_df_H)
S0_C2 <- enricher(S0_gene_ID$ENTREZID, TERM2GENE=m_df_C2)
S0_C5 <- enricher(S0_gene_ID$ENTREZID, TERM2GENE=m_df_C5)
S0_H_res <- S0_H@result
S0_C2_res <- S0_C2@result
S0_C5_res <- S0_C5@result


##
S1_gene_ID = bitr(S1_gene$Symbol, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Mm.eg.db")
S1_H <- enricher(S1_gene_ID$ENTREZID, TERM2GENE=m_df_H)
S1_C2 <- enricher(S1_gene_ID$ENTREZID, TERM2GENE=m_df_C2)
S1_C5 <- enricher(S1_gene_ID$ENTREZID, TERM2GENE=m_df_C5)
S1_H_res <- S1_H@result
S1_C2_res <- S1_C2@result
S1_C5_res <- S1_C5@result


### S0_S2 transition
S0S2 <- metadata[metadata$branch_id_alias=="S0_S2",]
S0S2 <- S0S2 %>% arrange(S5_pseudotime)

S0S2_gene <- read.table("...zenodo/STREAM/500_each_output/transition_genes/transition_genes_S0_S2.tsv", 
                        header=T, sep='\t', row.names = 1)
S0S2_gene <- cbind(row.names(S0S2_gene), S0S2_gene)
colnames(S0S2_gene)[1] <- "Symbol"

## 
S0_gene <- S0S2_gene[S0S2_gene$stat<0,]
S2_gene <- S0S2_gene[S0S2_gene$stat>0,]

##
S0_gene_ID = bitr(S0_gene$Symbol, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Mm.eg.db")
S0_H <- enricher(S0_gene_ID$ENTREZID, TERM2GENE=m_df_H)
S0_C2 <- enricher(S0_gene_ID$ENTREZID, TERM2GENE=m_df_C2)
S0_C5 <- enricher(S0_gene_ID$ENTREZID, TERM2GENE=m_df_C5)
S0_H_res <- S0_H@result
S0_C2_res <- S0_C2@result
S0_C5_res <- S0_C5@result


##
S2_gene_ID = bitr(S2_gene$Symbol, fromType="SYMBOL", toType="ENTREZID", OrgDb="org.Mm.eg.db")
S2_H <- enricher(S2_gene_ID$ENTREZID, TERM2GENE=m_df_H)
S2_C2 <- enricher(S2_gene_ID$ENTREZID, TERM2GENE=m_df_C2)
S2_C5 <- enricher(S2_gene_ID$ENTREZID, TERM2GENE=m_df_C5)
S2_H_res <- S2_H@result
S2_C2_res <- S2_C2@result
S2_C5_res <- S2_C5@result
