# Supplementary fig 9



########################################################################
###### Environment #####################################################
########################################################################
## Package
lib <- readRDS("...zenodo/Others/library.rds")
for(i in 1: length(lib)){
  library(lib[i], character.only = T)
}

## Palette
col.std <- wes_palette("IsleofDogs1", 5)
col.str <- wes_palette("Darjeeling2", 3)
col.stg <- c(wes_palette("GrandBudapest1", 4),wes_palette("GrandBudapest2", 4))
col.clst <- c("#FDBF6F","#FF7F00", "#B2DF8A", "#33A02C",  "#FB9A99", "#E31A1C")  



###########################################################################
######### S Fig9A #########################################################
###########################################################################
### See "...zenodo/Processing_Analysis/Mouse_integration.R" to prepare the data.
### See "...zenodo/Processing_Analysis/STREAM_mouse.ipynb" to prepare the data.

seu <- readRDS("...zenodo/Mouse_integrated_data/IntData.rds")
meta <- read.csv("...zenodo/STREAM/All_output/metadata_all_modified.csv",
                 row.names = 1)

Label <- seu@meta.data[,c("Annotation", "Study")]
meta <- meta[row.names(Label),]

###
Exp_Mif <- seu@assays$integrated@scale.data[row.names(seu@assays$integrated@scale.data) == "Mif",]
data_Mif <- data.frame(Exp_Mif, Label, meta$S5_pseudotime)
colnames(data_Mif) <- c("value","Cluster", "Study", "S5_Pseudotime")

p1 <- ggplot(data_Mif, aes(x=S5_Pseudotime, y=value))+
  geom_point(aes(col=Cluster))+
  scale_color_manual(values = col.clst)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("Expression")+
  ggtitle("Mif")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p2 <- ggplot(data_Mif, aes(x=S5_Pseudotime, y=value))+
  geom_point(aes(col=Study))+
  scale_color_manual(values = col.std)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("Expression")+
  ggtitle("Mif")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

###
Exp_Krt18 <- seu@assays$integrated@scale.data[row.names(seu@assays$integrated@scale.data) == "Krt18",]
data_Krt18 <- data.frame(Exp_Krt18, Label, meta$S5_pseudotime)
colnames(data_Krt18) <- c("value","Cluster", "Study", "S5_Pseudotime")

p3 <- ggplot(data_Krt18, aes(x=S5_Pseudotime, y=value))+
  geom_point(aes(col=Cluster))+
  scale_color_manual(values = col.clst)+
  geom_smooth(method=lm,linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("Expression")+
  ggtitle("Krt18")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))

p4 <- ggplot(data_Krt18, aes(x=S5_Pseudotime, y=value))+
  geom_point(aes(col=Study))+
  scale_color_manual(values = col.std)+
  geom_smooth(method=lm, linetype="dashed",
              color="darkred", fill="blue", size=2)+
  ylab("Expression")+
  ggtitle("Krt18")+
  theme(plot.title = element_text(size=18, face="bold"),
        axis.text =element_text(size=10),
        axis.title=element_text(size=12,face="bold"),
        legend.text=element_text(size=10),
        legend.title = element_text(size=12,face="bold"))
Sfig9A <- plot_grid(p1,p2,p3,p4,align="hv")



###########################################################################
######### S Fig9B #########################################################
###########################################################################
cor_Stem <- read.csv("...zenodo/GSVA/Mouse/cor_Stem.csv", row.names = 1)
cor_Alv <- read.csv("...zenodo/GSVA/Mouse/cor_Alv.csv", row.names = 1)
cor_Basal <- read.csv("...zenodo/GSVA/Mouse/cor_Basal.csv", row.names = 1)
cor_Hor <-  read.csv("...zenodo/GSVA/Mouse/cor_Hor.csv", row.names = 1)

tick_x <- 2/128
xtick <- data.frame(ticks=seq(2000, 12000, 2000), zero = 0)
tick_y <- length(rownames(cor_Stem))/128
ytick <- data.frame(ticks=seq(-1.0, 1.0, 0.2), zero = 0)
ytick_lab <- c("-1.0","-0.8","-0.6","-0.4","-0.2","0.0","0.2","0.4","0.6","0.8","1.0") 

##
label_data_Stem <- cor_Stem[cor_Stem$rank %in% c(1:10)|
                         cor_Stem$rank.inv %in% c(1:10),] 

p1 <- ggplot(cor_Stem, aes(x=rank, y=mean.inv))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_Stem, aes(x=rank, y=mean.inv, color=row.names(label_data_Stem)), size=2)+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = 12319, 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  geom_label_repel(
    data          = subset(label_data_Stem, mean.inv > 0),
    aes(label=row.names(subset(label_data_Stem, mean.inv > 0))),
    nudge_x       = 2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0
  ) +
  geom_label_repel(
    data          = subset(label_data_Stem, mean.inv < 0),
    aes(label=row.names(subset(label_data_Stem, mean.inv < 0))),
    nudge_x       = -2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1
  )+
  xlab("Genes")+
  ylab("Correlation with S5_pseudotime \n (Averaged;n=5)")+
  ggtitle("Gene expression correlated to S5 (MaSC)")+
  NoLegend()

##
label_data_Basal <- cor_Basal[cor_Basal$rank %in% c(1:10)|
                         cor_Basal$rank.inv %in% c(1:10),] 

p2 <- ggplot(cor_Basal, aes(x=rank, y=mean.inv))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_Basal, aes(x=rank, y=mean.inv, color=row.names(label_data_Basal)), size=2)+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = 12319, 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  geom_label_repel(
    data          = subset(label_data_Basal, mean.inv > 0),
    aes(label=row.names(subset(label_data_Basal, mean.inv > 0))),
    nudge_x       = 2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0
  ) +
  geom_label_repel(
    data          = subset(label_data_Basal, mean.inv < 0),
    aes(label=row.names(subset(label_data_Basal, mean.inv < 0))),
    nudge_x       = -2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1
  )+
  xlab("Genes")+
  ylab("Correlation with S4_pseudotime \n (Averaged;n=5)")+
  ggtitle("Gene expression correlated to S4 (Basal)")+
  NoLegend()

##
label_data_Alv <- cor_Alv[cor_Alv$rank %in% c(1:10)|
                          cor_Alv$rank.inv %in% c(1:10),] 

p3 <- ggplot(cor_Alv, aes(x=rank, y=mean.inv))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_Alv, aes(x=rank, y=mean.inv, color=row.names(label_data_Alv)), size=2)+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = 12319, 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  geom_label_repel(
    data          = subset(label_data_Alv, mean.inv > 0),
    aes(label=row.names(subset(label_data_Alv, mean.inv > 0))),
    nudge_x       = 2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0
  ) +
  geom_label_repel(
    data          = subset(label_data_Alv, mean.inv < 0),
    aes(label=row.names(subset(label_data_Alv, mean.inv < 0))),
    nudge_x       = -2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1
  )+
  xlab("Genes")+
  ylab("Correlation with S2_pseudotime \n (Averaged;n=5)")+
  ggtitle("Gene expression correlated to S2 (Alv)")+
  NoLegend()

##
label_data_Hor <- cor_Hor[cor_Hor$rank %in% c(1:10)|
                        cor_Hor$rank.inv %in% c(1:10),] 

p4 <- ggplot(cor_Hor, aes(x=rank, y=mean.inv))+
  geom_point(color="darkgray", size = 0.5)+
  geom_point(data=label_data_Hor, aes(x=rank, y=mean.inv, color=row.names(label_data_Hor)), size=2)+ 
  theme_classic()+
  theme(axis.text = element_blank(),
        axis.ticks = element_blank(), 
        axis.line = element_blank())+
  geom_segment(x = 0, xend = 0, 
               y = -1, yend = 1, size = 0.5)+
  geom_segment(x = 0, xend = 12319, 
               y = 0, yend = 0, size = 0.5)+
  geom_segment(data = xtick, 
               aes(x = ticks, xend = ticks, 
                   y = zero, yend = zero - tick_x)) +
  geom_segment(data = ytick, 
               aes(x = zero, xend = zero - tick_y, 
                   y = ticks, yend = ticks))+ 
  geom_text(data=xtick, aes(x=ticks, y=zero, label=ticks),
            vjust=1.5) +
  geom_text(data=ytick, aes(x=zero, y=ticks, label=ytick_lab),
            hjust=1.5)+
  geom_label_repel(
    data          = subset(label_data_Hor, mean.inv > 0),
    aes(label=row.names(subset(label_data_Hor, mean.inv > 0))),
    nudge_x       = 2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 0
  ) +
  geom_label_repel(
    data          = subset(label_data_Hor, mean.inv < 0),
    aes(label=row.names(subset(label_data_Hor, mean.inv < 0))),
    nudge_x       = -2500,
    segment.size  = 0.2,
    segment.color = "grey50",
    direction     = "y",
    hjust         = 1
  )+
  xlab("Genes")+
  ylab("Correlation with S1_pseudotime \n (Averaged;n=5)")+
  ggtitle("Gene expression correlated to S1 (Hor)")+
  NoLegend()

SFig9B <- plot_grid(p1, p2, p3, p4, align="hv", ncol=2)




###########################################################################
######### S Fig9C #########################################################
###########################################################################
cor_GSVA_Stem <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Stem.csv")
cor_GSVA_Basal <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Basal.csv")
cor_GSVA_Alv <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Alv.csv")
cor_GSVA_Hor <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Hor.csv")

colnames(cor_GSVA_Stem)[1] <- "Study"
colnames(cor_GSVA_Stem)[2:101] <- 1:100
temp_stem <- melt(cor_GSVA_Stem, id="Study", measure = colnames(cor_GSVA_Stem)[2:101])
temp_stem$value <- -1 * temp_stem$value
temp_stem$variable <- as.numeric(temp_stem$variable)
temp_stem$Category <- rep("Stem", length(row.names(temp_stem)))

colnames(cor_GSVA_Basal)[1] <- "Study"
colnames(cor_GSVA_Basal)[2:101] <- 1:100
temp_Basal <- melt(cor_GSVA_Basal, id="Study", measure = colnames(cor_GSVA_Basal)[2:101])
temp_Basal$value <- -1 * temp_Basal$value
temp_Basal$variable <- as.numeric(temp_Basal$variable)
temp_Basal$Category <- rep("Basal", length(row.names(temp_Basal)))

colnames(cor_GSVA_Alv)[1] <- "Study"
colnames(cor_GSVA_Alv)[2:101] <- 1:100
temp_Alv <- melt(cor_GSVA_Alv, id="Study", measure = colnames(cor_GSVA_Alv)[2:101])
temp_Alv$value <- -1 * temp_Alv$value
temp_Alv$variable <- as.numeric(temp_Alv$variable)
temp_Alv$Category <- rep("Alv", length(row.names(temp_Alv)))

colnames(cor_GSVA_Hor)[1] <- "Study"
colnames(cor_GSVA_Hor)[2:101] <- 1:100
temp_Hor <- melt(cor_GSVA_Hor, id="Study", measure = colnames(cor_GSVA_Hor)[2:101])
temp_Hor$value <- -1 * temp_Hor$value
temp_Hor$variable <- as.numeric(temp_Hor$variable)
temp_Hor$Category <- rep("Hor", length(row.names(temp_Hor)))

df <- rbind(temp_stem, temp_Basal, temp_Alv, temp_Hor)
cols <- c(wes_palette("IsleofDogs1", 1),"#FF7F00","#33A02C","#E31A1C")
df$Category <- factor(df$Category, levels = c("Stem", "Basal", "Alv", "Hor"))

###
cor_GSVA_Stem <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Stem_1000.csv")
cor_GSVA_Basal <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Basal_1000.csv")
cor_GSVA_Alv <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Alv_1000.csv")
cor_GSVA_Hor <- read.csv("...zenodo/GSVA/Mouse/cor_GSVA_Hor_1000.csv")

coln <- seq(120, 1000, 20)

colnames(cor_GSVA_Stem)[1] <- "Study"
colnames(cor_GSVA_Stem)[2:46] <- coln
temp_stem <- melt(cor_GSVA_Stem, id="Study", measure = colnames(cor_GSVA_Stem)[2:46])
temp_stem$value <- -1 * temp_stem$value
temp_stem$variable <- as.numeric(temp_stem$variable)
temp_stem$Category <- rep("Stem", length(row.names(temp_stem)))

colnames(cor_GSVA_Basal)[1] <- "Study"
colnames(cor_GSVA_Basal)[2:46] <- coln
temp_Basal <- melt(cor_GSVA_Basal, id="Study", measure = colnames(cor_GSVA_Basal)[2:46])
temp_Basal$value <- -1 * temp_Basal$value
temp_Basal$variable <- as.numeric(temp_Basal$variable)
temp_Basal$Category <- rep("Basal", length(row.names(temp_Basal)))

colnames(cor_GSVA_Alv)[1] <- "Study"
colnames(cor_GSVA_Alv)[2:46] <- coln
temp_Alv <- melt(cor_GSVA_Alv, id="Study", measure = colnames(cor_GSVA_Alv)[2:46])
temp_Alv$value <- -1 * temp_Alv$value
temp_Alv$variable <- as.numeric(temp_Alv$variable)
temp_Alv$Category <- rep("Alv", length(row.names(temp_Alv)))

colnames(cor_GSVA_Hor)[1] <- "Study"
colnames(cor_GSVA_Hor)[2:46] <- coln
temp_Hor <- melt(cor_GSVA_Hor, id="Study", measure = colnames(cor_GSVA_Hor)[2:46])
temp_Hor$value <- -1 * temp_Hor$value
temp_Hor$variable <- as.numeric(temp_Hor$variable)
temp_Hor$Category <- rep("Hor", length(row.names(temp_Hor)))

df2 <- rbind(temp_stem, temp_Basal, temp_Alv, temp_Hor)
cols <- c(wes_palette("IsleofDogs1", 1),"#FF7F00","#33A02C","#E31A1C")
df2$Category <- factor(df2$Category, levels = c("Stem", "Basal", "Alv", "Hor"))
df2$variable <- rep(coln, each=5)

df3 <- rbind(df,df2)

###
p1 <- ggplot(df3[df3$Category=="Stem",], aes(x=variable, y=value))+
  geom_smooth(col=wes_palette("IsleofDogs1", 1))+
  geom_point(aes(color=Study))+
  scale_color_manual(values=col.std)+
  ggtitle("GSVA_Stem_gene_sets")
p2 <- ggplot(df3[df3$Category=="Basal",], aes(x=variable, y=value))+
  geom_smooth(col="#FF7F00")+
  geom_point(aes(color=Study))+
  scale_color_manual(values=col.std)+
  ggtitle("GSVA_Basal_gene_sets")
p3 <- ggplot(df3[df3$Category=="Alv",], aes(x=variable, y=value))+
  geom_smooth(col="#33A02C")+
  geom_point(aes(color=Study))+
  scale_color_manual(values=col.std)+
  ggtitle("GSVA_Alv_gene_sets")
p4 <- ggplot(df3[df3$Category=="Hor",], aes(x=variable, y=value))+
  geom_smooth(col="#E31A1C")+
  geom_point(aes(color=Study))+
  scale_color_manual(values=col.std)+
  ggtitle("GSVA_Hor_gene_sets")

SFig9C <- plot_grid(p1,p2,p3,p4)







